# ----------------------------------------------------------------------
# The following installation directives can be edited to control the
# installation of the network performance test package.
# ----------------------------------------------------------------------

#
# Specify the root directory of the rTPL net performance test package.
# You may use the current root directory of this package, where this
# distribution directory resides. Alternatively a different root
# directory may be used.
#
PACKAGE_ROOT = ..

#
# Basename of the directory used for the net performance tests for a
# specified set hosts. Multiple host sets can be installed.
#
# The specified name translated to lowercase is used as file extension
# for files related with the set hosts (for instance log files).
#
# This directive defaults to use only the local host.
#
HOSTS_DIR = local

#
# Specify the title of the hosts set mentioned at the "HOSTS_DIR"
# directive.
#
HOSTS_TITLE = Local

#
# Specify the members of the hosts set mentioned at the "HOSTS_DIR"
# directive. Note that this directive is only used in shell scripts. The
# format of the host names is:
#
#       <Inet_host>/<QoS_host>/<host_title>/<remote_user>
#
# Please note that it is required to define all four fields, even when
# you do not use the Quality of Service feature.
#
HOSTS = "127.0.0.1/127.0.0.1/127.0.0.1/$$USER" \
	"localhost/localhost/localhost/$$USER"

#
# Specify if net tests must be performed one-directional. In that case
# the tests are performed form host A to host B and not in the reverse
# direction. When the two-directional option is selected
# ("ONE_DIRECT = false"), the tests are done from A => B and from
# B => A.
#
# ONE_DIRECT = true
#
ONE_DIRECT = false

#
# Specify if Quality of Service tests must be included.
#
# USE_QOS = true
#
USE_QOS = false

#
# Specify the title of the Quality of Service tests.
#
QOS_TITLE = QoS

#
# Specify the title of the "usual" Internet route. It is only used when
# also Quality of Service tests are performed.
#
INET_TITLE = Inet

#
# Specify the remote shell which is used at the performance tests
# mentioned at the "HOSTS_DIR" directive. It is also possible to specify
# remote shells for individual hosts. Note that the "Internet" hostname
# <Inet_host> (see the "HOSTS" directive) should be defined. Format:
#
#    RSH = <remote_shell> [<Inet_host>:<remote_shell> [...]]
#
# Optional '~' characters in the <remote_shell> command will be replaced
# by blanks.
#
RSH = ssh

#
# Specify for an individual host the directory path where the net
# performance test scripts can be found. Normally we rely to the shell
# startup files, so the default value of this variable empty. The format
# of this variable is:
#
#    HOST_PATHS = <Inet_host>:<path> [...]
#
HOST_PATHS =

#
# Specify a directory with HTML files (and accompanying files),
# describing the set hosts defined above. If no such files are
# available, this variable stays empty which is the default. When
# available the HTML files are placed in the directory
#
#	$(PACKAGE_ROOT)/html/$(HOSTS_DIR)/table/hosts
#
# and the main file should be named "index.html". It is hyperlinked from
# the net performance result pages one directory higher. When selected
# the pages are displayed in the same window as the help HTML pages
# which are also part of this distribution.
#
HOSTS_DOC_DIR =

#
# Optionally specify the Quality of Service IP addesses of the gateway
# to use which belongs to a specified <QoS_host>. This is useful when
# there are more gateways to select. The format of the IP address is:
#
#	<QoS_host>/<IP_QoS_gateway>
#
# The default value of this variable is empty.
#
IP_QOS_GWS =

#
# Optionally specify the "normal" Internet IP addesses of the gateway
# to use which belongs to a specified <Inet_host>. This is useful when
# there are more gateways to select. The format of the IP address is:
#
#	<Inet_host>/<IP_Inet_gateway>
#
# The default value of this variable is empty.
#
IP_INET_GWS =

#
# Optionally specify the source and destination host, defining a Quality
# of Service connection, for which the roundtrip and throughput
# measurements should be skipped. This is useful when it is not possible
# for one or other reason to do the measurements between these hosts.
# When one-directional tests are performed (see directive "ONE_DIRECT"),
# only the connection from the source to the destination host is
# skipped.
#
# The format of the hosts, specifying a connection, is:
#
#	<src_host>/<dest_host>
#
# The default value of this variable is empty.
#
SKIP_QOS_CONNS =

#
# Optionally specify the source and destination host, defining a
# "normal" Internet connection, for which the roundtrip and throughput
# measurements should be skipped. This is useful when it is not possible
# for one or other reason to do the measurements between these hosts.
# When one-directional tests are performed (see directive "ONE_DIRECT"),
# only the connection from the source to the destination host is
# skipped.
#
# The format of the hosts, specifying a connection, is:
#
#	<src_host>/<dest_host>
#
# The default value of this variable is empty.
#
SKIP_INET_CONNS =

#
# Specify the vistors counter text for the corresponding table column.
# Use an empty string when no counter is available.
#
# Do not forget to escape '&' and '#', because they are special
# characters for "make" and the used substitution program "sed".
#
# COUNTER =
#
COUNTER = <EM>Visitors:\&nbsp;</EM><!--\#exec cgi="/cgi-bin/counter"-->

#
# Specify the # days to store the data.
#
NR_DAYS = 7

#
# Specify the period in minutes to repeat the test measurements
#
PERIOD = 30

#
# Specify the # weeks to store the data; each week will be stored in a
# separate file.
#
NR_WEEKS = 54

#
# Specify the minimum # days that data must be obtained before these
# network data of a host will added be to the year covering, week mean
# data file.
#
MEAN_MIN_NR_DAYS = 2

#
# Specify the # days from which the days mean should be stored. When
# this value is less equal zero, just as many days are stored such that
# the data file is of equal size as the data file which contains the
# the data of the last days specified by the "NR_DAYS" directive,
# declared above. This is the default.
#
NR_MEAN_DAYS = 366

#
# Specify the minimum # hours that data must be obtained before these
# network data of a host will be added to the days mean.
#
MEAN_MIN_NR_HOURS = 7


# ----------------------------------------------------------------------
# The following directives are used for the roundtrip measurements at
# the specified set hosts. The program "ping" is used here.
# ----------------------------------------------------------------------

#
# Set the # pings.
#
PING_COUNT = 20

#
# Set the initial # pings to skip.
#
PING_SKIP = 2

#
# Set the count percentage of pings to be accepted after package lost.
#
PING_ACCEPT = 60

#
# Set the ping packet size [bytes].
#
PING_PACKET_SIZE = 56


# ----------------------------------------------------------------------
# The following directives are used for the throughput measurements at
# the specified set hosts. The program "netperf" is used here.
# ----------------------------------------------------------------------

#
# Specify the "netperf" test duration (>0 secs) (<0 bytes|trans).
#
NETPERF_TEST_LEN = 10

#
# Specify the "netperf" test to perform.
#
NETPERF_TEST_NAME = TCP_STREAM

#
# Set the "netperf" send size.
#
NETPERF_SEND_SIZE = 32768

#
# Set the "netperf" recv size.
#
NETPERF_RECV_SIZE = 32768

#
# Set the "netperf" local socket send/recv buffer sizes.
#
NETPERF_LOCAL_SIZE = 32768

#
# Set the "netperf" remote socket send/recv buffer sizes.
#
NETPERF_REMOTE_SIZE = 32768

#
# Set the "netperf" "TCP_NODELAY" option as follows:
#    <Undefined>   Do not set "TCP_NODELAY".
#    -D		   Set "TCP_NODELAY" locally and remotely.
#    -DL	   Set "TCP_NODELAY" locally.
#    -DR	   Set "TCP_NODELAY" remotely.
#
NETPERF_TCP_NODELAY_OPTION = -D


# ----------------------------------------------------------------------
# The following directives are used for the UDP bandwidth measurements
# at the specified set hosts. The program "udpmon_bw_mon" is used here.
#
# Please note that for these tests The Linux operating system is
# required with a Pentium processor.
# ----------------------------------------------------------------------

#
# Specify if UDP bandwidth tests must be included.
#
# USE_UDP_BW = false
#
USE_UDP_BW = true

#
# Set the UDP packet size.
#
UDP_PACKET_SIZE = 1400

#
# Set the UDP # packets.
#
UDP_NR_PACKETS = 300

#
# Set the UDP wait send time between two packets.
#
UDP_WAIT_TIME = 80


# ----------------------------------------------------------------------
# The following directives are only required in the exceptional
# situation that the net performance data of the specified hosts must be
# copied to another host for some reasons.
#
# In general they are left undefined.
# ----------------------------------------------------------------------

#
# Specify the root directory of the net performance package at the 
# remote host to which the data are copied. No absolute path is
# required: it may be defined relative to the home directory of the copy
# user at the remote host.
#
COPY_PACKAGE_ROOT =

#
# Basename of the directory used for the net performance tests at the
# copy host. See also the "HOSTS_DIR" directive.
#
COPY_HOSTS_DIR =

#
# Name of the host to which the net performance data should be copied.
# No data are copied when this directive stays empty.
#
COPY_HOST =

#
# Name of the user at the remote, copy host.
#
COPY_USER =


# ----------------------------------------------------------------------
# Define the color usage in the HTML pages.
# ----------------------------------------------------------------------

#
# Use yes/no gray values in the HTML pages. Gray values are useful for
# printing or to include the HTML pages in a document.
#
# USE_GRAY_VALUES = true
#
USE_GRAY_VALUES = false
