/* ------------------------------------------------------------------ */
/*		      D a t a P o i n t . j a v a		      */
/*		      ===========================		      */
/*								      */
/*   This file contains the source of the "DataPoint" class in the    */
/*   "user.plot" package.					      */
/* ------------------------------------------------------------------ */


package user.plot;    // Define the plot package.

/**
 * Auxiliary class of the <CODE>PlotCanvas</CODE> to hold the data read
 * in from the file.
 *
 *    @see  PlotCanvas
 *
 *    @author  Friedrich Schotte
 *    @author  Hans Blom
 *
**********************/
public class  DataPoint
/*********************/
{
    /*
     * Define the data point coordinate instances.
     */

    /**
     * The <I>X</I>-coordinate.
     */

    public double  x;

    /**
     * Higher <I>X</I>&nbsp;error bar.
     */

    public double  dxh;

    /**
     * Lower <I>X</I>&nbsp;error bar.
     */

    public double  dxl;

    /**
     * The <I>Y</I>-coordinate.
     */

    public double  y;

    /**
     * Higher <I>Y</I>&nbsp;error bar.
     */

    public double  dyh; 

    /**
     * Lower <I>Y</I>&nbsp;error bar.
     */

    public double  dyl; 
    

    /**
     * Constructor. Specify the coordinates and the higher and lower
     * error bars. When an argument is <CODE>null</CODE>, the
     * corresponding object is not used.
     *
     *    @param  x_obj     The <I>X</I>-coordinate.
     *
     *    @param  dxh_obj   The higher <I>X</I>&nbsp;error bar.
     *
     *    @param  dxl_obj   The lower <I>X</I>&nbsp;error bar.
     *
     *    @param  y_obj     The <I>Y</I>-coordinate.
     *
     *    @param  dyh_obj   The higher <I>Y</I>&nbsp;error bar.
     *
     *    @param  dyl_obj   The lower <I>Y</I>&nbsp;error bar.
     *
    **********************************/
    public  DataPoint (Double  x_obj,
		       Double  dxh_obj,
		       Double  dxl_obj,
		       Double  y_obj,
		       Double  dyh_obj,
		       Double  dyl_obj)
    /*********************************/
    {
	if (x_obj  != null)
	    x  = x_obj.doubleValue  ();

	if (dxh_obj != null)
	    dxh = dxh_obj.doubleValue ();

	if (dxl_obj != null)
	    dxl = dxl_obj.doubleValue ();

	if (y_obj  != null)
	    y  = y_obj.doubleValue  ();
	    
	if (dyh_obj != null)
	    dyh = dyh_obj.doubleValue ();
	    
	if (dyl_obj != null)
	    dyl = dyl_obj.doubleValue ();

    } // DataPoint ()


    /**
     * Constructor. Specify the <I>X</I>-coordinate and the
     * <Y>-coordinate without error bars. The coordinates are specified
     * by their primitive type.
     *
     *    @param  x   The <I>X</I>-coordinate.
     *
     *    @param  y   The <I>Y</I>-coordinate.
     *
    ****************************/
    public  DataPoint (double  x,
		       double  y)
    /***************************/
    {
	this (new Double (x), null, null,
	      new Double (y), null, null);
    }


    /**
     * Constructor. Specify the <I>X</I>-coordinate and the
     * <Y>-coordinate without the <I>X</I>&nbsp;error bar. The
     * coordinates are specified by their primitive type.
     *
     *    @param  x     The <I>X</I>-coordinate.
     *
     *    @param  y     The <I>Y</I>-coordinate.
     *
     *	  @param  dyh   The higher <I>Y</I>&nbsp;error bar.
     *
     *    @param  dyl   The lower <I>Y</I>&nbsp;error bar.
     *
    ******************************/
    public  DataPoint (double  x,
		       double  y,
		       double  dyh,
		       double  dyl)
    /*****************************/
    {
	this (new Double (x), null,		null,
	      new Double (y), new Double (dyh), new Double (dyl));
    }


    /**
     * Constructor. Specify the <I>X</I>-coordinate and the
     * <Y>-coordinate with error bars. The coordinates are specified by
     * their primitive type.
     *
     *    @param  x     The <I>X</I>-coordinate.
     *
     *	  @param  dxh   The higher <I>X</I>&nbsp;error bar.
     *
     *    @param  dxl   The lower <I>X</I>&nbsp;error bar.
     *
     *    @param  y     The <I>Y</I>-coordinate.
     *
     *	  @param  dyh   The higher <I>Y</I>&nbsp;error bar.
     *
     *    @param  dyl   The lower <I>Y</I>&nbsp;error bar.
     *
    ******************************/
    public  DataPoint (double  x,
		       double  dxh,
		       double  dxl,
		       double  y,
		       double  dyh,
		       double  dyl)
    /*****************************/
    {
	this (new Double (x), new Double (dxh), new Double (dxl),
	      new Double (y), new Double (dyh), new Double (dyl));
    }

} // class DataPoint
