/* ------------------------------------------------------------------ */
/*		     P l o t A p p l e t . j a v a		      */
/*		     =============================		      */
/*								      */
/*   This file contains the source of the "PlotApplet" class in the   */
/*   "user.plot" package. It is used in connection with the	      */
/*   "PlotCanvas" class.					      */
/* ------------------------------------------------------------------ */


package user.plot;    // Define the plot package.

import java.lang.*;
import java.io.*;
import java.awt.*;
import java.applet.*;
import java.util.*;


/**
 * This class contains the Applet methods connected with the
 * <CODE>PlotCanvas</CODE>.
 *
 *    @see  PlotCanvas
 *    @see  PlotDataApplet
 *
 *    @author  Friedrich Schotte
 *    @author  Hans Blom
 *
******************************************************/
public class  PlotApplet  extends     Applet
			  implements  PlotStatusHandler
/*****************************************************/
{
    /*
     * Define the class instances.
     */
     
    private PlotCanvas  plot;    // The plot canvas.
    private String      error;	 // Contains an error exception message.


    /**
     * Initialise the <CODE>PlotApplet</CODE>. In this method the plot
     * canvas is specialised. Also the Applet parameters are read.
     *
     *    @param  plot   The used plot canvas.
     *
    ***********************************/
    public void  init (PlotCanvas  plot)
    /**********************************/
    {
	/*
	 * Set the instance variables.
	 */
	 
	this.plot  = plot;    // The plot canvas to use.
	this.error = null;    // No error messages yet.

	/*
	 * Use this class as the "PlotStatusHandler" interface when
	 * this interface is still the empty implementation of the
	 * "PlotCanvas" instance itself
	 */

	if (plot.getPlotStatusHandler () == plot)
	    plot.setPlotStatusHandler (this);

	/*
	 * Read the plot parameters from the Applet.
	 */

        plot.setXAxisLabel (getParameter ("x axis"));
        plot.setYAxisLabel (getParameter ("y axis"));

        if (getParameter ("tick length") != null) 
	    plot.setTickLength (Integer.parseInt (
			            getParameter ("tick length")));

        if (getParameter ("x tick spacing") != null) 
	    plot.setXTickSpacing (Integer.parseInt (
				  getParameter ("x tick spacing")));

        if (getParameter ("y tick spacing") != null) 
	    plot.setYTickSpacing (Integer.parseInt (
				  getParameter ("y tick spacing")));
			       
        if (getParameter ("colors") != null)
        {
	    StringTokenizer  list = new StringTokenizer (
					    getParameter ("colors"));  

            while (list.hasMoreTokens ())
		plot.addTraceColor (parseColor (list.nextToken ()));
        }

        if (getParameter ("area background") != null) 
	    plot.setAreaBackground (
		parseColor (getParameter ("area background")));

        if (getParameter ("x offset") != null) 
        {
	    StringTokenizer  list = new StringTokenizer (
					    getParameter ("x offset"));

            while (list.hasMoreTokens ()) 
            {
		String value = list.nextToken ();

		try
		{
		    plot.addXOffset (new Double (value));
		}
		catch (NumberFormatException  e)
		{
		    error = "x offset: " + value + ": " + e;
		}
            }
        }

        if (getParameter ("y offset") != null) 
        {
	    StringTokenizer  list = new StringTokenizer (
					    getParameter ("y offset"));

            while (list.hasMoreTokens()) 
	    {
		String  value = list.nextToken ();

	    try
	    {
		plot.addYOffset (new Double (value));
	    }
	    catch (NumberFormatException  e)
	    {
		error = "y offset: '" + value + "': numeric?"; }
            }
	}
	    
	if (getParameter ("join") != null) 
	{
	    StringTokenizer  list = new StringTokenizer (
					    getParameter ("join"));

	    while (list.hasMoreTokens ())
		plot.addJoin (new Boolean (list.nextToken ()));
	}

	if (getParameter ("marker") != null) 
	{
	    StringTokenizer  list = new StringTokenizer (
					    getParameter ("marker"));

	    while (list.hasMoreTokens ())
		plot.addMarker (list.nextToken ());
	}
	
	if (getParameter ("x min") != null) 
	{
	    try
	    {
		plot.setXMin (new Double (getParameter ("x min")));
	    }
	    catch (NumberFormatException  e)
	    {
		error = "xmin: numeric ?";
	    }
	}

	if (getParameter ("x max") != null) 
	{
	    try
	    {
		plot.setXMax (new Double (getParameter ("x max")));
	    }
	    catch (NumberFormatException  e)
	    {
		error = "xmax: numeric ?";
	    }
	}

	if (getParameter ("y min") != null) 
	{
	    try
	    {
		plot.setYMin (new Double (getParameter ("y min")));
	    }
	    catch (NumberFormatException  e)
	    {
		error = "ymin: numeric ?";
	    }
	}

	if (getParameter ("y max") != null) 
	{
	    try
	    {
		plot.setYMax (new Double (getParameter ("y max")));
	    }
	    catch (NumberFormatException  e)
	    {
		error = "ymax: numeric ?";
	    }
	}

	if (getParameter ("x scaling") != null) 
	{
	    String value = getParameter ("x scaling");

            if (value.equals ("linear"))
		plot.setXScaling (PlotCanvas.LINEAR);
	    else if (value.equals ("log"))
		plot.setXScaling (PlotCanvas.LOG);
	    else
		error = "x scaling: '" + value +
			"': expecting one or two of 'linear' or 'log'"; 
	}

	if (getParameter ("y scaling") != null) 
	{
	    String value = getParameter ("y scaling");

            if (value.equals ("linear"))
		plot.setYScaling (PlotCanvas.LINEAR);
	    else if (value.equals ("log"))
		plot.setYScaling (PlotCanvas.LOG);
	    else
		error = "x scaling: '" + value +
			"': expecting one or two of 'linear' or 'log'"; 
	}
    
    } // init ()


    /**
     * Overload the (empty) <CODE>start()</CODE> method of the
     * <CODE>Applet</CODE> class to resume the painting in the
     * <CODE>PlotCanvas</CODE> class.
     *
     *    @see  PlotCanvas#resumePaint
     *    @see  PlotApplet#stop
     *    @see  PlotApplet#destroy
     *
    ********************/
    public void  start ()
    /*******************/
    {
	plot.resumePaint ();
    }


    /**
     * Overload the (empty) <CODE>stop()</CODE> method of the
     * <CODE>Applet</CODE> class to suspend the painting in the
     * <CODE>PlotCanvas</CODE> class.
     *
     *    @see  PlotCanvas#suspendPaint
     *    @see  PlotApplet#start
     *    @see  PlotApplet#destroy
     *
    *******************/
    public void  stop ()
    /******************/
    {
	plot.suspendPaint ();
    }


    /**
     * Overload the (empty) <CODE>destroy()</CODE> method of the
     * <CODE>Applet</CODE> class to destroy the painting in the
     * <CODE>PlotCanvas</CODE> class.
     *
     *    @see  PlotCanvas#destroyPaint
     *    @see  PlotApplet#start
     *    @see  PlotApplet#stop
     *
    **********************/
    public void  destroy ()
    /*********************/
    {
	plot.destroyPaint ();
    }


    /**
     * Set the error string.
     *
     *    @param  error   The error string to set.
     *
    *****************************/
    void  setError (String  error)
    /****************************/
    {
	this.error = error;
    }


    /**
     * Get the error string.
     *
     *    @return   The error string.
     *
    *************************/
    public String  getError ()
    /************************/
    {
	return error;
    }


    /**
     * Needed for the &quot;colors&quot; parameter list, converts string
     * to color.  (As of Java 1.0 there is no such utility in the
     * <CODE>Color</CODE> class.)
     *
     *    @param  name  "red", "green", "blue", "pink", "orange",
     *			"magenta", "cyan", "white", "yellow",
     *			"gray", "grey", "lightGray", "lightGrey",
     *			"darkGray", "darkGrey" or "black"
     *
     *    @return   The color specified by the color name.
     *
    **************************************/
    public Color  parseColor (String  name)
    /*************************************/
    { 
	if (name == null)	      // Get foreground if no name spec.
	    return getForeground ();
	else if (name.equals ("red"))
	    return Color.red;
	else if (name.equals ("green"))
	    return Color.green;
	else if (name.equals ("blue"))
	    return Color.blue;
	else if (name.equals ("pink"))
	    return Color.pink;
	else if (name.equals ("orange"))
	    return Color.orange;
	else if (name.equals ("magenta"))
	    return Color.magenta;
	else if (name.equals ("cyan"))
	    return Color.cyan;
	else if (name.equals ("white"))
	    return Color.white;
	else if (name.equals ("yellow"))
	    return Color.yellow;
	else if (name.equals ("gray"))
	    return Color.gray;
	else if (name.equals ("grey"))
	    return Color.gray;
	else if (name.equals ("lightGray"))
	    return Color.lightGray;
	else if (name.equals ("lightGrey"))
	    return Color.lightGray;
	else if (name.equals ("darkGray"))
	    return Color.darkGray;
	else if (name.equals ("darkGrey"))
	    return Color.darkGray;
	else if (name.equals ("black"))
	    return Color.black;
	else if (name.substring (0, 1).equals ("#")) 
	{
	    /*
	     * Interpret name as hexadecimal number of 3 x 8 bit
	     * red/green/blue values.
	     */

	    int  rgb;

	    try
	    {
		rgb = Integer.valueOf ( name.substring (1), 16
				      ).intValue ();
	    } 
	    catch (NumberFormatException  e)
	    {
		error = "'" + name + "'= hex number?";
		rgb   = 0x0;
	    }

	    return new Color (rgb);
	  }

	// If no matching name found:
	
	String  colors = "red, green, blue, pink, orange, " +
			 "magenta, cyan, white, yellow, " +
			 "gray(grey), darkGray(darkGrey), black, " +
			 "#rrggbb";

	error = "'" + name + "': choice of colors is very limited: \n" +
		colors + "\n (sorry)";
		
	return Color.black;
    
    } // parseColor ()


    /**
     * Show the plot status message. This method is part of the
     * <CODE>PlotStatusHandler</CODE> interface. This implementation
     * shows the message in the status bar of the browser. It is only
     * used when the user does not implements the interface.
     *
     *    @param  message        The plot status message to show.
     *
     *    @param  canvas_state   The enter, be within, or exit the plot
     *                           canvas state.
     *
     *    @see  PlotStatusHandler
     *    @see  PlotCanvas#ENTER
     *    @see  PlotCanvas#WITHIN
     *    @see  PlotCanvas#EXIT
     *
    **********************************************/
    public void  showMessage (String  message,
			      int     canvas_state)
    /*********************************************/
    {
	showStatus (message);
    }

    
    /**
     * Return the information about the plot Applet.
     *
     *    @return   The applet information.
     *
    ******************************/
    public String  getAppletInfo ()
    /*****************************/
    {
	return "Plot by Friedrich Schotte and Hans Blom";
    }

    
    /**
     * Return information about the Plot Applet parameters.
     *
     *    @return   The parameter information.
     *
    **************************************/
    public String [][]  getParameterInfo ()
    /*************************************/
    {
	String [][]  paramter_info =
	{
	  { "colors", "string [string ...]",
	    "clear text name(s), useful if more than one trace" },
	  { "tick length", "int",
	    "scaling marks on x and y axis (pixels, neg. = outside)" },
	  { "x tick spacing", "int",
	    "is automatically calculated, give upper limit (pixels)" },
	  { "y tick spacing", "int",
	    "is automatically calculated, give upper limit (pixels)" },
	  { "x axis", "string", "descriptive label" },
	  { "y axis", "string", "descriptive label" },
	  { "area background", "string", "color name for plot area" },
	  { "x offset", "double [double ...]",
	    "useful if multiple very similar traces" },
	  { "y offset", "double [double ...]",
	    "useful if multiple very similar traces" },
	  { "join", "boolean [boolean ...]",
	    "connect data point by lines (default = true)" },
	  { "marker", "string [string...]",
	    "none, diamond, square, triangle, octagon, diabolo, " +
	    "x_sign, plus_sign, y_sign, arrow, bowtie, z_sign. " +
	    "rayed_square, bushel, asteric" },
	  { "x scaling", "[linear|log]",
	    "for x axis (default = linear)" },
	  { "y scaling", "[linear|log]",
	    "for y axis (default = linear)" },
	  { "x min", "double", "x axis start (default = autoscale)" },
	  { "x max", "double", "x axis end (default = autoscale)" },
	  { "y min", "double", "y axis start (default = autoscale)" },
	  { "y max", "double", "y axis end (default = autoscale)" },
	};

	return paramter_info;

    } // getParameterInfo ()

} // class PlotApplet
