/* ------------------------------------------------------------------ */
/*			N e t D a t a . j a v a			      */
/*			=======================			      */
/*								      */
/*   This file contains the main source of the Net Data Applet.	      */
/* ------------------------------------------------------------------ */


import java.io.*;
import java.util.*;
import java.util.zip.*;
import java.awt.*;
import java.applet.*;
import java.net.*;
import user.common.*;
import user.signal.*;
import user.plot.*;


/**
 * This class is used to read the file <CODE>data/net_data</CODE> which
 * contains the net traffic data from the local file system or from the
 * Web server. This class main function is to store the net data and to
 * make the data available for JavaScript code.
 * </P>
 *
 * <P>
 * To show the user the availability of the data at the Web server or
 * file system a signal light is used. This light is:
 * <UL>
 * <LI><B>Red</B> when no data are loaded yet, or the data could not be
 *     loaded.</LI>
 * <LI><B>Yellow</B> when the net data are being loaded. The light is:
 *     <UL>
 *     <LI><B>Blinking</B>  when the loading is continuing.</LI>
 *     <LI><B>Stationary</B> when we have to wait for the Web server or
 *	   when the loading is very slow.</LI>
 *     </UL></LI>
 * <LI><B>Green</B> when the net data are loaded.</LI>
 * </UL>
 * </P>
 *
 * <P>
 * The data are read in a separate thread. A special class instance is
 * used for the synchronisation with the main thread. The usage of the
 * data read thread is required, because is is a security violation at
 * some browsers (a.o. Netscape&nbsp;6) to call the Applet data read
 * method from JavaScript.
 * </P>
 *
 * <P>
 * It is also possible to show the data in a plot window
 * <CODE>Frame</CODE>. There are several methods available to plot the
 * corresponding net data. The frame is plotted as an instance of the
 * <CODE>DataPlotFrame</CODE> class which on its turn is managed by an
 * instance of the <CODE>DataPlotWindow</CODE> class. Only methods of
 * this class should be used handle the plot window frame.
 * </P>
 *
 * <P>
 * All function arguments and return values from the functions to be
 * called from JavaScript are instances of the <CODE>String</CODE>
 * class. This is done to be compatible with older browsers.
 * </P>
 *
 * <P>
 * The function which are intended to be called from JavaScript are
 * explicitly marked &quot;<EM>To be called from JavaScript</EM>&quot;.
 * </P>
 *
 *    @author  Hans Blom
 *
****************************************************/
public class  NetData  extends     PlotApplet
		       implements  Runnable,
				   ExternPlotControls,
				   BlinkChecker
/***************************************************/
{
    /*
     * Define the boolean string constants.
     */

    private static final String  TRUE_STR  = "true";
    private static final String  FALSE_STR = "false";

    /*
     * Set the used background.
     */

    private static final Color  BACKGROUND = Color.white;

    /*
     * Set the default name of the dates file and the name of the
     * parameter to be read by the Applet.
     */

    private static final String  DEFAULT_DATES_FILE = "data/dates.zip";
    private static final String  DATES_FILE_NAME    = "DatesFile";

    /*
     * Set the name of the recent data file.
     */

    private static final String  RECENT_DATA_FILE = "data/net_data.zip";

    /*
     * Set the file possible data file type names.
     */

    private static final String  RECENT_DATA_TYPE    = "last_days";
    private static final String  WEEK_DATA_TYPE	     = "week";
    private static final String  WEEK_MEAN_DATA_TYPE = "week_mean";
    private static final String  DAY_MEAN_DATA_TYPE  = "day_mean";
    private static final String  QUARTER_DATA_TYPE   = "quarter_mean";
    private static final String  MONTH_DATA_TYPE     = "month_mean";

    /*
     * Set the net data type indices and the # of data types.
     */

    private static final int  RECENT_DATA_INDEX	   = 0; // Recent data.
    private static final int  WEEK_DATA_INDEX	   = 1; // Week data.
    private static final int  WEEK_MEAN_DATA_INDEX = 2; // Week mean dt.
    private static final int  DAY_MEAN_DATA_INDEX  = 3; // Day mean dt.
    private static final int  QUARTER_DATA_INDEX   = 4; // Quarter data.
    private static final int  MONTH_DATA_INDEX	   = 5; // Month data.
    private static final int  NR_DATA_TYPES	   = 6; // # Data types.

    /*
     * Set the default file, file (index) type and corresponding file ID
     * to the data from the last # days (most recent data). Note that
     * there is no file ID for this data type.
     */

    private static final String  DEFAULT_DATA_FILE  = RECENT_DATA_FILE;
    private static final String  DEFAULT_FILE_TYPE  = RECENT_DATA_TYPE;
    private static final int	 DEFAULT_DATA_INDEX = RECENT_DATA_INDEX;
    private static final int	 DEFAULT_FILE_ID    = -1;

    /*
     * Set the default name of the flag which determines if the net data
     * dates should be read. Set also the name of the corresponding
     * Applet parameter to be read from the HTML page.
     */

    private static final boolean  DEFAULT_READ_DATES = true;
    private static final String	  READ_DATES_NAME    = "ReadDates";

    /*
     * Set the default title of the hosts set. Default it is undefined.
     * It only will be used by JavaScript.
     */

    private static final String  DEFAULT_SET_TITLE = "***";

    /*
     * Set the default period between two date steps. It is set as
     * string, because the period is only used from JavaScript.
     */

    private static final String  DEFAULT_PERIOD = "30"; // [m]

    /*
     * Set the default value of the flag which controls if one-
     * directional or two-directional net tests traffic is used.
     */

    private static final boolean  DEFAULT_ONE_DIRECT = true;

    /*
     * Set the default value of the flag which controls if both QoS and
     * Internet net data types are used.
     */

    private static final boolean  DEFAULT_QOS_AND_INET = true;

    /*
     * Set the default QoS title.
     */

    private static final String  DEFAULT_QOS_TITLE = "QoS";

    /*
     * Set the default title of the "usual" Internet route.
     */

    private static final String  DEFAULT_INET_TITLE = "Inet";

    /*
     * Set the default value of the flag which controls if UDP bandwidth
     * measurements should be executed.
     */

    private static final boolean  DEFAULT_USE_UDP_BW = true;

    /*
     * Set the name of the Applet parameter which is used to determine
     * if a white foreground must be used. This is the case when the
     * green intensity is below the value specified by this parameter.
     */

    private static final String  GREEN_WHITE_FGND_BND_NAME =
				     "GreenWhiteFgndBnd";

    /*
     * Set the name of the Applet parameters who are used to set the
     * background and foreground colors of the plot legends from the
     * plot trace(s) not shown in the plot.
     */

    private static final String  NO_PLOT_LEGEND_BGND_NAME =
				     "NoPlotLegendBgnd";
    private static final String  NO_PLOT_LEGEND_FGND_NAME =
				     "NoPlotLegendFgnd";

    /*
     * Set the name of the Data_Type field and the names of the data
     * types. They are used in the data file.
     */

    private static final String  DATA_TYPE_NAME    = "Data_Type";
    private static final String  NET_TYPE_NAME	   = "Net_Type";
    private static final String  SET_TITLE_NAME	   = "set_title";
    private static final String  ONE_DIRECT_NAME   = "one_direct";
    private static final String  PERIOD_NAME	   = "period";
    private static final String  FILE_TYPE_NAME    = "file_type";
    private static final String  FILE_ID_NAME	   = "file_id";
    private static final String  USE_QOS_NAME	   = "use_qos";
    private static final String  QOS_TITLE_NAME	   = "qos_title";
    private static final String  INET_TITLE_NAME   = "inet_title";
    private static final String  HOST_TITLE_NAME   = "host_title";
    private static final String  SKIP_CONN_NAME    = "skip_conn";
    private static final String  WEEK_NAME	   = "week";
    private static final String  DAY_NAME	   = "day";
    private static final String  MEAN_QUARTER_NAME = "mean_quarter";
    private static final String  QUARTER_NAME	   = "quarter";
    private static final String  MEAN_MONTH_NAME   = "mean_month";
    private static final String  MONTH_NAME	   = "month";
    private static final String  WEEK_DATES_NAME   = "week_dates";
    private static final String  LOAD_NAME	   = "load";
    private static final String  PING_NAME	   = "ping";
    private static final String  THROUGHPUT_NAME   = "throughput";
    private static final String  USE_UDP_BW_NAME   = "use_udp_bw";
    private static final String  UDP_BW_NAME	   = "udp_bw";

    /*
     * Convert some of the constants, defined above, to character
     * arrays.
     */

    private static final char []  DATA_TYPE_NAME_CHARS =
	DATA_TYPE_NAME.toCharArray ();
    private static final char []  NET_TYPE_NAME_CHARS  =
	NET_TYPE_NAME.toCharArray  ();

    /*
     * Set the titles of the plot frames for the used (net) data types.
     */

    private static final String  PLOT_TITLE_TRAILOR	= "Data Plot";
    private static final String  PLOT_PING_PREFIX	= "Ping";
    private static final String  PLOT_THROUGHPUT_PREFIX = "Throughput";
    private static final String  PLOT_UDP_BW_PREFIX	= "UDP";
    
    private static final String  PLOT_LOAD_TITLE	=
	"Load " + PLOT_TITLE_TRAILOR;

    /*
     * Set the axis prefix for some net data types.
     */

    private static final String  AXIS_UDP_BW_PREFIX = "UDP BW";

    /*
     * Set the title trailors repesenting the data types.
     */

    private static final String  RECENT_DATA_PREFIX  = "of Last";
    private static final String  RECENT_DATA_TRAILOR = "Days";
    private static final String  WEEK_DATA_PREFIX    = "of Week";
    private static final String  WEEK_MEAN_TITLE     = "of Week Mean";
    private static final String  DAY_MEAN_TITLE      = "of Day Mean";
    private static final String  QUARTER_PREFIX	     =
	"of Time Mean Quarter";
    private static final String  MONTH_PREFIX	     =
	"of Time Mean Month";

    /*
     * Set the labels of the plot axes. The date, week and day (X) axes
     * are used by all data types.
     */

    private static final String  DATE_AXIS_LABEL       = "Date";
    private static final String  WEEK_AXIS_LABEL       = "Week";
    private static final String  DAY_AXIS_LABEL        = "Day";
    private static final String  LOAD_AXIS_LABEL       = "Load";
    private static final String  THROUGHPUT_AXIS_LABEL =
	"Throughput [Mbit/s]";

    /*
     * Set the label used to select new data.
     */

    private static final String  TO_FIRST_LABEL = "|<<";  // First data.
    private static final String  TO_PREV_LABEL	= "<<";	  // Prev. data.
    private static final String  TO_NEXT_LABEL	= ">>";   // Next  data.

    /*
     * Set the status messages shown connected to the corresponding new
     * data labels.
     */

    private static final String  TO_FIRST_STATUS =
	"Go to the first time/date range.";
    private static final String  TO_PREV_STATUS  =
	"Go to the previous time/date range.";
    private static final String  TO_NEXT_STATUS  =
	"Go to the next time/date range.";

    /*
     * Set the host connection labels. They are used between 1th and 2th
     * host in net data connections.
     */

    private static final String  HOST_TO_LABEL	 = TO_NEXT_LABEL;
    private static final String  HOST_FROM_LABEL = TO_PREV_LABEL;

    /*
     * Set the minimum ping, throughput and UDP bandwidth (receive rate
     * and packages lost) values when logarithmic Y-scaling is used and
     * no values smaller equals zero are allowed: they are set to the
     * assumed minimum values. Set also the corresponding constant
     * "Double" class instances which are used to add to the plot trace
     * when the ping, throughput and various UDP bandwidth values were
     * too small.
     */

     private static final double  MIN_LOG_PING_VALUE = 1.0E-3; // [ms].
     private static final Double  MIN_LOG_PING       =
	new Double (MIN_LOG_PING_VALUE);

    private static final double  MIN_LOG_THROUGHPUT_VALUE =
	1.0E-3; // [Mbit/s].
    private static final Double  MIN_LOG_THROUGHPUT	  =
	new Double (MIN_LOG_THROUGHPUT_VALUE);

    private static final double MIN_LOG_UDP_BW_VALUE =
	1.0E-3; // [Mbit/s].
    private static final Double  MIN_LOG_UDP_BW	  =
	new Double (MIN_LOG_UDP_BW_VALUE);

    /*
     * Set the index of the private controls used at the top of the plot
     * frame window.
     */

    private static final int  SHOW_BUTTON_INDEX    = 0; // All/host dat.
    private static final int  SCALING_BUTTON_INDEX = 1; // Y-Ax scaling.
    private static final int  DOMAIN_PANEL_INDEX   = 2; // Time domains.
    private static final int  NR_CONTROLS	   = 3; // # Priv. ctrl.

    /*
     * Set the index of the private controls used at the top of the load
     * plot frame window.
     */

    private static final int  DOMAIN_PANEL_LOAD_INDEX = 0; // Time dom.
    private static final int  NR_LOAD_CONTROLS	      = 1; // # Crtl.

    /*
     * Set the border around the time domain control components.
     */

    private static final int  DOMAIN_CONTROL_BORDER = 1;

    /*
     * Set the domain items for one day and for the full domain.
     */

    private static final String  DOMAIN_ONE_DAY_ITEM = "< 1 Day >";
    private static final String  DOMAIN_FULL_ITEM    = "< Full >";

    /*
     * Set the time domain value for one day and for the full domains.
     */

    private static final long  DOMAIN_ONE_DAY_TIME =  1L *
						     DateFormat.DAYS;
    private static final long  DOMAIN_FULL_TIME    = -1L;

    /*
     * Set the maximum domain times used for the most recent days in the
     * related selector. Also set the default domain and the minimum and
     * maximum # time domain days.
     */

    private static final String  DEFAULT_RECENT_DOMAIN_ITEM =
	DOMAIN_ONE_DAY_ITEM;
    private static final int	 MIN_NR_RECENT_DOMAIN_DAYS  = 1;
    private static final int	 MAX_NR_RECENT_DOMAIN_DAYS  = 7;

    private static final String []  MAX_RECENT_DOMAIN_ITEMS =
    {
	"< 12 Hours >",
	DOMAIN_ONE_DAY_ITEM,
	"< 2 Days >",
	"< 3 Days >",
	"< 4 Days >",
	"< 5 Days >",
	"< 6 Days >",
	"< 7 Days >",
	DOMAIN_FULL_ITEM
    };

    /*
     * Set the corresponding time domain interval values for the most
     * recent days data type.
     */

    private static final long  DEFAULT_RECENT_DOMAIN_TIME =
	DOMAIN_ONE_DAY_TIME;

    private static final long []  MAX_RECENT_DOMAIN_TIMES =
    {
	12L * DateFormat.HOURS,
	DOMAIN_ONE_DAY_TIME,
	 2L * DateFormat.DAYS,
	 3L * DateFormat.DAYS,
	 4L * DateFormat.DAYS,
	 5L * DateFormat.DAYS,
	 6L * DateFormat.DAYS,
	 7L * DateFormat.DAYS,
	DOMAIN_FULL_TIME
    };

    /*
     * Set the name of the parameter which denotes the # recent days.
     */

    private static final String  NR_RECENT_DAYS_NAME = "NrRecentDays";

    /*
     * Set the status message shown at the recent date time / date
     * range selector.
     */

    private static final String  RECENT_DOMAIN_STATUS =
	"Set the time/day range.";

    /*
     * Set the domain times used for the week data files in the related
     * selector. Also set the default domain. The maximum # domains for
     * the most recent days are used.
     */

    private static final String     DEFAULT_WEEK_DOMAIN_ITEM =
	DOMAIN_ONE_DAY_ITEM;
    private static final String []  WEEK_DOMAIN_ITEMS	     =
	MAX_RECENT_DOMAIN_ITEMS;

    /*
     * Set the corresponding time domain interval values for week data
     * type.
     */

    private static final long	  DEFAULT_WEEK_DOMAIN_TIME =
	DOMAIN_ONE_DAY_TIME;
    private static final long []  WEEK_DOMAIN_TIMES	   =
	MAX_RECENT_DOMAIN_TIMES;

    /*
     * Set the status message shown at the week time / date range
     * selector.
     */

    private static final String  WEEK_DOMAIN_STATUS =
	RECENT_DOMAIN_STATUS;

    /*
     * Set the domain items for the week mean data type and its default
     * value.
     */

    private static final String  DOMAIN_26_WEEKS_ITEM = "< 26 Weeks>";

    private static final String  DEFAULT_WEEK_MEAN_DOMAIN_ITEM =
	DOMAIN_26_WEEKS_ITEM;

    private static final String []  WEEK_MEAN_DOMAIN_ITEMS =
    {
	DOMAIN_26_WEEKS_ITEM,
	"< 52 Weeks>",
	DOMAIN_FULL_ITEM
    };

    /*
     * Set the domain times for the week mean data type.
     */

    private static final long  DOMAIN_26_WEEKS_TIME = 26L *
						      DateFormat.WEEKS;

    private static final long  DEFAULT_WEEK_MEAN_DOMAIN_TIME =
	DOMAIN_26_WEEKS_TIME;

    private static final long []  WEEK_MEAN_DOMAIN_TIMES =
    {
	DOMAIN_26_WEEKS_TIME,
	52L * DateFormat.WEEKS,
	DOMAIN_FULL_TIME
    };

    /*
     * Set the status message shown at the week mean date range
     * selector.
     */

    private static final String  WEEK_MEAN_DOMAIN_STATUS =
	"Set the week range.";

    /*
     * Set the maximum domain items for the day mean data type: there
     * are items added as long as the # days is smaller than the
     * maximum # days in the data file.
     */

    private static final String  DOMAIN_30_DAYS_ITEM = "< 30 Days >";

    private static final String  DEFAULT_DAY_MEAN_DOMAIN_ITEM =
	DOMAIN_30_DAYS_ITEM;

    private static final String []  MAX_DAY_MEAN_DOMAIN_ITEMS =
    {
	DOMAIN_30_DAYS_ITEM,
	"< 60 Days >",
	"< 90 Days >",
	"< 120 Days >",
	"< 180 Days >",
	"< 360 Days >",
	DOMAIN_FULL_ITEM
    };

    /*
     * Set the maximum domain times for the day mean data type.
     */

    private static final long  DOMAIN_30_DAYS_TIME = 30L *
						     DateFormat.DAYS;

    private static final long  DEFAULT_DAY_MEAN_DOMAIN_TIME =
	DOMAIN_30_DAYS_TIME;

    private static final long []  MAX_DAY_MEAN_DOMAIN_TIMES =
    {
	DOMAIN_30_DAYS_TIME,
	 60L * DateFormat.DAYS,
	 90L * DateFormat.DAYS,
	120L * DateFormat.DAYS,
	180L * DateFormat.DAYS,
	360L * DateFormat.DAYS,
	DOMAIN_FULL_TIME
    };

    /*
     * Set the default value and the name of the parameter containing
     * the maximum # days of the day mean data type available in the
     * data file.
     */

    private static final int	 DEFAULT_NR_MEAN_DAYS = 366;
    private static final String  NR_MEAN_DAYS_NAME    = "NrMeanDays";

    /*
     * Set the perecntage to be added to the # mean days value during
     * the comparison if a domain range for the mean day data type
     * should be used.
     */

    private static final int  ADD_NR_MEAN_DAYS_PERC = 10; // %

    /*
     * Set the status message shown at the day mean date range selector.
     */

    private static final String  DAY_MEAN_DOMAIN_STATUS =
	"Set the day range.";

    /*
     * Set the domain items used for the quarter time domain data type,
     * the default domain item and the corresponding time domains.
     */

    private static final String	    DEFAULT_QUARTER_DOMAIN_ITEM =
	DOMAIN_ONE_DAY_ITEM;
    private static final String []  QUARTER_DOMAIN_ITEMS	=
	MAX_RECENT_DOMAIN_ITEMS;
    private static final long	    DEFAULT_QUARTER_DOMAIN_TIME =
	DOMAIN_ONE_DAY_TIME;
    private static final long	[]  QUARTER_DOMAIN_TIMES	=
	MAX_RECENT_DOMAIN_TIMES;

    /*
     * Set the status message shown at the quarter time / date range
     * selector.
     */

    private static final String  QUARTER_DOMAIN_STATUS =
	RECENT_DOMAIN_STATUS;

    /*
     * Set the domain items used for the month time mean data type and
     * the default domain item.
     */

    private static final String  DEFAULT_MONTH_DOMAIN_ITEM =
	DOMAIN_ONE_DAY_ITEM;

    private static final String []  MONTH_DOMAIN_ITEMS =
    {
	"< 12 Hours >",
	DOMAIN_ONE_DAY_ITEM,
	DOMAIN_FULL_ITEM
    };

    /*
     * Set the corresponding time domain interval values for the month
     * time mean data type.
     */

    private static final long  DEFAULT_MONTH_DOMAIN_TIME =
	DOMAIN_ONE_DAY_TIME;

    private static final long []  MONTH_DOMAIN_TIMES =
    {
	12L * DateFormat.HOURS,
	DOMAIN_ONE_DAY_TIME,
	DOMAIN_FULL_TIME
    };

    /*
     * Set the status message shown at the month time / date range
     * selector.
     */

    private static final String  MONTH_DOMAIN_STATUS =
	RECENT_DOMAIN_STATUS;

    /*
     * Set the labels of the plot buttons who control if all net data
     * are plotted, or only the data for the connection with one host.
     */

    private static final String  SHOW_ALL_LABEL = "Show All"; // All dt.
    private static final String  SHOW_LABEL	= "Show";     // One h.

    /*
     * Set the status messages which are corresponding with these plot
     * buttons.
     */

    private static final String  SHOW_ALL_STATUS =
	"Show all plot traces.";
    private static final String  SHOW_STATUS	 =
	"Show the plot traces from/to";

    /*
     * Set the labels of the plot buttons who control the linear or
     * logarithmic scaling type.
     */

    private static final String  LINEAR_LABEL = "Linear"; // Linear scl.
    private static final String  LOG_LABEL    = "Log";    // Log. scl.

    /*
     * Set the status messages corresponding with the linear
     * logarithmic scaling type.
     */

    private static final String  LINEAR_STATUS =
	"Scale Y-axis linear.";
    private static final String  LOG_STATUS    =
	"Scale Y-axis logarithmic.";

    /*
     * Set the long ping type names.
     */

    private static final String []  LONG_PING_TYPE_NAMES =
    {
	"Minimum",
	"Average",
	"Maximum",
	"All",
	"Percentages Lost"
    };

    /*
     * Set the short ping type names.
     */

    private static final String []  SHORT_PING_TYPE_NAMES =
    {
	"Min",
	"Avg",
	"Max",
	"All",
	"Lost"
    };

    /*
     * Set the ping type units.
     */

    private static final String []  PING_TYPE_UNITS =
    {
	"[ms]",
	"[ms]",
	"[ms]",
	"[ms]",
	"[%]"
    };

    /*
     * Set the long UDP bandwidth type names.
     */

    private static final String []  LONG_UDP_BW_TYPE_NAMES =
    {
	"Receive Data Rate",
	"Percentages Frames Lost"
    };

    /*
     * Set the short UDP bandwidth type names.
     */

    private static final String []  SHORT_UDP_BW_TYPE_NAMES =
    {
	"Data Rate",
	"Frames Lost"
    };

    /*
     * Set the UDP bandwidth type units.
     */

    private static final String []  UDP_BW_TYPE_UNITS =
    {
	"[Mbit/s]",
	"[%]"
    };

    /*
     * Set the initialised tick spacing values.
     */

    private static final int  INIT_X_TICK_SPACING = 100;
    private static final int  INIT_Y_TICK_SPACING =  60;

    /*
     * set the Data_Type ID's used to determine the dates data
     * connected to the type of data read from the dates URL.
     */

    private static final int  NO_DATES_ID     = 0; // No data tpe known.
    private static final int  WEEK_ID	      = 1; // Current week data.
    private static final int  DAY_ID	      = 2; // Data current day.
    private static final int  MEAN_QUARTER_ID = 3; // Calc. quart. mean.
    private static final int  QUARTER_ID      = 4; // Quarter of year d.
    private static final int  MEAN_MONTH_ID   = 5; // Calc. month mean.
    private static final int  MONTH_ID	      = 6; // Month data.

    /*
     * Set the Data_Type ID's used to determine the type of data read
     * from the data URL.
     */

    private static final int  NO_DATA_ID    =  0; // No data type known.
    private static final int  SET_TITLE_ID  =  1; // Hosts set title.
    private static final int  PERIOD_ID	    =  2; // Period betw. dates.
    private static final int  ONE_DIRECT_ID =  3; // One-/two-dir. conn.
    private static final int  FILE_TYPE_ID  =  4; // Data file type.
    private static final int  FILE_ID_ID    =  5; // Data file ID.
    private static final int  USE_QOS_ID    =  6; // Inet & QoS tests.
    private static final int  QOS_TITLE_ID  =  7; // Title QoS tests.
    private static final int  INET_TITLE_ID =  8; // Title Inet tests.
    private static final int  HOST_TITLE_ID =  9; // Host titles.
    private static final int  SKIP_CONN_ID  = 10; // Skip host conn.
    private static final int  WEEK_DATES_ID = 11; // Week dates data.
    private static final int  LOAD_ID       = 12; // Load data.
    private static final int  PING_ID       = 13; // Roundtrip data.
    private static final int  THROUGHPUT_ID = 14; // Throughput data.
    private static final int  USE_UDP_BW_ID = 15; // Use UDP BW data?
    private static final int  UDP_BW_ID     = 16; // UDP bandwidth data.

    /*
     * Set the separator used for the separator between field names and
     * field values.
     */

    private static final String  TYPE_SEPAR	    = ":=";
    private static final char []  TYPE_SEPAR_CHARS  =
	TYPE_SEPAR.toCharArray ();
    private static final int      TYPE_SEPAR_LENGTH =
	TYPE_SEPAR_CHARS.length;

    /*
     * Define the "skipped-connection" string and the
     * "data-value-not-found" string. Note that all data are positive
     * values!
     */

    private static final String  CONNECTION_SKIPPED   = "-10";
    private static final String  DATA_VALUE_NOT_FOUND = "-1";
    
    /*
     * Set the default signal and signal light borders and the name of
     * the parameters to read by the Applet.
     */

    private static final int     DEFAULT_SIGNAL_BORDER = 0;
    private static final int     DEFAULT_LIGHT_BORDER  = 5;
    private static final String  SIGNAL_BORDER_NAME    = "SignalBorder";
    private static final String  LIGHT_BORDER_NAME     = "LightBorder";

    /*
     * Show a status read message after the # data lines specified here.
     */

    private static final int  NR_STATUS_LINES = 100;

    /*
     * Set the blink time used during the loading; the maximum time to
     * wait before a blink is repainted and the minimum required
     * # net data lines to read to show the blinking.
     */

    private static final int  LOAD_BLINK_TIME	 = 500; // ms
    private static final int  BLINK_REPAINT_TIME =  50; // ms
    private static final int  MIN_NR_BLINK_LINES =  50;

    /*
     * Set the time to wait in:
     *
     *   1. The data reading thread when new data should be read.
     *
     *   2. The main thread when the data are read.
     */

    private static final int  READ_DATA_SLEEP_TIME = 200; // ms

    /*
     * Set the (net) data plot type ID's.
     */

    private static final int  NO_PLOT	      = 0;   // Nothing plotted.
    private static final int  LOAD_PLOT	      = 1;   // Load plot.
    private static final int  PING_PLOT	      = 2;   // Roundtrip plot.
    private static final int  THROUGHPUT_PLOT = 3;   // Throughput plot.
    private static final int  UDP_BW_PLOT     = 4;   // UDP BW plot.

    /*
     * Set the constant wich determines if time ticks are rounded
     * at the specified time grid coordinates.
     */

    private static final boolean  ROUND_DATE_GRID = false;

    /**
     * This class instance variable displays the state when the applet
     * has been started for the first time. It is intended to be used
     * from <EM>JavaScript</EM>.
     */

    public String  is_started;

    /*
     * Set the private class instance variables.
     */

    private PlotCanvas	          data_plot;	    // Data plot canvas.
    private DataPlotWindow        data_plot_window; // Window data plot.
    private Signal	          signal;	    // Sig. to show ld.
    private int		          signal_border;    // Border round sig.
    private int		          light_border;     // Border round lgt.
    private Thread		  no_js_fun_thread; // Thd no JS funct.
    private QuitSync		  no_js_fun_quit;   // Quit no JS f. th.
    private BooleanObject	  do_read_data;     // Must read data?
    private BooleanObject	  do_show_plot;	    // Must show plot?
    private String		  dates_file;	    // Name dates file.
    private String		  data_file;	    // Name data file.
    private String		  data_file_base;   // Date file base.
    private NetDataDescriptor []  net_data_descrs;  // Dscr. recent dta.
    private NetDataDescriptor     current_data;	    // Curr. data descr.
    private int			  data_type_index;  // Ind. curr. dta t.
    private Hashtable		  date_id_table;    // Week/day ID tble.
    private boolean		  read_dates;	    // Rd net dta dates.
    private String		  set_title;	    // Hosts set title.
    private String		  period;	    // Date step period.
    private String		  file_type;	    // Data file type.
    private int			  file_id;	    // Data file ID.
    private boolean		  one_direct;	    // One(/Two)-dir. t.
    private boolean	          qos_and_inet;     // Use QoS and Inet.
    private String		  qos_title;	    // QoS title.
    private String		  inet_title;	    // Internet title.
    private ZipInputStream	  url_input;	    // URL input stream.
    private IntObject	          data_line_nr;     // Line # data file.
    private int		          blink_line_nr;    // Blinked dt lne #.
    private StringVector          hosts;	    // Hosts vector.
    private HostTitleTable        host_titles;      // Titles of hosts.
    private GenHostKey		  gen_host_key;	    // To get host keys.
    private SkipConnTable	  skip_conns;	    // Skipped hst conn.
    private DateVector            dates;	    // Sort vect. dates.
    private boolean		  use_udp_bw;	    // Use UDP bandw.?
    private NetDataTable          load_data;	    // Storage load dta.
    private NetDataTable          ping_data;	    // Storage ping dta.
    private NetDataTable          throughput_data;  // Storage tput dta.
    private NetDataTable	  udp_bw_data;	    // Storage UDP BW d.
    private Component []          plot_controls;    // Cntrls plot frme.
    private Component []          load_controls;    // Load plot cntrls.
    private Panel	          domain_panel;     // Date domain pan.
    private GridBagLayout         domain_grid_bag;  // Date d. layout m.
    private ControlButton	  first_button;     // Go to first dt d.
    private ControlButton	  prev_button;      // Go to prev. dt d.
    private ControlButton	  next_button;      // Go to next dt d.
    private ControlButton	  show_button;      // Show all/host tr.
    private ControlChoice	  dom_choice_add;   // Dom. choice add.
    private ControlButton	  scaling_button;   // Y-Axis scl. butt.
    private long	          time_offset;      // Time offset sec.
    private int		          plot_type;	    // Current plot tpe.
    private int		          control_type;     // Current cntrl t.
    private int		          max_date_index;   // Index max. date.
    private int		          min_date_index;   // Index min. date.
    private int		          fixed_host_index; // Fxd host i. n. t.
    private int		          ping_type;	    // Last ping type.
    private int			  udp_bw_type;	    // Last UDP BW type.
    private boolean	          plot_all;	    // Plot'd all net t.
    private PingFormat	          ping;	            // Format ping v's.
    private UDPBWFormat		  udp_bw;	    // Form. UDP BW v's.
    private IntObject		  load_scale;	    // Lin/Log Y-scale
    private IntObject		  ping_scale;	    // for load, ping,
    private IntObject		  throughput_scale; // throughput, UDP
    private IntObject		  udp_bw_scale;	    // bandwidth and in
    private IntObject		  control_scale;    // the control.
    private String []		  one_host_ar;      // Help ar. 1 host.
    private String []		  two_hosts_ar;     // Help ar. 2 hsts.


    /**
     * Initialise the <CODE>NetData</CODE> Applet. The
     * <CODE>init()</CODE> method of the <CODE>PlotApplet</CODE> class
     * is overloaded.
     *
    *******************/
    public void  init ()
    /******************/
    {
	try
	{
	    setBackground   (BACKGROUND); // Set the Applet background.
	    initDataDescr   ();		  // Init. the data descriptors.
	    setParameters   ();		  // Set the Applet HTML param.
	    setParDataDescr ();		  // Set param. depend. data d.
	    initVariables   ();		  // Init. the Applet variables.
	    initDataPlot    ();		  // Init. plot frame & canvas.
	    addComponents   ();		  // Add the components.
	}
	catch (Exception  e)    // Treat exceptions.
	{
	    handleException (e);
	}

    } // init ()


    /**
     * Initialise the net data descriptors. Also set the current net
     * data descriptor.
     *
    *****************************/
    private void  initDataDescr ()
    /****************************/
    {
	/*
	 * Create the hashtable to store the week or day ID's.
	 */

	date_id_table = new Hashtable ();

	/*
	 * Create the array which contains the various net data types.
	 */

	net_data_descrs = new NetDataDescriptor [NR_DATA_TYPES];

	/*
	 * Set the data descriptor of the most recent net data and set
	 * some parameters.
	 */

	NetDataDescriptor  recent_data = new NetDataDescriptor ();

	recent_data.setDateAxisLabel	 (DATE_AXIS_LABEL);
	recent_data.setCurrentDomainTime (DEFAULT_RECENT_DOMAIN_TIME);

	net_data_descrs [RECENT_DATA_INDEX] = recent_data;

	/*
	 * Initialise the week data.
	 */

	NetDataDescriptor  week_data = new NetDataDescriptor ();

	week_data.setDateAxisLabel     (DATE_AXIS_LABEL);
	week_data.setDomains	       (WEEK_DOMAIN_ITEMS,
					WEEK_DOMAIN_TIMES,
					DEFAULT_WEEK_DOMAIN_ITEM,
					WEEK_DOMAIN_STATUS);
	week_data.setCurrentDomainTime (DEFAULT_WEEK_DOMAIN_TIME);
	week_data.setDateVarTable      (new DateVarTable (false));

	net_data_descrs [WEEK_DATA_INDEX] = week_data;

	/*
	 * Initialise the week mean data.
	 */

	NetDataDescriptor  week_mean_data = new NetDataDescriptor ();

	week_mean_data.setTypeTitle	    (WEEK_MEAN_TITLE);
	week_mean_data.setDateAxisLabel     (WEEK_AXIS_LABEL);
	week_mean_data.setDomains	    (
	    WEEK_MEAN_DOMAIN_ITEMS,
	    WEEK_MEAN_DOMAIN_TIMES,
	    DEFAULT_WEEK_MEAN_DOMAIN_ITEM,
	    WEEK_MEAN_DOMAIN_STATUS);
	week_mean_data.setCurrentDomainTime (
	    DEFAULT_WEEK_MEAN_DOMAIN_TIME);
	week_mean_data.setDateIDTable	    (date_id_table);

	net_data_descrs [WEEK_MEAN_DATA_INDEX] = week_mean_data;

	/*
	 * Initialise the day mean data.
	 */

	NetDataDescriptor  day_mean_data = new NetDataDescriptor ();

	day_mean_data.setTypeTitle	   (DAY_MEAN_TITLE);
	day_mean_data.setDateAxisLabel	   (DAY_AXIS_LABEL);
	day_mean_data.setCurrentDomainTime (
	    DEFAULT_DAY_MEAN_DOMAIN_TIME);
	day_mean_data.setDateIDTable	   (date_id_table);

	net_data_descrs [DAY_MEAN_DATA_INDEX] = day_mean_data;

	/*
	 * Initialise the quarter time mean data.
	 */

	NetDataDescriptor  quarter_data = new NetDataDescriptor ();

	quarter_data.setDateAxisLabel	  (DATE_AXIS_LABEL);
	quarter_data.setDomains		  (QUARTER_DOMAIN_ITEMS,
					   QUARTER_DOMAIN_TIMES,
					   DEFAULT_QUARTER_DOMAIN_ITEM,
					   QUARTER_DOMAIN_STATUS);
	quarter_data.setCurrentDomainTime (DEFAULT_QUARTER_DOMAIN_TIME);
	quarter_data.setDateVarTable	  (new DateVarTable (true));

	net_data_descrs [QUARTER_DATA_INDEX] = quarter_data;

	/*
	 * Initialise the month time mean data.
	 */

	NetDataDescriptor  month_data = new NetDataDescriptor ();

	month_data.setDateAxisLabel	(DATE_AXIS_LABEL);
	month_data.setDomains		(MONTH_DOMAIN_ITEMS,
					 MONTH_DOMAIN_TIMES,
					 DEFAULT_MONTH_DOMAIN_ITEM,
					 MONTH_DOMAIN_STATUS);
	month_data.setCurrentDomainTime (DEFAULT_MONTH_DOMAIN_TIME);
	month_data.setDateVarTable	(new DateVarTable (true));

	net_data_descrs [MONTH_DATA_INDEX] = month_data;

	/*
	 * Start the current network data with index of the default data
	 * type. Set therefore the data type index and the current
	 * descriptor.
	 */

	data_type_index = DEFAULT_DATA_INDEX;
	current_data	= net_data_descrs [data_type_index];

    } // initDataDescr ()


    /**
     * Set the parameters which are defined in the HTML page. Use
     * default values when nothing is set in the HTML page.
     *
    *****************************/
    private void  setParameters ()
    /****************************/
    {
	/*
	 * Get the name of the file with the dates.
	 */

	dates_file = getDefaultParameter (DATES_FILE_NAME,
					  DEFAULT_DATES_FILE);

	/*
	 * Set the boolean variable if the net data dates should be
	 * read.
	 */

	read_dates = getDefaultParameter (READ_DATES_NAME,
					  DEFAULT_READ_DATES);

	/*
	 * Get the signal border and light_border;
	 */

	signal_border = getDefaultParameter (SIGNAL_BORDER_NAME,
					     DEFAULT_SIGNAL_BORDER);
	light_border  = getDefaultParameter (LIGHT_BORDER_NAME,
					     DEFAULT_LIGHT_BORDER);

	/*
	 * Get the # recent days. Set variables depending from it.
	 */

	setNrRecentDays (
	    getDefaultParameter (NR_RECENT_DAYS_NAME,
				 MAX_NR_RECENT_DOMAIN_DAYS));

	/*
	 * Get the maximum # days available in the day mean data type.
	 * Set variables depending from it.
	 */

	setNrMeanDays (getDefaultParameter (NR_MEAN_DAYS_NAME,
					    DEFAULT_NR_MEAN_DAYS));

    } // setParameters ()

    /**
     * This function return a string parameter, when the
     * parameter is undefined the default value is returned.
     *
     *    @param  name      The name of the parameter.
     *
     *    @param  dft_val   Its default value;
     *
     *    @return  The parameter value.
     *
    ****************************************************/
    private String  getDefaultParameter (String  name,
					 String  dft_val)
    /***************************************************/
    {
	String  val_str = getParameter (name);

	if (val_str == null)    // Nothing defined: return default.
	    return dft_val;
	else			// Return the value string.
	    return val_str;

    } // getDefaultParameter ()


    /**
     * This function returns the value of an int parameter, when the
     * parameter is undefined or an exception occurs the default value
     * is returned.
     *
     *    @param  name      The name of the parameter.
     *
     *    @param  dft_val   Its default value;
     *
     *    @return  The parameter value.
     *
    *************************************************/
    private int  getDefaultParameter (String  name,
				      int     dft_val)
    /************************************************/
    {
	String  val_str = getParameter (name);

	if (val_str == null)    // Nothing defined: return default.
	{
	    return dft_val;
	}
	else    // Parse the string parameter obtained from the Applet.
	{
	    try
	    {
		return Integer.parseInt (val_str);
	    }
	    catch (NumberFormatException  e_num)
	    {
		return dft_val;
	    }
	}
    
    } // getDefaultParameter ()


    /**
     * This function returns the value of a boolean parameter, when the
     * parameter is undefined or when a bad boolean string is specified
     * the default value is returned.
     *
     *    @param  name      The name of the parameter.
     *
     *    @param  dft_val   Its default value;
     *
     *    @return  The parameter value.
     *
    ******************************************************/
    private boolean  getDefaultParameter (String   name,
					  boolean  dft_val)
    /*****************************************************/
    {
	String  val_str = getParameter (name);

	if (val_str == null)    // Nothing obtained: return default.
	{
	    return dft_val;
	}
	else    // Parse the string parameter obtained from the Applet.
	{
	    if (val_str.equals (TRUE_STR))
		return true;
	    else if (val_str.equals (FALSE_STR))
		return false;
	    else
		return dft_val;
	}
    
    } // getDefaultParameter ()


    /**
     * This function uses the #&nbsp;recent days to set the total
     * #&nbsp;recent domains. It is also used to define the title
     * trailor.
     *
     *    @param  nr_recent_domain_days
     *
    **************************************************/
    private void  setNrRecentDays (int  nr_recent_days)
    /*************************************************/
    {
	/*
	 * Correct a too small value of the # days.
	 */

	if (nr_recent_days < MIN_NR_RECENT_DOMAIN_DAYS)
	    nr_recent_days = MIN_NR_RECENT_DOMAIN_DAYS;

	/*
	 * Set the domain offset by addition of the hour and full domain
	 * items.
	 */

	int  domain_offset = MAX_RECENT_DOMAIN_ITEMS.length -
			     MAX_NR_RECENT_DOMAIN_DAYS;

	/*
	 * Set the recent net data type.
	 */

	NetDataDescriptor  recent_data = net_data_descrs [
					     RECENT_DATA_INDEX];

	/*
	 * Set the # recent domains. The domains are defined in
	 * "setParDataDescr()".
	 */

	recent_data.setMaxNrDomains (nr_recent_days + domain_offset);

	/*
	 * Set the # recent domains in the title trailor.
	 */

	recent_data.setTypeTitle (RECENT_DATA_PREFIX + " " +
				  nr_recent_days + " " +
				  RECENT_DATA_TRAILOR);

    } // setNrRecentDays ()


    /**
     * This function uses the maximum # days available in the day mean
     * data file to set the maximum # domains of the corresponding data
     * type.
     *
     *    @param  nr_mean_days   The maximum # days in the day mean data
     *				 file.
     *
    **********************************************/
    private void  setNrMeanDays (int  nr_mean_days)
    /*********************************************/
    {
	/*
	 * Add a percentage of the # days such that a bit larger domain
	 * time is allowed.
	 */

	nr_mean_days += ((ADD_NR_MEAN_DAYS_PERC * nr_mean_days) / 100);

	/*
	 * Calculate the maximum domain time from maximum # days.
	 */

	long  max_domain_time = (long) nr_mean_days * DateFormat.DAYS;

	/*
	 * Set the maximum domain time. The domains are defined in
	 * "setParDataDescr()".
	 */

	net_data_descrs [DAY_MEAN_DATA_INDEX].setMaxDomainTime (
						  max_domain_time);

    } // setNrMeanDays ()


    /**
     * This function sets the Applet parameter dependent variables in 
     * the net data descriptors.
     *
    *******************************/
    private void  setParDataDescr ()
    /******************************/
    {
	/*
	 * Set the recent and the day mean net data types.
	 */

	NetDataDescriptor  recent_data   = net_data_descrs [
					        RECENT_DATA_INDEX];
	NetDataDescriptor  day_mean_data = net_data_descrs [
					       DAY_MEAN_DATA_INDEX];

	/*
	 * Set the domains for the recent data type, taking into account
	 * the # days read. See "setNrRecentDays()". Also the domain
	 * selector choice of the recent data type is set here.
	 */

	recent_data.setDomains (MAX_RECENT_DOMAIN_ITEMS,
				MAX_RECENT_DOMAIN_TIMES,
				DEFAULT_RECENT_DOMAIN_ITEM,
				RECENT_DOMAIN_STATUS);

	/*
	 * Set the domains for the day mean data type, taking into
	 * account the maximum # days in the data file. See
	 * "setNrMeanDays()". Also the domain select choice of the
	 * recent data type is set here.
	 */

	 day_mean_data.setDomains (MAX_DAY_MEAN_DOMAIN_ITEMS,
				   MAX_DAY_MEAN_DOMAIN_TIMES,
				   DEFAULT_DAY_MEAN_DOMAIN_ITEM,
				   DAY_MEAN_DOMAIN_STATUS);

    } // setParDataDescr ()


    /**
     * This function initialises the class instance variables. Some
     * applet parameters are required for the constructors in this
     * method.
     *
    *****************************/
    private void  initVariables ()
    /****************************/
    {
	/*
	 * Initialise the public class instance which shows the state
	 * when this Applet has been started for the first time. The
	 * "start()" method has not yet been called, so th e current
	 * state is "false".
	 */

	is_started = FALSE_STR;

	/*
	 * When dates are being read, the data file is not privately
	 * imported and selected and can therefore be read as soon as
	 * the Applet is started.
	 */

	boolean  init_read_data = read_dates;

	/*
	 * Initialise some private class variables.
	 */

	url_input	 = null;    // Input not yet open.

	signal		 = new Signal (Signal.WAIT_COLOR,
				       this,
				       LOAD_BLINK_TIME,
				       signal_border,
				       light_border);

	data_file	 = DEFAULT_DATA_FILE;
	data_file_base	 = StringTools.getBasename (DEFAULT_DATA_FILE);
	no_js_fun_thread = new Thread		   (this);
	no_js_fun_quit	 = new QuitSync		   ();
	do_read_data	 = new BooleanObject	   (init_read_data);
	do_show_plot	 = new BooleanObject	   (false);
	data_line_nr	 = new IntObject	   (0);
	blink_line_nr	 = -1;
	hosts		 = new StringVector	   ();
	host_titles	 = new HostTitleTable	   ();
	gen_host_key	 = new GenHostKey	   ();
	skip_conns	 = new SkipConnTable	   (gen_host_key);
	dates		 = new DateVector	   ();
	load_data	 = new NetDataTable	   (1, gen_host_key);
	ping_data	 = new NetDataTable	   (2, gen_host_key);
	throughput_data  = new NetDataTable	   (2, gen_host_key);
	udp_bw_data	 = new NetDataTable	   (2, gen_host_key);
	ping		 = new PingFormat	   ();
	udp_bw		 = new UDPBWFormat	   ();
	plot_type	 = NO_PLOT;    // Default no plot.
	control_type	 = NO_PLOT;    // No plot for control.
	max_date_index	 = -1;
	min_date_index	 = 0;
	fixed_host_index = 0;
	ping_type	 = 0;
	udp_bw_type	 = 0;
	plot_all	 = false;
	load_scale	 = new IntObject (PlotCanvas.LINEAR);
	ping_scale	 = new IntObject (PlotCanvas.LINEAR);
	throughput_scale = new IntObject (PlotCanvas.LINEAR);
	udp_bw_scale	 = new IntObject (PlotCanvas.LINEAR);
	control_scale	 = null;
	one_host_ar	 = new String [1];   // Buffer one host data.
	two_hosts_ar	 = new String [2];   // Buffer two hosts data.

	/*
	 * Set some net data file dependent parameters to their default
	 * values.
	 */

	set_title    = DEFAULT_SET_TITLE;
	period	     = DEFAULT_PERIOD;
	file_type    = DEFAULT_FILE_TYPE;
	file_id	     = DEFAULT_FILE_ID;
	one_direct   = DEFAULT_ONE_DIRECT;
	qos_and_inet = DEFAULT_QOS_AND_INET;
	qos_title    = DEFAULT_QOS_TITLE;
	inet_title   = DEFAULT_INET_TITLE;
	use_udp_bw   = DEFAULT_USE_UDP_BW;

    } // initVariables ()


    /**
     * This function initialises the data plot
     * <CODE>Canvas</CODE>&nbsp;&amp; <CODE>Frame</CODE>. The data plot
     * canvas also obtains its parameters from the super
     * <CODE>init()</CODE> method of this <CODE>Applet</CODE>.
     *
     *     @exception  Exception   Thrown after reading bad
     *				   <CODE>Applet</CODE> parameters.
     *
    ***********************************************/
    private void  initDataPlot ()  throws  Exception
    /**********************************************/
    {
	/*
	 * Create the plot canvas and window.
	 */

	data_plot	 = new PlotCanvas     ();
	data_plot_window = new DataPlotWindow (data_plot);

	/*
	 * Set the initialised X and Y tick spacing.
	 */

	data_plot.setXTickSpacing (INIT_X_TICK_SPACING);
	data_plot.setYTickSpacing (INIT_Y_TICK_SPACING);

	/*
	 * Call the super "init()" method. This method is a.o. used to
	 * read the standard Applet parameters of the plot.
	 */

	super.init (data_plot);

	/*
	 * Set the plot window frame parameters which are depending from
	 * the Applet parameters.
	 */

	setPlotWindowParameters ();

	data_plot_window.setRoundDateGrid (ROUND_DATE_GRID);

	/*
	 * Set the default trace colors and markers when they are not
	 * defined by the Applet parameters.
	 */

	if (data_plot.getNrTraceColors () == 0)
	    setDefaultPlotTraceColors ();

	if (data_plot.getNrMarkers () == 0)
	    setDefaultPlotMarkers ();

	/*
	 * Set the domain choices status message handler. The data plot
	 * frame is used for all control choices.
	 */

	setDomainChoicesStatusHandler ();

	/*
	 * Set our plot window frame controls. They are added after the
	 * default plot window frame controls.
	 */
	 
	setPlotWindowControls ();

    } // initDataPlot ()


    /**
     * Read the plot window frame parameters from the Applet.
     *
     *    @exception  Exception   Thrown after bad parsing of the Applet
     *				  parameters.
     *
    **********************************************************/
    private void  setPlotWindowParameters ()  throws  Exception
    /*********************************************************/
    {
	/*
	 * Read the green inensity boundary.
	 */

	String  green_white_fgnd_bnd_str;

	green_white_fgnd_bnd_str = getParameter (
				       GREEN_WHITE_FGND_BND_NAME);

	if (green_white_fgnd_bnd_str != null)  // Parse the param. read.
	{
	    data_plot_window.setGreenWhiteFgndBnd (
		Integer.parseInt (green_white_fgnd_bnd_str));
	}

	/*
	 * Read the legend background of the plot traces not shown.
	 */

	String  no_plot_legend_bgnd_str;

	no_plot_legend_bgnd_str = getParameter (
				      NO_PLOT_LEGEND_BGND_NAME);

	if (no_plot_legend_bgnd_str != null)   // Parse the param. read.
	{
	    data_plot_window.setNoPlotLegendBgnd (
		parseColor (no_plot_legend_bgnd_str));
	}

	/*
	 * Read the legend foreground of the plot traces not shown.
	 */

	String  no_plot_legend_fgnd_str;

	no_plot_legend_fgnd_str = getParameter (
				      NO_PLOT_LEGEND_FGND_NAME);

	if (no_plot_legend_fgnd_str != null)   // Parse the param. read.
	{
	    data_plot_window.setNoPlotLegendFgnd (
		parseColor (no_plot_legend_fgnd_str));
	}
    
    } // setPlotWindowParameters ()


    /**
     * Set the default trace colors. They are a static array in the
     * <CODE>DataPlotWindow</CODE> class.
     *
    *****************************************/
    private void  setDefaultPlotTraceColors ()
    /****************************************/
    {
	Color []  trace_colors	  = DataPlotWindow.TRACE_COLORS;
	int	  nr_trace_colors = trace_colors.length;

	for (int index = 0;  index < nr_trace_colors;  index++)
	    data_plot.addTraceColor (trace_colors [index]);
    
    } // setDefaultPlotTraceColors ()


    /**
     * Set the default plot markers. All markers from the
     * <CODE>user.plot</CODE> package are used.
     *
    *************************************/
    private void  setDefaultPlotMarkers ()
    /************************************/
    {
	data_plot.addAllMarkers ();
    }


    /**
     * Set the domain choices status message handler. The data plot
     * window is used as status handler.
     *
    *********************************************/
    private void  setDomainChoicesStatusHandler ()
    /********************************************/
    {
	for (int index = 0;  index < NR_DATA_TYPES;  index++)
	{
	    ControlChoice  domain_choice =
		net_data_descrs [index].getDomainChoice ();
	    
	    domain_choice.setStatusHandler (data_plot_window);
	}
    }


    /**
     * Set out plot window frame controls. They will be added after the
     * default plot window frame controls.
     *
    *************************************/
    private void  setPlotWindowControls ()
    /************************************/
    {
	/*
	 * Inquire the domain choice from the current net data.
	 */

	ControlChoice  domain_choice = current_data.getDomainChoice ();

	/*
	 * Create the button used as the following switch: to show all
	 * data from a network type / show only this type of data with
	 * a specified host.
	 */

	show_button = new ControlButton (data_plot_window,
					 SHOW_ALL_LABEL,
					 SHOW_ALL_STATUS);

	/*
	 * Create the button used to switch between linear and
	 * logarithmic Y-axis scaling.
	 */

	scaling_button = new ControlButton (data_plot_window,
					    LOG_LABEL,
					    LOG_STATUS);

	/*
	 * Create the domain controls. The domain choice, connected to
	 * the current net data was already created during the
	 * definition of the net data.
	 */

	first_button = new ControlButton (data_plot_window,
					  TO_FIRST_LABEL,
					  TO_FIRST_STATUS);
	prev_button  = new ControlButton (data_plot_window,
					  TO_PREV_LABEL,
					  TO_PREV_STATUS);
	next_button  = new ControlButton (data_plot_window,
					  TO_NEXT_LABEL,
					  TO_NEXT_STATUS);

	/*
	 * Create the domain panel and add the controls to it. Note that
	 * a grid bag layout is used for the domain control. Reason:
	 * Internet Explorer 4.0 has problems to paint the domain
	 * choice.
	 */

	domain_panel	= new Panel	    ();
	domain_grid_bag = new GridBagLayout ();

	domain_panel.setLayout (domain_grid_bag);

	addToDomainPanel (first_button, false); // Go to first time dom.
	addToDomainPanel (prev_button, true);	// Go to prev. time dom.
	addToDomainPanel (next_button, true);   // Go to next  time dom.

	addDomainChoiceToDomainPanel (domain_choice);  // Sel. time dom.

	/*
	 * Set the controls in an array used by the "DataPlotWindow"
	 * class for the ping and throughput plots ...
	 */

	plot_controls = new Component [NR_CONTROLS];

	plot_controls [SHOW_BUTTON_INDEX   ] = show_button;
	plot_controls [SCALING_BUTTON_INDEX] = scaling_button;
	plot_controls [DOMAIN_PANEL_INDEX  ] = domain_panel;

	/*
	 * ... and also for the load plot.
	 */

	load_controls = new Component [NR_LOAD_CONTROLS];

	load_controls [DOMAIN_PANEL_LOAD_INDEX] = domain_panel;

	/*
	 * Set this clas instance as the extern control handler.
	 */

	data_plot_window.setExternPlotControls (this);
	
	
    } // setPlotWindowControls ()


    /**
     * Add the specified domain choice to the domain panel. Store the
     * added choice.
     *
     *    @param  domain_choice   The choice to add.
     *
    **********************************************/
    private void  addDomainChoiceToDomainPanel (
		      ControlChoice  domain_choice)
    /*********************************************/
    {
	addToDomainPanel (domain_choice, true);

	/*
	 * Store the added choice to be able to replace it when a new
	 * net data type is loaded.
	 */

	dom_choice_add = domain_choice;

	// domain_choice.validate ();
    }


    /**
     * Add a time domain component to the domain panel.
     *
     *    @param  domain_component   The domain component to add.
     *
     *    @param  use_left_border    <CODE>true</CODE> add left border;
     *				     <CODE>false</CODE> otherwise.
     *
    ***********************************************************/
    private void  addToDomainPanel (Component  domain_component,
    				    boolean    use_left_border)
    /**********************************************************/
    {
	/*
	 * Create new constraints for the domain panel.
	 */

	GridBagConstraints  constraints = new GridBagConstraints ();

	/*
	 * Set the constraints fields for this domain panel component.
	 * The components are placed at a row with the specified
	 * horizontal gap, specified at the left border, when
	 * specified.
	 */

	int  left_border;

	if (use_left_border)
	    left_border = DOMAIN_CONTROL_BORDER;
	else
	    left_border = 0;

	constraints.gridy  = 0;
	constraints.insets = new Insets (0, left_border, 0, 0);

	/*
	 * Set the domain component constraints and add the domain
	 * component.
	 */

	domain_grid_bag.setConstraints (domain_component, constraints);
	domain_panel.add	       (domain_component);

    } // addToDomainPanel ()


    /**
     * Add the components used in the browser to this Applet. This is
     * the Signal Canvas in a BorderLayout.
     *
    *****************************/
    private void  addComponents ()
    /****************************/
    {
	setLayout (new BorderLayout (0, 0));

	add ("Center", signal);
    }


    /**
     * Overload the <CODE>start()</CODE> method of the
     * <CODE>PlotApplet</CODE> class to:
     *
     * <OL>
     *
     * <LI>Call <CODE>super.start()</CODE>.</LI>
     *
     * <LI>Call the <CODE>start()</CODE> method of the
     *	   <CODE>Signal</CODE> class instance which is used to handle
     *	   the signal blink thread.</LI>
     *
     * <LI>Call the <CODE>start()</CODE> method of the thread which is
     *     used for functions that could not be called from
     *     <EM>JavaScript</EM> for some browsers when this thread is not
     *     running. Otherwise the <CODE>resume()</CODE> will be called,
     *     because it has been suspended by another <CODE>stop()</CODE>
     *     call of this Applet.</LI>
     *
     * <LI>Mark that this Applet has been started for the first
     *	   time.</LI>
     *
     * </OL>
     *
     *    @see  user.signal.Signal#start
     *	  @see  NetData#stop
     *    @see  NetData#destroy
     *
    ********************/
    public void  start ()
    /*******************/
    {
	/*
	 * Start or continue the blink thread of the signal.
	 */
	 
	signal.start ();

	/*
	 * Resume the thread for the functions that could not be run
	 * from JavaScript when it is alive. Start it when it is not
	 * alive.
	 */

	if (no_js_fun_thread.isAlive ())
	    no_js_fun_thread.resume ();
	else
	    no_js_fun_thread.start ();

	is_started = TRUE_STR;    // The Applet has been started.

    } // start ()


    /**
     * Overload the <CODE>stop()</CODE> method of the
     * <CODE>PlotApplet</CODE> class. This is done to:
     *
     * <OL>
     *
     * <LI>Call the <CODE>stop()</CODE> method of the
     *	   <CODE>Signal</CODE> class instance which is used to handle
     *	   the signal blink thread.</Li>
     *
     * <LI>Call the <CODE>suspend()</CODE> method of the thread which is
     *	   used to run commands that could not be run (for some
     *	   browsers) from <EM>JavaScript</EM>. The thread may be resumed
     *	   by another call of the <CODE>start()</CODE> method.</LI>
     *
     * <LI>Dispose an existing plot frame.</LI>
     *
     * </OL>
     *
     *    @see  user.signal.Signal#stop
     *	  @see  NetData#start
     *    @see  NetData#destroy
     *
    *******************/
    public void  stop ()
    /******************/
    {
	/*
	 * Call the "stop()" method of the "Signal" class instance to
	 * handle the blink thread.
	 */

	signal.stop ();

	/*
	 * Call the "suspend()" method of the thread which is used to
	 * run functions that could not be run (for all browsers) from 
	 * JavaScript, but only when it is alive.
	 */

	if (no_js_fun_thread.isAlive ())
	    no_js_fun_thread.suspend ();

	/*
	 * Remove a possible plot window frame.
	 */

	data_plot_window.disposePlot ();

    } // stop ()


    /**
     * Overload the <CODE>destroy()</CODE> method of the
     * <CODE>PlotApplet</CODE> class. This is done to:
     *
     * <OL>
     *
     * <LI>Call the <CODE>destroy()</CODE> method of the
     *	   <CODE>Signal</CODE> class instance which is used to handle
     *	   the signal blink thread.</LI>
     *
     * <LI>Quit the thread which is used for commands that could not be
     *	   run (for all browsers) from JavaScript.</LI>
     *
     * <OL/>
     *
     *    @see  user.signal.Signal#destroy
     *    @see  NetData#start
     *    @see  NetData#stop
     *
    **********************/
    public void  destroy ()
    /*********************/
    {
	/*
	 * Call the "destroy()" method of the "Signal" class instance to
	 * handle the blink thread.
	 */

	signal.destroy ();

	/*
	 * Quit the thread which is used to run functions that could not
	 * be run (for all browsers) from JavaScript,  but only when it
	 * is alive.
	 */

	if (no_js_fun_thread.isAlive ())    // Read no JS runction
	{				    // thread is running.
	    /*
	     * Mark the no JavaScript functions thread to quit and
	     * resume this thread which has been suspended by a previous
	     * call of the "stop()" method. This allows the thread to
	     * die.
	     */

	    no_js_fun_quit.set	    ();   // Mark the thread to quit.
	    no_js_fun_thread.resume ();   // Resume the no JS func. thd.
	}

    } // destroy ()


    /**
     * Get the title of the hosts set. A new <CODE>String</CODE> object
     * is returned.
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @return  The title of the hosts set.
     *
    ****************************/
    public String  getSetTitle ()
    /***************************/
    {
	return new String (set_title);
    }


    /**
     * Get the period [m] between two dates. it is returned as a new
     * <CODE>String</CODE> object.
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @return  The period between two dates. It is returned as
     *		   string.
     *
    **************************/
    public String  getPeriod ()
    /*************************/
    {
	return new String (period);
    }


    /**
     * Return if one-directional or two-directional connections are
     * used. The Boolean flag is returned as a new <CODE>String</CODE>
     * object.
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @return  When one-directional connections are used
     *		   <CODE>true</CODE> is returned; <CODE>false</CODE>
     *		   otherwise. Both values will be returned as string.
     *
    *****************************/
    public String  getOneDirect ()
    /****************************/
    {
	if (one_direct)
	    return new String (TRUE_STR);
	else
	    return new String (FALSE_STR);
    }


    /**
     * Return if besides tests over the &quot;usual&quot; Internet
     * connction also tests over Quality-of-Service connections should
     * be performed. The Boolean flag is returned as a new
     * <CODE>String</CODE> object.
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @return   When also Quality-of-Service tests should be
     *		    performed <CODE>true</CODE> is returned;
     *		    <CODE>false</CODE> otherwise. Both values will be
     *		    returned as string.
     *
    ******************************/
    public String  getQoSAndInet ()
    /*****************************/
    {
	if (qos_and_inet)
	    return new String (TRUE_STR);
	else
	    return new String (FALSE_STR);
    }


    /**
     * Get the title of the Quality-of-Service network performance
     * tests. It is returned as a new <CODE>String</CODE> object.
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @return   The title of the Quality-of-Service tests.
     *
    ****************************/
    public String  getQoSTitle ()
    /***************************/
    {
	return new String (qos_title);
    }


    /**
     * Get the title of the network performance tests along the
     * &quot;usual&quot; Internet route. It is returned as a new
     * <CODE>String</CODE> object.
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @return   The title of the tests along the Internet route.
     *
    ****************************/
    public String getInetTitle ()
    /***************************/
    {
	return new String (inet_title);
    }


    /**
     * Return if UDP bandwidth measurements should be performed. The
     * Boolean flag is returned as a new <CODE>String</CODE> object.
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @return   When also UDP bandwidth tests should be performed
     *		    <CODE>true</CODE> is returned; <CODE>false</CODE>
     *		    otherwise. Both values will be returned as string.
     *
    ****************************/
    public String  getUseUDPBW ()
    /***************************/
    {
	if (use_udp_bw)
	    return new String (TRUE_STR);
	else
	    return new String (FALSE_STR);
    }


    /**
     * Return the #&nbsp;dates for which select date data files are
     * available. When no dates are available the string value of zero
     * is returned. It is returned as a new <CODE>String</CODE> object.
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @param  type_index_str   The index of the date type to obtain
     *				   the # selected dates from, specified
     *				   as string.
     *
     *    @return  The #&nbsp;select dates.
     *
    *******************************************************/
    public String  getNrSelectDates (String  type_index_str)
    /******************************************************/
    {
	try    // Parse the data type index from the specified string.
	{
	    int  type_index = Integer.parseInt (type_index_str);
	    
	    DateVarTable  date_vars =
		net_data_descrs [type_index].getDateVarTable ();

	    if (date_vars == null)
		return new String ("0");
	    else
		return Integer.toString (date_vars.size ());
	}
	catch (NumberFormatException  e_num) // Type index is no number.
	{
	    showDiagnostics (e_num);

	    return new String ("0");
	}
    }


    /**
     * Return the date of the day, representing the date interval, with
     * the specified index from the data type with the specified index.
     * It is returned as a new <CODE>String</CODE> object.
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @param  type_index_str   The index of the data type to use.
     *
     *    @param  index_str	   The index of the date day to get,
     *				   specified as string.
     *
     *    @return  The date of the day at the specified index.
     *
    *************************************************/
    public String  getDateDay (String  type_index_str,
			       String  index_str)
    /************************************************/
    {
	try    // Parse indices from the specified strings.
	{
	    int  type_index = Integer.parseInt (type_index_str);
	    int  index	    = Integer.parseInt (index_str);

	    DateVarTable  date_vars =
		net_data_descrs [type_index].getDateVarTable ();

	    if (date_vars == null)
		return new String ("");
	    else
		return new String (date_vars.getDate (index));
	}
	catch (NumberFormatException  e_num)   // An index is no number.
	{
	    showDiagnostics (e_num);

	    return new String ("");
	}

    } // getDateDay ()


    /**
     * Return the date ID of the date interval with the specified index
     * from the data type with the specified index. It is returned as a
     * new <CODE>String</CODE> object.
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @param  type_index_str   The index of the data type to use.
     *
     *    @param  index_str	   The index of the date ID to get,
     *				   specified as string.
     *
     *    @return  The date ID at the specified index.
     *
    ************************************************/
    public String  getDateID (String  type_index_str,
			      String  index_str)
    /***********************************************/
    {
	try    // Parse indices from the specified strings.
	{
	    int  type_index = Integer.parseInt (type_index_str);
	    int  index	    = Integer.parseInt (index_str);

	    DateVarTable  date_vars =
		net_data_descrs [type_index].getDateVarTable ();

	    if (date_vars == null)
		return new String ("");
	    else
		return new String (date_vars.getID (index));
	}
	catch (NumberFormatException  e_num)   // An index is no number.
	{
	    showDiagnostics (e_num);

	    return new String ("");
	}

    } // getDateID ()


    /**
     * Set the net data, but only when curently no data are being read.
     * First the net data storage is cleared. After the clearing of the
     * memory the net data read thread is requested to read the net data
     * file. This method will wait until the net data are read which is
     * also the only functionality when net data are being read at the
     * moment.
     * </P>
     *
     * <P>
     * The reading of the net data is a.o. stopped when an
     * <CODE>URL</CODE> I/O Exception occurs. The  exception message is
     * displayed in the browser bar and in the JAVA Console.
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @param  data_file   The data file to read the data from.
     *
    ******************************************/
    public void  setNetData (String  data_file)
    /*****************************************/
    {
	/*
	 * Request the thread to read the data from the data file when
	 * they are not yet being read. Otherwise the setting of the
	 * data file and the request to the thread are ignored. The
	 * setting of the variables is synchronised with the data read
	 * thread.
	 */

	synchronized (do_read_data)   // Synchronise with read thread.
	{
	    /*
	     * Do not set the data file and read the data when data are
	     * being read at the moment or have to be read.
	     */

	    if (!do_read_data.value)    // Data are now not read.
	    {
		/*
		 * Set the data file to read the data from. Convert any
		 * '\\' to '/'. Therefore the original file is copied to
		 * a new file instance. Also set the basename of the
		 * data file
		 */

		this.data_file = new String (data_file).replace ('\\',
								 '/');

		this.data_file_base = StringTools.getBasename (
					  this.data_file);

		/*
		 * Request the net data read thread to read and set the
		 * data.
		 */

		do_read_data.value = true;

	    } // Data are now not being read.

	} // Synchronise with the net data read thread.

	/*
	 * Wait for the net data to be read by the thread.
	 */

    } // setNetData ()


    /**
     * Return if at the moment the net data thread is reading data. This
     * Boolean flag will be returned as a new <CODE>String</CODE>
     * object.
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @return  When net data are being read at the moment
     *		   <CODE>true</CODE> is returned; <CODE>false</CODE>
     *		   otherwise. Both values will be returned as a string.
     *
    ***************************/
    public String  doReadData ()
    /**************************/
    {
	boolean curr_do_read_data;

	/*
	 * Check synchronised with the read thread if there are net data
	 * being read at the moment.
	 */

	synchronized (do_read_data)
	{
	    curr_do_read_data = do_read_data.value;
	}

	if (curr_do_read_data)
	    return new String (TRUE_STR);
	else
	    return new String (FALSE_STR);

    } // doReadDate ()


    /**
     * Implements the run method of the thread for the functions that
     * could not run (for some browsers) under <EM>JavaScript</EM>. This
     * implies the following functionality:
     *
     * <UL>
     *
     * <LI>Reading the net data from the corresponding data file, when
     *	   needed. When the data where read, or an execption did occur
     *	   which stopped the data reading the state flag is marked
     *	   corresposingly.</LI>
     *
     * <LI>Show the plot window.</LI>
     *
     * </UL>
     *
     * Jump from this method when a <CODE>QuitException</CODE> has been
     * thrown.
     *
    ******************/
    public void  run ()
    /*****************/
    {
	/*
	 * Catch the Quit Exception which will be thrown when the thread
	 * for functions that cannot be called from JavaScript should
	 * stop. This is for instance the case when the Applet will be
	 * destroyed).
	 */

	try
	{
	    for (;;)   // Check and execute the non JavaScript fucntions
	    {	       // forever until quit.
		/*
		 * Set, synchronised with the main thread in help
		 * variables, the current state of the flags that show
		 * if:
		 *
		 *   1. The net data should be yes/no read. This
		 *	variable is reset to its default value after the
		 *	net data are read: the current reading state can
		 *	be queried.
		 *
		 *   2. The plot window should be yes/no showed. This
		 *	variable is immediately restored to its default
		 *	value.
		 */

		boolean  curr_do_read_data;

		synchronized (do_read_data)   // Must read the net data?
		{
		    curr_do_read_data = do_read_data.value;
		}

		boolean  curr_do_show_plot;

		synchronized (do_show_plot)    // Must show the plot?
		{
		    curr_do_show_plot  = do_show_plot.value;
		    do_show_plot.value = false;		      // Reset.
		}

		/*
		 * Check the non JavaScript functions that should be
		 * handled by this thread.
		 */

		if (curr_do_read_data)    // Data have to be read.
		{
		    /*
		     * Read and set the net data. Mark, synchronised
		     * with the main thread, that the data are being
		     * read, when finished or when an (non-quit)
		     * exception did occur.
		     */

		    setNetDataFromThread ();

		    synchronized (do_read_data)      // Data are being
		    {				     // read or an (non-
			do_read_data.value = false;  // quit) exception
		    }				     // did occur.
		}
		else if (curr_do_show_plot)    // The plot window should
		{			       // be shown.
		    /*
		     * Show the plot window. Do it synchronised with the
		     * data plot window class instance such that the
		     * settings from this class instance cannot be
		     * changed during the showing of the plot. When the
		     * plot frame is showed with the "shown()" function,
		     * the "synchronized" block will be left.
		     */

		    synchronized (data_plot_window)
		    {
			data_plot_window.showPlot ();
		    }
		}
		else    // No data have to be read.
		{
		    /*
		     * Check here if the non JavaScript functions thread
		     * should quit when there are no data to read.
		     */

		    no_js_fun_quit.checkThrow ();
		}

		/*
		 * Pause a while for the next check if there non
		 * JavaScript functions to execute.
		 */

		try
		{
		    Thread.sleep (READ_DATA_SLEEP_TIME);
		}
		catch (InterruptedException e_intr)
		{
		}

	    } // Check and execute the non Javascript functions forever
	      // until quit from thread.
	}
	catch (QuitException  quit_except)    // Stop the thread when a
	{				      // quit exception has been
	}				      // selected.

    } // run ()


    /**
     * Set the net data. First the net data storage is cleared. This
     * method will be called from the thread that runs functions that
     * cannot be called from <EM>JavaScript</EM> for some browsers.
     * </P>
     *
     * <P>
     * The reading of the net data is stopped when an <CODE>URL</CODE>
     * I/O Exception occurs. The  exception message is displayed in the
     * browser bar and in the JAVA Console.
     * </P>
     *
     * <P>
     * However, the catched <CODE>QuitException</CODE>, thrown when the
     * net data read thread should quit will be re-thrown to the calling
     * function.
     *
     *    @exception  QuitException   Thrown when the net data read
     *				      thread should quit.
     *
    ***********************************************************/
    private void  setNetDataFromThread ()  throws  QuitException
    /**********************************************************/
    {
	try    // Quit, URL I/O Exceptions.
	{
	    /*
	     * Close the URL input when it is open. Hereafter it will be
	     * reopened for rereading the file.
	     */

	    if (url_input != null)
		closeURLInputData ();

	    /*
	     * Show that the net data have to be reloaded.
	     */

	    signal.setLightColor (Signal.WAIT_COLOR);

	    clearNetData ();    // Clear the net data storage.
	    readNetData  ();    // (Re)read the net data.
	}
	catch (QuitException  quit_except)   // Re-throw Quit Exceptions
	{				     // to the calling method.
	    throw quit_except;
	}
	catch (Exception  e)    // Handle URL I/O Exceptions.
	{
	    handleException (e);
	}

    } // setNetDataFromThread ()


    /**
     * This function handles an exception. The execption is displayed in
     * the browser bar and in the JAVA console. The <CODE>URL</CODE>
     * input is closed when it is open.
     *
     *    @param  e   The exception to handle.
     *
    *******************************************/
    private void  handleException (Exception  e)
    /******************************************/
    {
	/*
	 * Stop the signal blinking.
	 */

	signal.setBlinking (false);

	/*
	 * Show the exception also at the signal.
	 */

	signal.setLightColor (Signal.WAIT_COLOR);

	/*
	 * Display the exception in the browser bar and in the JAVA
	 * console.
	 */

	showDiagnostics (e);

	/*
	 * Close the URL input when it is still open after an
	 * exception. New exceptions are ignored.
	 */

	if (url_input != null)    // The URL input is still open.
	{
	    try
	    {
		closeURLInputData ();
	    }
	    catch (Exception  e_url_input)
	    {
	    }
	}

	/*
	 * Reset the (load blinking) data net line #.
	 */

	data_line_nr.value = 0;
	blink_line_nr	   = -1;

    } // handleException ()


    /**
     * Clear all net data vectors and tables.
     *
    ***************************/
    private void clearNetData ()
    /**************************/
    {
	clearDataDescr		();
	date_id_table.clear	();
	hosts.removeAllElements ();
	host_titles.clear	();
	skip_conns.clear	();
	dates.clear	        ();
	load_data.clear	        ();
	ping_data.clear	        ();
	throughput_data.clear   ();
	udp_bw_data.clear	();

    } // clearNetData ()

    /**
     * Clear the tables used at the net data descriptors.
     *
    ******************************/
    private void  clearDataDescr ()
    /*****************************/
    {
	DateVarTable  date_vars;

	/*
	 * Clear all existing date variable tables.
	 */

	for (int i = 0;  i < NR_DATA_TYPES;  i++)
	{
	    date_vars = net_data_descrs [i].getDateVarTable ();

	    if (date_vars != null)
		date_vars.clear ();
	}
    }


    /**
     * Read the net data values from the various data files. Read the
     * net data dates before the values, when selected.
     *
     *    @exception  Exception   An exception is thrown when the net
     *				  data read thread should quit or at an
     *				  URL I/O error.
     *
     *    @see  NetData#readDates
     *    @see  NetData#readNetTypeData
     *
    **********************************************/
    private void  readNetData ()  throws  Exception
    /*********************************************/
    {
	if (read_dates)      // Read the dates used by the net types,
	    readDates ();    // when selected.
	    
	readNetTypeData ();    // Read the net type data.
    }


    /**
     * Read the dates used by the net types from the data file. They
     * are stored in a data table. A new date data type in the dates
     * file is preceeded from a line
     *
     * <CENTER>
     *
     * <CODE>Data_Type := <VAR>Data_Tye</VAR></CODE>
     *
     * </CENTER>
     *
     *    @exception  Exception   An exception is thrown when the net
     *				  data read thread should quit or at an
     *				  URL I/O error.
     *
     *    @see  NetData#readNetData
     *	  @see  NetData#readNetTypeData
     *
    ********************************************/
    private void  readDates ()  throws  Exception
    /*******************************************/
    {
	String []  data_type_words = new String [2];

	String	dates_file_base = StringTools.getBasename (dates_file);

	int	       type_id  = NO_DATES_ID;
	CharInputLine  url_line;
	String	       type_name;
	int	       separ_index;
	boolean	       first_net_data_exception = true;

	/*
	 * Show that the dates must be loaded.
	 */

	signal.setLightColor (Signal.WAIT_COLOR);

	/*
	 * Open the URL input stream and show the status.
	 */

	showStatus ("Opening dates file: " + dates_file);

	openURLInputData (dates_file);

	/*
	 * Show the alert signal to show that we are loading input.
	 */

	signal.setLightColor (Signal.ALERT_COLOR);

	/*
	 * Show status reading dates.
	 */

	showStatus ("Reading dates file: " + dates_file);

	/*
	 * Start the signal blinking during the loading of the dates.
	 */

	signal.setBlinking (true);

	/*
	 * Allocate the class instance which contains the current input
	 * line character array.
	 */

	url_line = new CharInputLine ();

	/*
	 * Read all lines from the URL and parse these lines.
	 */

	while (url_line.read (url_input))
	{
	    try  // Ignore NetDataException's. Try to continue reading.
	    {
		/*
		 * Increment the line # read. It is used in the load
		 * blink thread to show the load state and it is shown
		 * in execption messages. Check also here if the net
		 * data read thread should quit.
		 */

		synchronized (data_line_nr)
		{
		    if (++data_line_nr.value % NR_STATUS_LINES == 0)
		    {
			showStatus (dates_file_base + ": " +
				    data_line_nr.value + " lines");

			no_js_fun_quit.checkThrow ();
		    }
		}

		if (url_line.startsWith (DATA_TYPE_NAME_CHARS))
		{
		    /*
		     * Get the index of the input type separation string
		     * when an input line is found which is intended to
		     * change the net data dates type.
		     */

		    separ_index = url_line.indexOf (TYPE_SEPAR_CHARS);

		    /*
		     * Throw a net data format exception when no
		     * separation string could be found.
		     */

		    if (separ_index == -1)
		    {
			throw new NetDataException (
				      "No data type separator '" +
				      TYPE_SEPAR + "' found in type " +
				      "string: '" + url_line + "'");
		    }

		    /*
		     * Read the name of the data type (remove spaces
		     * from boths ends of the string) and analyse the
		     * data type.
		     */

		    type_name = url_line.toSubstring (
				    separ_index +
				    TYPE_SEPAR_LENGTH).trim ();

		    if (type_name.equals (WEEK_NAME))    // Week type.
		    {
			type_id = WEEK_ID;
		    }
		    else if (type_name.equals (DAY_NAME))    // Day
		    {					     // type.
			type_id = DAY_ID;
		    }
		    else if (type_name.equals (MEAN_QUARTER_NAME))
		    {
			type_id = MEAN_QUARTER_ID; // Calc. quart. mean.
		    }
		    else if (type_name.equals (QUARTER_NAME)) // Quarter
		    {					      // data.
			type_id = QUARTER_ID;
		    }
		    else if (type_name.equals (MEAN_MONTH_NAME))
		    {	
			type_id = MEAN_MONTH_ID;    // Calc. month mean.
		    }
		    else if (type_name.equals (MONTH_NAME))    // Month
		    {					       // data.
			type_id = MONTH_ID;
		    }
		    else			   // Unknown type.
		    {
			type_id = NO_DATES_ID;

			throw new NetDataException (
				      "Unknown data type: '" +
				      type_name + "'");
		    }
		}
		else if (type_id == WEEK_ID)    // Week data.
		{
		    NetDataDescriptor  week_data =
			net_data_descrs [WEEK_DATA_INDEX];

		    week_data.getDateVarTable ().parseLine (url_line);
		}
		else if (type_id == QUARTER_ID)    // Quarter data.
		{
		    NetDataDescriptor  quarter_data =
			net_data_descrs [QUARTER_DATA_INDEX];

		    quarter_data.getDateVarTable().parseLine (url_line);
		}
		else if (type_id == MONTH_ID)    // Month data.
		{
		    NetDataDescriptor  month_data =
			net_data_descrs [MONTH_DATA_INDEX];

		    month_data.getDateVarTable ().parseLine (url_line);
		}
		else if ( type_id == DAY_ID	      ||    // Skipped
			  type_id == MEAN_QUARTER_ID  ||    // data
			  type_id == MEAN_MONTH_ID )	    // types.
		{
		}
		else    // No dates data type defined.
		{
		    throw new NetDataException (
				  "No data type defined in dates file");
		}
	    }
	    catch (NetDataException  e_net_data)   // Data format error.
	    {
		/*
		 * Show the first NetData Exception message. Ignore the
		 * rest and continue with the reading of the net data as
		 * far as it goes.
		 */

		if (first_net_data_exception)
		{
		    showDiagnostics (e_net_data);

		    first_net_data_exception = false;
		}
	    }

	} // Read all lines.

	/*
	 * Stop the signal blinking after the dates are loaded.
	 */

	signal.setBlinking (false);

	data_line_nr.value = 0;   // No line # in execpt. mess. anymore.
	blink_line_nr	   = -1;  // Reset blink line #.

	closeURLInputData ();    // Close the input.

	/*
	 * Show status dates read, but that the net data must still be
	 * readed.
	 */

	showStatus ("Dates read; net data still to be read");

    } // readDates ()


    /**
     * Read the net data values from the data file of the current type.
     * A private data table is used for each data type. A new data type
     * in the data file is preceeded from a line
     *
     * <CENTER>
     *
     * <CODE>Data_Type := <VAR>Data_Tye</VAR></CODE>
     *
     * </CENTER>
     *
     *    @exception  Exception   An exception is thrown when the net
     *				  data read thread should quit or at an
     *				  URL I/O error.
     *
     *    @see  NetData#readNetData
     *    @see  NetData#readDates
     *
    **************************************************/
    private void  readNetTypeData ()  throws  Exception
    /*************************************************/
    {
	String []  data_type_words = new String [2];

	NetDataTable   net_data = null;
	String	       net_type = NetDataTable.DEFAULT_NET_TYPE;
	int	       type_id  = NO_DATA_ID;
	CharInputLine  url_line;
	String	       type_name;
	int	       separ_index;
	boolean	       first_net_data_exception = true;
	boolean	       file_type_set		= false;
	boolean	       file_id_set		= false;
	boolean	       net_data_type_set	= false;

	/*
	 * Show that the net data must be loaded.
	 */

	signal.setLightColor (Signal.WAIT_COLOR);

	/*
	 * Open the URL input stream and show the status.
	 */

	showStatus ("Opening net data file: " + data_file_base);

	openURLInputData (data_file);

	/*
	 * Show the alert signal to show that we are loading input.
	 */

	signal.setLightColor (Signal.ALERT_COLOR);

	/*
	 * Show status reading net data.
	 */

	showStatus ("Reading net data file: " + data_file_base);

	/*
	 * Start the signal blinking during the loading of the data
	 * input.
	 */

	signal.setBlinking (true);

	/*
	 * Allocate the class instance which contains the current input
	 * line character array.
	 */

	url_line = new CharInputLine ();

	/*
	 * Read all lines from the URL and parse these lines.
	 */

	while (url_line.read (url_input))
	{
	    try  // Ignore NetDataException's. Try to continue reading.
	    {
		/*
		 * Increment the line # read. It is used in the load
		 * blink thread to show the load state and it is shown
		 * in execption messages. Check also at the same moment
		 * if the net data read thread should quit.
		 */

		synchronized (data_line_nr)
		{
		    if (++data_line_nr.value % NR_STATUS_LINES == 0)
		    {
			showStatus (data_file_base + ": " +
				    data_line_nr.value + " lines");

			no_js_fun_quit.checkThrow ();
		    }
		}

		/*
		 * Set the net data type when A. it is not yet set and
		 * when one of the following statements is true:
		 *
		 *    1. The file type and ID are both set.
		 *
		 *    2. The net data are defined.
		 */

		if ( !net_data_type_set    // A.
		     &&
		     ( file_type_set && file_id_set    // 1.
		       ||
		       net_data != null		       // 2.
		     ) )
		{
		    setNetDataType ();
		    net_data_type_set = true;
		}

		if (url_line.startsWith (DATA_TYPE_NAME_CHARS))
		{
		    /*
		     * Get the index of the input type separation string
		     * when an input line is found which is intended to
		     * change the net data type.
		     */

		    separ_index = url_line.indexOf (TYPE_SEPAR_CHARS);

		    /*
		     * Throw a net data format exception when no
		     * separation string could be found.
		     */

		    if (separ_index == -1)
		    {
			throw new NetDataException (
				      "No data type separator '" +
				      TYPE_SEPAR + "' found in type " +
				      "string: '" + url_line + "'");
		    }

		    /*
		     * Read the name of the data type (remove spaces
		     * from boths ends of the string) and analyse the
		     * data type. The corresponding storage table is
		     * selected.
		     */

		    type_name = url_line.toSubstring (
				    separ_index +
				    TYPE_SEPAR_LENGTH).trim ();

		    if (type_name.equals (SET_TITLE_NAME))  // Hosts set
		    {					    // title.
			type_id  = SET_TITLE_ID;
			net_data = null;
		    }
		    else if (type_name.equals (PERIOD_NAME))  // Date
		    {					      // period.
			type_id  = PERIOD_ID;
			net_data = null;
		    }
		    else if (type_name.equals (ONE_DIRECT_NAME))// 1-/2-
		    {					        // dir.
			/*
			 * Require that the one-/two-directional
			 * connection type is defined before the load,
			 * ping and throughput data types: the host
			 * dependence of these types is dependent from
			 * the directional data type.
			 */

			checkNoTestDataTypes (ONE_DIRECT_NAME,
					      type_name, type_id);

			type_id  = ONE_DIRECT_ID;
			net_data = null;
		    }
		    else if (type_name.equals (FILE_TYPE_NAME)) // File
		    {						// type.
			/*
			 * Require that the file type is defined before
			 * one of the data types: the way the data are
			 * read is depending from the file type.
			 */

			checkNoTestDataTypes (FILE_TYPE_NAME,
					      type_name, type_id);

			type_id  = FILE_TYPE_ID;
			net_data = null;
		    }
		    else if (type_name.equals (FILE_ID_NAME))   // File
		    {						// ID.
			/*
			 * Require that the file ID is defined before
			 * one of the data types: some data type
			 * parameters may depend from the file ID.
			 */

			checkNoTestDataTypes (FILE_ID_NAME,
					      type_name, type_id);

			type_id  = FILE_ID_ID;
			net_data = null;
		    }
		    else if (type_name.equals (USE_QOS_NAME))  // Inet &
		    {					       // QoS.
			type_id  = USE_QOS_ID;
			net_data = null;
		    }
		    else if (type_name.equals (QOS_TITLE_NAME))  // QoS
		    {						 // tit.
			type_id  = QOS_TITLE_ID;
			net_data = null;
		    }
		    else if (type_name.equals (INET_TITLE_NAME)) // Inet
		    {						 // tit.
			type_id  = INET_TITLE_ID;
			net_data = null;
		    }
		    else if (type_name.equals (HOST_TITLE_NAME)) // Host
		    {					         // tit.
			/*
			 * Require that the host titles are specified
			 * before the load, ping and throughput types:
			 * only the data of the hosts are displayed from
			 * which the host titles are specified.
			 */

			checkNoTestDataTypes (HOST_TITLE_NAME,
					      type_name, type_id);

			type_id  = HOST_TITLE_ID;
			net_data = null;
		    }
		    else if (type_name.equals (SKIP_CONN_NAME)) // Skip
		    {						// conn.
			type_id  = SKIP_CONN_ID;		// type.
			net_data = null;
		    }
		    else if (type_name.equals (WEEK_DATES_NAME))// Week
		    {						// dates
			type_id  = WEEK_DATES_ID;	        // type.
			net_data = null;
		    }
		    else if (type_name.equals (LOAD_NAME))   // Load
		    {					     // type.
			type_id  = LOAD_ID;
			net_data = load_data;
		    }
		    else if (type_name.equals (PING_NAME))   // Ping
		    {					     // type.
			type_id  = PING_ID;
			net_data = ping_data;
		    }
		    else if (type_name.equals (THROUGHPUT_NAME)) // Tput
		    {						 // tp.
			type_id  = THROUGHPUT_ID;
			net_data = throughput_data;
		    }
		    else if (type_name.equals (USE_UDP_BW_NAME))  // Use
		    {						  // UDP
			type_id  = USE_UDP_BW_ID;		  // d.?
			net_data = null;
		    }
		    else if (type_name.equals (UDP_BW_NAME))   // UDP BW
		    {					       // type.
			type_id  = UDP_BW_ID;
			net_data = udp_bw_data;
		    }
		    else			   // Unknown type.
		    {
			type_id = NO_DATA_ID;

			throw new NetDataException (
				      "Unknown data type: '" +
				      type_name + "'");
		    }
		}
		else if (url_line.startsWith (NET_TYPE_NAME_CHARS))
		{
		    /*
		     * Get the index of the input type separation string
		     * when an input line is found which is intended to
		     * change the net type.
		     */

		    separ_index = url_line.indexOf (TYPE_SEPAR_CHARS);

		    /*
		     * Throw a net data format exception when no
		     * separation string could be found.
		     */

		    if (separ_index == -1)
		    {
			throw new NetDataException (
				      "No data type separator '" +
				      TYPE_SEPAR + "' found in type " +
				      "string: '" + url_line + "'");
		    }

		    /*
		     * Read the name of the data type (remove spaces
		     * from boths ends of the string) and analyse the
		     * net type.
		     */

		    net_type = url_line.toSubstring (
				   separ_index +
				   TYPE_SEPAR_LENGTH).trim ();

		    if ( !( net_type.equals (NetDataTable.QOS)  ||
			    net_type.equals (NetDataTable.INET) ) )
		    {
			throw new NetDataException (
				      "Unkown net type: '" + net_type +
				      "'");
		    }
		}
		else    // Parse the net data line, corr. to the type.
		{
		    switch (type_id)   // Analyse the current data type.
		    {
			case SET_TITLE_ID :   // Title of the hosts set.

			    set_title = url_line.toString ();
			    break;

			case PERIOD_ID : // The period [m] betw. 2 dt's.

			    period = url_line.toString ();
			    break;

			case ONE_DIRECT_ID :    // One-/two-direc. conn.

			    if (url_line.toString ().equals (TRUE_STR))
				one_direct = true;
			    else
				one_direct = false;

			    /*
			     * Sort the two hosts when the net tests
			     * between these hosts is measured in one
			     * direction. Note that the load data always
			     * depend from one host. The ping and
			     * throughput data are depending from the
			     * connection between two hosts, so sorting
			     * is required when the tests are done
			     * one-directional.
			     */

			    boolean  sort_2_hosts = one_direct;

			    gen_host_key.setSortHosts (sort_2_hosts);
			    break;

			case FILE_TYPE_ID :    // Data file type.

			    file_type	  = url_line.toString ();
			    file_type_set = true;
			    break;

			case FILE_ID_ID :    // Data file ID.

			    file_id = Integer.parseInt (
					  url_line.toString ());

			    file_id_set = true;
			    break;

			case USE_QOS_ID :  // Inet & QoS net tests done.

			    if (url_line.toString ().equals (TRUE_STR))
				qos_and_inet = true;
			    else
				qos_and_inet = false;

			    break;

			case QOS_TITLE_ID :    // QoS title.

			    qos_title = url_line.toString ();
			    break;

			case INET_TITLE_ID :    // Internet title.

			    inet_title = url_line.toString ();
			    break;

			case HOST_TITLE_ID :    // Host titles.

			    /*
			     * Note that the host titles should be
			     * specified for the net test data types
			     * (load, ping and throughput): they mark
			     * the hosts to be shown in the tables. Add
			     * also the host at the end of the host
			     * vector.
			     */

			    String  host = host_titles.parseLine (
					       url_line);

			    hosts.addNewElement (host);
			    break;

			case SKIP_CONN_ID :    // Skip host conecction.

			    /*
			     * Parse the skipped source and destination
			     * hosts and store the corresponding skipped
			     * connection.
			     */

			    skip_conns.parseLine (url_line, net_type);
			    break;

			case WEEK_DATES_ID :  // Ignore week dates data.

			    break;
			    
			case USE_UDP_BW_ID :    // Do UDP BW tests?

			    if (url_line.toString ().equals (TRUE_STR))
				use_udp_bw = true;
			    else
				use_udp_bw = false;

			    break;

			default :    // The net test data types.

			    if (net_data == null) // No type before dta.
			    {
				throw new NetDataException (
					      "No data type defined " +
					      "in data file");
			    }
			    else   // Parse the line and store the data.
			    {
				net_data.parseLine (
				    url_line,
				    hosts,
				    dates,
				    host_titles,
				    current_data.getDateIDTable (),
				    net_type);
			    }
			    break;

		    } // Analyse the current data type.
		
		} // Parse the net data line, corresponding to the type.
	    }
	    catch (NetDataException  e_net_data)   // Data format error.
	    {
		/*
		 * Show the first NetData Exception message. Ignore the
		 * rest and continue with the reading of the net data as
		 * far as it goes.
		 */

		if (first_net_data_exception)
		{
		    showDiagnostics (e_net_data);

		    first_net_data_exception = false;
		}
	    }

	} // Read all lines.

	/*
	 * Stop the blinking of the signal after the input data are
	 * loaded.
	 */

	signal.setBlinking (false);

	/*
	 * Show that the data are loaded.
	 */

	signal.setLightColor (Signal.GO_COLOR);

	data_line_nr.value = 0;   // No line # in execpt. mess. anymore.
	blink_line_nr	   = -1;  // Reset blink line #.

	closeURLInputData ();    // Close the input.

	/*
	 * Show status data read.
	 */

	showStatus ("Net data read");

    } // readNetTypeData ()


    /**
     * Check if the current data type is not one of the test data types.
     * These test types depend from the value(s) in the new data type.
     *
     *    @param  new_type_name   Name of the new data type to set.
     *
     *	  @param  type_name	  Name of the current data type.
     *
     *	  @param  type_id	  ID of the current data type.
     *
     *	  @exception  NetDataException   An execption of this type is
     *					 thrown when the data type is
     *					 one of the test types.
     *
    **********************************************************/
    private void  checkNoTestDataTypes ( String  new_type_name,
					 String  type_name,
					 int     type_id
				       )
				       throws  NetDataException
    /*********************************************************/
    {
	if ( type_id == LOAD_ID        ||
	     type_id == PING_ID        ||
	     type_id == THROUGHPUT_ID  ||
	     type_id == UDP_BW_ID )
	{
	    throw new NetDataException (
			  "The " + type_name +
			  " may not be specified before " +
			  new_type_name +
			  " because the data depend from the latter");
	}
    }


    /**
     * Set the data type from the file type specified in the data file
     * and the select ID, also specified in the data file. Use these
     * values to set also the data type titles.
     *
    ******************************/
    private void  setNetDataType ()
    /*****************************/
    {
	/*
	 * Parse the data file type read from the data file. It
	 * determines the data type.
	 */

	if (file_type.equals (RECENT_DATA_TYPE)) // Data of last # days.
	{
	    data_type_index = RECENT_DATA_INDEX;
	}
	else if (file_type.equals (WEEK_DATA_TYPE))   // Week data type.
	{
	    data_type_index = WEEK_DATA_INDEX;
	}
	else if (file_type.equals (WEEK_MEAN_DATA_TYPE))   // Week mean
	{						   // data type.
	    data_type_index = WEEK_MEAN_DATA_INDEX;
	}
	else if (file_type.equals (DAY_MEAN_DATA_TYPE))    // Day mean
	{						   // data type.
	    data_type_index = DAY_MEAN_DATA_INDEX;
	}
	else if (file_type.equals (QUARTER_DATA_TYPE))    // Quarter
	{						  // data type.
	    data_type_index = QUARTER_DATA_INDEX;
	}
	else if (file_type.equals (MONTH_DATA_TYPE))    // Month data
	{						// type.
	    data_type_index = MONTH_DATA_INDEX;
	}
	else    // Unknown: use the default data type and index.
	{
	    file_type	    = DEFAULT_FILE_TYPE;
	    file_id	    = DEFAULT_FILE_ID;
	    data_type_index = DEFAULT_DATA_INDEX;
	}

	/*
	 * Set also the current descriptor as accelerator.
	 */

	current_data = net_data_descrs [data_type_index];

	/*
	 * Set the data file select ID for the appropriate data file
	 * types.
	 */

	switch (data_type_index)
	{
	    case WEEK_DATA_INDEX    :    // Set the file select ID.
	    case QUARTER_DATA_INDEX :
	    case MONTH_DATA_INDEX   :

		current_data.setSelectID (file_id);
		break;

	    default:      // Only one data file for the remaining types:
			  // ignore the file select ID.
		break;
	}

	/*
	 * Set the data type title for the data types with are dependent
	 * from a file select ID.
	 */

	switch (data_type_index)
	{
	    case WEEK_DATA_INDEX :    // Week data type.

		current_data.setTypeTitle (WEEK_DATA_PREFIX + " " +
					   file_id);
		break;

	    case QUARTER_DATA_INDEX :    // Quarterly time mean data.

		current_data.setTypeTitle (QUARTER_PREFIX + " " +
					   file_id);
		break;

	    case MONTH_DATA_INDEX :    // Monthly time mean data.

		current_data.setTypeTitle (MONTH_PREFIX + " " +
					   file_id);
		break;

	    default :    // Title already set for remaining data types.

		break;
	}

    } // setNetDataType ()


    /**
     * This function implements the <CODE>isFulfilled()</CODE> method
     * from the <CODE>BlinkChecker</CODE> interface. It checks if the
     * signal indeed should be switched off when blinking is enabled.
     * This is the case when:
     *
     * <OL>
     *
     * <LI>The first time the half of the required #&nbsp;lines are
     *	   read.</LI>
     *
     * <LI>At the later times the full required #&nbsp;lines are
     *	   read.</LI>
     *
     * </OL>
     * </P>
     *
     * <P>
     * Please note that this method will be called from within the
     * <CODE>run()</CODE> method of the blinking thread in the
     * <CODE>Signal</CODE> class instance.
     *
    *****************************/
    public boolean  isFulfilled ()
    /****************************/
    {
	/*
	 * Get the current data line # synchronized with the main thread
	 * reading the data.
	 */

	int  curr_line_nr;

	synchronized (data_line_nr)
	{
	    curr_line_nr = data_line_nr.value;
	}

	/*
	 * Switch the light off when:
	 *
	 *    1. The first time when the half of the required # lines
	 *	 are read.
	 *
	 *    2. At the later times when the full required # lines are
	 *	 read.
	 */

	if ( ( blink_line_nr == -1  &&
	       curr_line_nr >= (MIN_NR_BLINK_LINES / 2)
	     )
	     ||
	     curr_line_nr  >= blink_line_nr + MIN_NR_BLINK_LINES
	   )
	{
	    return true;
	}
	else
	{
	    return false;
	}

    } // isFulfilled ()


    /**
     * Open the URL input stream for the specified URL of the zipped
     * file. First a full URL is tried. If this appears to be not a
     * correct URL, the URL of the zipped filename is supposed to be
     * defined relative to the directory in which this
     * <CODE>Applet</CODE> resides. The URL will be opened without using
     * caching such that always the most recent data will be obtained.
     *
     *    @param  file_url   The URL of the filename to open.
     *
     *    @exception  Exception   An exception is thrown after an URL
     *				  I/O error.
     *
    *******************************************************************/
    private void  openURLInputData (String  file_url)  throws  Exception
    /******************************************************************/
    {
	URL  input_url;

	/*
	 * Open the URL. Try first if a full URL is specified. If this
	 * is not the case construct it from the directory URL and from
	 * the (relative) URL of the filename. Finally try to open it by
	 * preceding the URL with ('file://[/]'). In that case assume
	 * that a full path is specified. When a Windows drive is used
	 * also an extra preceding slash should be specified and ':' is
	 * replaced by '|'.
	 */

	try    // Try first the full URL.
	{
	    input_url = new URL (file_url);
	}
	catch (MalformedURLException  e_mal_url_1)
	{
	    try    // Try a relative URL.
	    {
		/*
		 * Get the URL of the Applet directory.
		 */

		URL  url_base = getCodeBase ();

		/*
		 * Construct the file URL from the directory URL and
		 * from the URL of the relative filename.
		 */

		input_url = new URL (url_base, file_url);
	    }
	    catch (MalformedURLException  e_mal_url_2)
	    {
		/*
		 * Try the full URL preceded by 'file://[/]'. Do not
		 * catch URL Exceptions here. Replace ':' by '|' because
		 * a Windows drive is assumed here.
		 */

		if (!file_url.startsWith ("/"))    // No Prefix '/'.
		{
		    file_url = "/" + file_url;

		    file_url.replace (':', '|');
		}

		file_url = "file://" + file_url;   // Add file protocol.

		input_url = new URL (file_url);

	    } // Catch URL Exceptions relative URL.
	    
	} // Catch URL Exceptions full URL.

	/*
	 * Open a connection to the URL and turn the caching of such
	 * that always the most recent version will be obtained.
	 */

	URLConnection  input_url_conn = input_url.openConnection ();

	input_url_conn.setUseCaches (false);

	/*
	 * Open the zipped data URL input stream form the opened URL
	 * connection.
	 */

	url_input = new ZipInputStream (
			    new BufferedInputStream (
				    input_url_conn.getInputStream ()));

	/*
	 * Place the file pointer to the first and only entry from the
	 * ZIP file.
	 */

	ZipEntry  zip_entry = url_input.getNextEntry ();

    } // openURLInputData ()


    /**
     * Close the zipped URL input stream. Mark that it is closed.
     *
     *    @exception  Exception   An exception is thrown after ZIP or
     *				  an URL I/O error.
     *
    ****************************************************/
    private void  closeURLInputData ()  throws  Exception
    /***************************************************/
    {
	try
	{
	    url_input.closeEntry ();
	    url_input.close	 ();
	}
	catch (Exception  e)
	{
	    throw e;    // Rethrow the exception.
	}
	finally    // Always mark the input closed.
	{
	    url_input = null;
	}

    } // closeURLInputData ()


    /**
     * Get the current data type index as a string. It is returned as a
     * new <CODE>String</CODE> object.
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @return  The current data type index.
     *
    *********************************/
    public String  getDataTypeIndex ()
    /********************************/
    {
	return Integer.toString (data_type_index);
    }


    /**
     * Get the selected file ID of the current data type as a string. It
     * is returned as a new <CODE>String</CODE> object.
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @return  The selected file ID of the current type.
     *
    ************************************/
    public String  getDataTypeSelectID ()
    /***********************************/
    {
	return Integer.toString (current_data.getSelectID ());
    }


    /**
     * Return the #&nbsp;hosts which are read from the data file. It is
     * returned as a new <CODE>String</CODE> object.
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @return  The #&nbsp;hosts.
     *
    ***************************/
    public String  getNrHosts ()
    /**************************/
    {
	return Integer.toString (hosts.size ());
    }


    /**
     * Return the host at the specified index in the host array. It is
     * returned as a new <CODE>String</CODE> object.
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @param  index_str   The index of the host in the array.
     *
     *    @return   The host at the given index.
     *
    *****************************************/
    public String  getHost (String  index_str)
    /****************************************/
    {
	try   // Parse the host index from the specified string.
	{
	    int  index = Integer.parseInt (index_str);

	    return new String ((String) hosts.elementAt (index));
	}
	catch (NumberFormatException  e_num)   // Index is no number.
	{
	    showDiagnostics (e_num);

	    return new String ("");
	}

    } // getHost ()


    /**
     * Return of the host title sepcified with its index. When no host
     * title is defined the hostname is returned. It is returned as a
     * new <CODE>String</CODE> object.
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @param  index_str   The index of the host in the array.
     *
     *    @return   The host title at the given index.
     *
    **********************************************/
    public String  getHostTitle (String  index_str)
    /*********************************************/
    {
	try   // Handle the exception generated by a bad index string.
	{
	    /*
	     * Return the host title from the companying function with
	     * the host index parsed.
	     */

	    return new String (getHostTitle (
				   Integer.parseInt (index_str)));
	}
	catch (NumberFormatException  e_num)    // Index is no number.
	{
	    showDiagnostics (e_num);

	    return new String ("");  // No host title could be obtained.
	}
    
    } // getHostTitle ()  (specified with an index string)


    /**
     * Return of the host title sepcified with its index. When no host
     * title is defined the hostname is returned.
     *
     *    @param  index_str   The index of the host in the array.
     *
     *    @return   The host title at the given index.
     *
    ****************************************/
    private String  getHostTitle (int  index)
    /***************************************/
    {
	/*
	 * Get the hostname.
	 */

	String  host = (String) hosts.elementAt (index);

	if (host == null)    // No host knwon.
	{
	    return "";    // No host could be obtained.
	}
	else    // Get the title of the host found.
	{
	    /*
	     * The host title is stored as a hash with the hostname as
	     * key.
	     */

	    String  host_title = host_titles.get (host);

	    if (host_title == null)    // No host title found: return
	    {			       // the hostname.
		return host;
	    }
	    else    // Return the found host title.
	    {
		return host_title;
	    }
	    
	} // A host was found.

    } // getHostTitle ()  (specified with an index value)


    /**
     * Return if the connection, specified by the host indices and the
     * network type, is skipped. The <CODE>boolean</CODE> value is
     * returned as a new <CODE>String</CODE> object.
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @param  host_1_index_str   The index of the first host.
     *
     *    @param  host_2_index_str   The index of the second host.
     *
     *    @param  net_type	     The network type.
     *
     *    @return  True when the conenction is skipped; false otherwise.
     *
    ************************************************************/
    public String  isSkippedConnection (String  host_1_index_str,
					String  host_2_index_str,
					String	net_type)
    /***********************************************************/
    {
	try    // Bad formatted host index strings.
	{
	    /*
	     * Parse the host indices from the specified strings.
	     */

	    int  host_1_index = Integer.parseInt (host_1_index_str);
	    int  host_2_index = Integer.parseInt (host_2_index_str);

	    /*
	     * Get the corresponding hosts key.
	     */

	    String  hosts_key = getDataHostsKey (host_1_index,
						 host_2_index,
						 net_type);

	    /*
	     * Return the boolean flag as a new "String" which denotes
	     * if the connection is skipped.
	     */

	    if (skip_conns.isSkipped (hosts_key))
		return new String (TRUE_STR);
	    else
		return new String (FALSE_STR);
	}
	catch (NumberFormatException  e_num)    // Bad index string.
	{
	    showDiagnostics (e_num);

	    /*
	     * Return that the connection was not skipped when it is
	     * unkown due to a bad formatted index string.
	     */

	    return new String (FALSE_STR);
	}

    } // isSkippedConnection ()


    /**
     * Return the #&nbsp;dates which are found in all net data. It is
     * returned as new <CODE>String</CODE> object.
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @return  The #&nbsp;dates.
     *
    ***************************/
    public String  getNrDates ()
    /**************************/
    {
	return Integer.toString (dates.size ());
    }


    /**
     * Return the (day part of the) date at the specified index in the
     * date array. Note that the array is sorted to increasingly recent
     * date (and time). It is returned as a new <CODE>String</CODE>
     * object.
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @param  index_str   The index of the date (day) in the array.
     *
     *    @return  The date at the given index.
     *
    *****************************************/
    public String  getDate (String  index_str)
    /****************************************/
    {
	try    // Parse the date index from the specified string.
	{
	    int  index = Integer.parseInt (index_str);

	    /*
	     * Return the date. Note that "DateFormat.getDate()" already
	     * allocates a new string.
	     */

	    return ( (DateFormat) dates.elementAt (index) ).getDate ();
	}
	catch (NumberFormatException  e_num)    // Index is no number.
	{
	    showDiagnostics (e_num);

	    return new String ("");
	}
	
    } // getDate ()


    /**
     * Return the time or week/day ID at the specified index in the
     * time array. Note that the array is sorted to increasinly recent
     * (date and) time. It is returned as a new <CODE>String</CODE>
     * object.
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @param  index_str   The index of the time in the array.
     *
     *    @return  The time at the given index.
     *
    *************************************************/
    public String  getTimeOrDateID (String  index_str)
    /************************************************/
    {
	try    // Parse the time/date ID from the specified string.
	{
	    int  index = Integer.parseInt (index_str);

	    DateFormat  date = (DateFormat) dates.elementAt (index);

	    Hashtable  date_id_table = current_data.getDateIDTable ();

	    if (date_id_table == null)    // Get the time.
	    {
		/*
		 * Return the time. Note that "getTime()" already
		 * allocates a new string.
		 */

		return date.getTime ();
	    }
	    else    // Get the date ID. The date string is the key.
	    {
		return new String ( (String) date_id_table.get (
						 date.getDate ()) );
	    }
	}
	catch (NumberFormatException  e_num)    // Index is no number.
	{
	    showDiagnostics (e_num);

	    return new String ("");
	}
	
    } // getTimeOrDateID ()


    /**
     * Set the sizes of the plot canvas which are used when a new plot
     * window is showed.
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @param  new_plot_width    The new width of the plot canvas.
     *
     *    @param  new_plot_height   The new height of the plot canvas.
     *
    ****************************************************/
    public void  setNewPlotSize (String  new_plot_width,
				 String  new_plot_height)
    /***************************************************/
    {
	try    // Catch bad width and/or height integers.
	{
	    /*
	     * Set the sizes synchronised with the "DataPlotWindow"
	     * class instance to have no interference with the plot
	     * window when it is just being shown in the non JavaScript
	     * functions thread.
	     */

	    synchronized (data_plot_window)
	    {
		data_plot_window.setNewPlotSize (
		    Integer.parseInt (new_plot_width),
		    Integer.parseInt (new_plot_height));
	    }
	}
	catch (NumberFormatException  e_num)    // Bad size integer.
	{
	    showDiagnostics (e_num);
	}
    }


    /**
     * Return the width of the plot canvas parsed as a string. Return
     * zero when the width of the plot canvas appears to be larger than
     * the screen.
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @return   The width of the plot canvas.
     *
    *****************************/
    public String  getPlotWidth ()
    /****************************/
    {
	Toolkit  plot_toolkit = data_plot.getToolkit ();

	int  plot_width   = data_plot.size	       ().width;
	int  screen_width = plot_toolkit.getScreenSize ().width;

	if (plot_width > screen_width)
	    return new String ("0");
	else
	    return Integer.toString (plot_width);
    }


    /**
     * Return the height of the plot canvas parsed as a string. Return
     * zero when the height of the plot canvas appears to be larger than
     * the screen.
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @return   The height of the plot canvas.
     *
    ******************************/
    public String  getPlotHeight ()
    /*****************************/
    {
	Toolkit  plot_toolkit = data_plot.getToolkit ();

	int  plot_height   = data_plot.size		().height;
	int  screen_height = plot_toolkit.getScreenSize ().height;

	if (plot_height > screen_height)
	    return new String ("0");
	else
	    return Integer.toString (plot_height);
    }


    /**
     * Returns the string &quot;true&quot; when a plot frame is showed;
     * the string &quot;false&quot; is returned when no plot is
     * displayed. The string are returned as a new <CODE>String</CODE>
     * object.
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @return  A boolean string to inquire if a plot frame is
     *		   showed.
     *
    ***************************/
    public String  plotShowed ()
    /**************************/
    {
	/*
	 * Sychronise with the "DataPlotWindow" class instance to have
	 * no interference with the plot window when it is just being
	 * shown in the non JavaScript functions thread.
	 */

	synchronized (data_plot_window)
	{
	    if (data_plot_window.getShowed ())    // Inquire the plot
		return new String (TRUE_STR);     // frame if a plot is
	    else				  // shown.
		return new String (FALSE_STR);
	}
    }


    /**
     * Plot the load data in a window frame.
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @param  max_date_index_str   The index of the most recent
     *				       date.
     *
    *****************************************************/
    public void  plotLoadData (String  max_date_index_str)
    /****************************************************/
    {
	try    // Catch badly formatted numbers.
	{
	    /*
	     * Synchronise the setting of the required load plot data
	     * variables with the "DataPlotWindow" class instance to
	     * have no interference with the plot window when it is just
	     * being shown in the non JavaScript functions thread.
	     */

	    synchronized (data_plot_window)
	    {
		/*
		 * Set the appropriate load data to the plot window
		 * frame and set related parameters.
		 */

		setLoadDataToPlot (max_date_index_str);
	    }

	    /*
	     * Notify the non JavaScript functions thread to show the
	     * plot window frame synchronised with the corresponding
	     * control variable.
	     */

	    synchronized (do_show_plot)
	    {
		do_show_plot.value = true;
	    }
	}
	catch (NumberFormatException  e_num)
	{
	    showDiagnostics (e_num);
	}
    
    } // plotLoadData ()


    /**
     * Set the appropriate load data to the plot window frame. Set also
     * related parameters.
     *
     *    @param  max_date_index_str   The index of the most recent
     *				       date.
     *
     *	  @exception  NumberFormatException   An exception of this type
     *					      is thrown when numbers are
     *					      badly formatted.
     *
    ************************************************************/
    private void  setLoadDataToPlot ( String  max_date_index_str
				    )
				    throws  NumberFormatException
    /***********************************************************/
    {
	/*
	 * Set the type of the current plot.
	 */

	plot_type = LOAD_PLOT;

	/*
	 * Parse the index of the most recent date (= maximum date
	 * index).
	 */

	setMaxDateIndex (max_date_index_str);

	/*
	 * Calculate the last index in the time domain (= minimum date
	 * index) from the most recent date as starting point.
	 */

	setMinDateIndex ();

	/*
	 * Set the plot title and the axis labels.
	 */

	String  plot_load_title = PLOT_LOAD_TITLE + " " +
				  current_data.getTypeTitle	();
	String  date_axis_label = current_data.getDateAxisLabel ();

	data_plot_window.setPlotTitle  (plot_load_title);
	data_plot_window.setXAxisLabel (date_axis_label);
	data_plot_window.setYAxisLabel (LOAD_AXIS_LABEL);

	/*
	 * Set the date coordinates. They depend from the date tick
	 * scaling type.
	 */

	if (ROUND_DATE_GRID)    // Use direct date coordinates.
	{
	    setDatesToPlot ();
	}
	else    // Interpolate date coord. Need also date ID parameters.
	{
	    setTimeOffsetToPlot       ();
	    setDateIDParametersToPlot ();
	}

	/*
	 * Set the hashtable with the host keys to be excluded from the
	 * plot.
	 */

	data_plot_window.setNoPlotHostKeysTable (
	    load_data.getNoPlotHostKeysTable ());

	/*
	 * Add the load data plot traces to the plot frame.
	 */

	int  nr_hosts = hosts.size ();

	for (int host_index = 0;  host_index < nr_hosts;  host_index++)
	{
	    addLoadDataToPlot (host_index);
	}

    } // setLoadDataToPlot ()


    /**
     * Plot the ping data with the specified type in a window frame.
     * When all ping values are selected also error-bars in the interval
     *
     * <CENTER>
     * [<VAR>avg</VAR>-<VAR>min</VAR>, <VAR>max</VAR>-<VAR>avg</VAR>]
     * </CENTER>
     *
     * are plotted.
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @param  max_date_index_str    The index of the most recent
     *					date.
     *
     *    @param  ping_host_index_str   The index of the host from where
     *					the ping measurements with all
     *					other hosts was done. If the
     *					index is less than zero the ping
     *					measurements between all
     *					possible host combinations are
     *					shown.
     *
     *    @param  ping_type_str		The ping type.
     *
    *******************************************************/
    public void  plotPingData (String  max_date_index_str,
			       String  ping_host_index_str,
			       String  ping_type_str)
    /******************************************************/
    {
	try    // Catch badly formatted numbers and ping types.
	{
	    /*
	     * Synchronise the setting of the required ping plot data
	     * variables with the "DataPlotWindow" class instance to
	     * have no interference with the plot window when it is just
	     * being shown in the non JavaScript functions thread.
	     */

	    synchronized (data_plot_window)
	    {
		/*
		 * Set the appropriate ping data to the plot window
		 * frame and set related parameters.
		 */

		setPingDataToPlot (max_date_index_str,
				   ping_host_index_str,
				   ping_type_str);
	    }

	    /*
	     * Notify the non JavaScript functions thread to show the
	     * plot window frame synchronised with the corresponding
	     * control variable.
	     */

	    synchronized (do_show_plot)
	    {
		do_show_plot.value = true;
	    }
	}
	catch (Exception  e)
	{
	    showDiagnostics (e);
	}
    
    } // plotPingData ()


    /**
     * Set the appropriate ping data to the plot window frame. Set also
     * related parameters.
     *
     *    @param  max_date_index_str    The index of the most recent
     *					date.
     *
     *    @param  ping_host_index_str   The index of the host from where
     *					the ping measurements with all
     *					other hosts was done. If the
     *					index is less than zero the ping
     *					measurements between all
     *					possible host combinations are
     *					shown.
     *
     *    @param  ping_type_str		The ping type.
     *
     *    @exception  Exception   An exception is thrown when numbers
     *				  are badly formatted or when ping types
     *				  are badly specified.
     *
    *************************************************************/
    private void  setPingDataToPlot ( String  max_date_index_str,
				      String  ping_host_index_str,
				      String  ping_type_str
				    )
				    throws  Exception
    /************************************************************/
    {
	/*
	 * Set the type of the current plot.
	 */

	plot_type = PING_PLOT;

	/*
	 * Parse the index of the most recent date (= maximum date
	 * index).
	 */

	setMaxDateIndex (max_date_index_str);

	/*
	 * Calculate the last index in the time domain (= minimum date
	 * index) from the most recent date as starting point.
	 */

	setMinDateIndex ();

	/*
	 * Parse the index of the fixed ping host and the ping type from
	 * the arguments.
	 */

	int  ping_host_index = getHostIndex (ping_host_index_str);
	int  ping_type	     = getPingType  (ping_type_str);

	/*
	 * Set the plot title and include the host title of the fixed
	 * ping host (when used) and the ping type into it.
	 */

	String  plot_title = getPlotPingTitle (ping_host_index,
					       ping_type);

	/*
	 * Get the date axis title, depending from the net data.
	 */

	String  date_axis_label = current_data.getDateAxisLabel ();

	/*
	 * Set the ping axis label. Include the ping type into it.
	 */

	String  ping_axis_label = getPingAxisLabel (ping_type);

	/*
	 * Set the plot title and the axis labels to be used in the plot
	 * window frame for the next plot.
	 */

	data_plot_window.setPlotTitle  (plot_title);
	data_plot_window.setXAxisLabel (date_axis_label);
	data_plot_window.setYAxisLabel (ping_axis_label);

	/*
	 * Set the date coordinates. They depend from the date tick
	 * scaling type.
	 */
	     
	if (ROUND_DATE_GRID)    // Use direct date coordinates.
	{
	    setDatesToPlot ();
	}
	else    // Interpolate date coord. Need also date ID parameters.
	{
	    setTimeOffsetToPlot	      ();
	    setDateIDParametersToPlot ();
	}

	/*
	 * Set the hashtable with the host keys to be excluded from the
	 * plot.
	 */

	data_plot_window.setNoPlotHostKeysTable (
	    ping_data.getNoPlotHostKeysTable ());

	/*
	 * Add the ping data plot traces to the plot frame.
	 */

	int  nr_hosts = hosts.size ();

	if (ping_host_index < 0)    // Ping values between all hosts.
	{
	    /*
	     * Do for all hosts. They define the 1th host used in the
	     * ping measurements.
	     */

	    for ( int host_1_index = 0;
		      host_1_index < nr_hosts;
		      host_1_index++ )
	    {
		/*
		 * Set the first 2th host. At one-directional tests this
		 * is the first of the remaining hosts. At two-
		 * directional tests this is the first host.
		 */

		int  start_host_2_index;

		if (one_direct)
		    start_host_2_index = host_1_index + 1;
		else
		    start_host_2_index = 0;

		/*
		 * Do for all 2th hosts used in the ping measurements.
		 */

		for ( int host_2_index = start_host_2_index;
			  host_2_index < nr_hosts;
			  host_2_index++ )
		{
		    if (host_2_index != host_1_index)
		    {
			if (qos_and_inet)    // Add also QoS test(s).
			{
			    addPingDataToPlot (host_1_index,
					       host_2_index,
					       ping_type,
					       NetDataTable.QOS,
					       qos_title,
					       true,
					       false);
			}

			/*
			 * Always add the "normal" Internet test.
			 */

			addPingDataToPlot (host_1_index,
					   host_2_index,
					   ping_type,
					   NetDataTable.INET,
					   inet_title,
					   true,
					   false);

		    } // host_2_index != host_1_index

		} // For the selected 2th ping hosts.
		    
	    } // For all 1th ping hosts.
	}
	else    // Add the ping measurements done with a fixed host.
	{
	    /*
	     * Do for all 2th hosts unequal to the fixed (1th) host.
	     */

	    for ( int host_2_index = 0;
		      host_2_index < nr_hosts;
		      host_2_index++ )
	    {
		if (host_2_index != ping_host_index)
		{
		    if (qos_and_inet)    // Add also QoS test.
		    {
			addPingDataToPlot (ping_host_index,
					   host_2_index,
					   ping_type,
					   NetDataTable.QOS,
					   qos_title,
					   false,
					   false);

			if (!one_direct)    // Add QoS in reverse dir.
			{
			    addPingDataToPlot (host_2_index,
					       ping_host_index,
					       ping_type,
					       NetDataTable.QOS,
					       qos_title,
					       false,
					       true);
			}

		    } // Add also QoS test.

		    addPingDataToPlot (ping_host_index,      // Add
				       host_2_index,	     // Internet
				       ping_type,	     // test.
				       NetDataTable.INET,
				       inet_title,
				       false,
				       false);

		    if (!one_direct)    // Add Inet in reverse dir.
		    {
			addPingDataToPlot (host_2_index,
					   ping_host_index,
					   ping_type,
					   NetDataTable.INET,
					   inet_title,
					   false,
					   true);
		    }

		} // The 2th host unequal to the fixed host.

	    } // For all 2th hosts.
	    
	} // Ping measurement with the fixed host.

    } // setPingDataToPlot ()


    /**
     * Plot the throughput data in a window frame.
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @param  max_date_index_str    The index of the most recent
     *					date.
     *
     *    @param  tput_host_index_str   The index of the host from where
     *					the throughput measurements with
     *					all other hosts was done. If the
     *					index is less than zero the ping
     *					measurements between all
     *					possible host combinattios are
     *					shown.
     *
    ************************************************************/
    public void  plotThroughputData (String  max_date_index_str,
				     String  tput_host_index_str)
    /***********************************************************/
    {
	try    // Catch badly formatted numbers.
	{
	    /*
	     * Synchronise the setting of the required throughput plot
	     * data variables with the "DataPlotWindow" class instance
	     * to have no interference with the plot window when it is
	     * just being shown in the non JavaScript functions thread.
	     */

	    synchronized (data_plot_window)
	    {
		/*
		 * Set the appropriate throughput data to the plot
		 * window frame and set related parameters.
		 */

		setThroughputDataToPlot (max_date_index_str,
					 tput_host_index_str);
	    }

	    /*
	     * Notify the non JavaScript functions thread to show the
	     * plot window frame synchronised with the corresponding
	     * control variable.
	     */

	    synchronized (do_show_plot)
	    {
		do_show_plot.value = true;
	    }
	}
	catch (NumberFormatException  e_num)
	{
	    showDiagnostics (e_num);
	}

    } // plotThroughputData ()


    /**
     * Set the appropriate throughput data to the plot window frame. Set
     * also related parameters.
     *
     *    @param  max_date_index_str    The index of the most recent
     *					date.
     *
     *    @param  tput_host_index_str   The index of the host from where
     *					the throughput measurements with
     *					all other hosts was done. If the
     *					index is less than zero the ping
     *					measurements between all
     *					possible host combinattios are
     *					shown.
     *
     *	  @exception  NumberFormatException   An exception of this type
     *					      is thrown when numbers are
     *					      badly formatted.
     *
    ******************************************************************/
    private void  setThroughputDataToPlot ( String  max_date_index_str,
					    String  tput_host_index_str
					  )
					  throws  NumberFormatException
    /*****************************************************************/
    {
	/*
	 * Set the type of the current plot.
	 */
	    
	plot_type = THROUGHPUT_PLOT;

	/*
	 * Parse the index of the most recent date (= maximum date
	 * index).
	 */

	setMaxDateIndex (max_date_index_str);

	/*
	 * Calculate the last index in the time domain (= minimum date
	 * index) from the most recent date as starting point.
	 */

	setMinDateIndex ();

	/*
	 * Parse the index of the fixed throughput host.
	 */

	int  tput_host_index = getHostIndex (tput_host_index_str);

	/*
	 * Set the plot title and include the host title of the fixed
	 * throughput host (when used) into it.
	 */

	String  plot_title = getPlotTitle (PLOT_THROUGHPUT_PREFIX,
					   tput_host_index);

	/*
	 * Set the date axis label from the current net data.
	 */

	String  date_axis_label = current_data.getDateAxisLabel ();

	/*
	 * Set the plot title and the axis labels to be used in the plot
	 * window frame for the next plot.
	 */

	data_plot_window.setPlotTitle  (plot_title);
	data_plot_window.setXAxisLabel (date_axis_label);
	data_plot_window.setYAxisLabel (THROUGHPUT_AXIS_LABEL);

	/*
	 * Set the date coordinates. They depend from the date tick
	 * scaling type.
	 */
	     
	if (ROUND_DATE_GRID)    // Use direct date coordinates.
	{
	    setDatesToPlot ();
	}
	else    // Interpolate date coord. Need also date ID parameters.
	{
	    setTimeOffsetToPlot       ();
	    setDateIDParametersToPlot ();
	}

	/*
	 * Set the hashtable with the host keys to be excluded from the
	 * plot.
	 */

	data_plot_window.setNoPlotHostKeysTable (
	    throughput_data.getNoPlotHostKeysTable ());

	/*
	 * Add the throughput data plot traces to the plot frame.
	 */

	int  nr_hosts = hosts.size ();

	if (tput_host_index < 0)    // Tput values between all hosts.
	{
	    /*
	     * Do for all hosts. They define the 1th host used in the
	     * throughput measurements.
	     */

	    for ( int host_1_index = 0;
		      host_1_index < nr_hosts;
		      host_1_index++ )
	    {
		/*
		 * Set the first 2th host. At one-directional tests this
		 * is the first of the remaining hosts. At two-
		 * directional tests this is the first host.
		 */

		int  start_host_2_index;

		if (one_direct)
		    start_host_2_index = host_1_index + 1;
		else
		    start_host_2_index = 0;

		/*
		 * Do for all 2th hosts used in the throughput
		 * measurements.
		 */

		for ( int host_2_index = start_host_2_index;
			  host_2_index < nr_hosts;
			  host_2_index++ )
		{
		    if (host_2_index != host_1_index)
		    {
			if (qos_and_inet)    // Add also QoS test.
			{
			    addThroughputDataToPlot (host_1_index,
						     host_2_index,
						     NetDataTable.QOS,
						     qos_title,
						     true,
						     false);
			}

			/*
			 * Always add the "normal" Internet test.
			 */

			addThroughputDataToPlot (host_1_index,
						 host_2_index,
						 NetDataTable.INET,
						 inet_title,
						 true,
						 false);

		    } // host_2_index != host_1_index
		    
		} // For the selected 2th throughput hosts.

	    } // For all 1th throughput hosts.
	}
	else    // Add the throughput measurements with a fixed host.
	{
	    /*
	     * Do for all 2th hosts unequal to the fixed (1th) host.
	     */

	    for ( int host_2_index = 0;
		      host_2_index < nr_hosts;
		      host_2_index++ )
	    {
		if (host_2_index != tput_host_index)
		{
		    if (qos_and_inet)    // Add also QoS test.
		    {
			addThroughputDataToPlot (tput_host_index,
						 host_2_index,
						 NetDataTable.QOS,
						 qos_title,
						 false,
						 false);

			if (!one_direct)    // Add QoS in reverse dir.
			{
			    addThroughputDataToPlot (host_2_index,
						     tput_host_index,
						     NetDataTable.QOS,
						     qos_title,
						     false,
						     true);
			}

		    } // Add also QoS test.

		    /* Add the Internet test. */

		    addThroughputDataToPlot (tput_host_index,
					     host_2_index,
					     NetDataTable.INET,
					     inet_title,
					     false,
					     false);

		    if (!one_direct)    // Add Inet in reverse dir.
		    {
			addThroughputDataToPlot (host_2_index,
						 tput_host_index,
						 NetDataTable.INET,
						 inet_title,
						 false,
						 true);
		    }
		    
		} // The 2th host unequal to the fixed host.

	    } // For all 2th hosts.

	} // Throughput measurements with the fixed host.

    } // setThroughputDataToPlot ()


    /**
     * Plot the UDP bandwidth data with the specified type in a window
     * frame.
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @param  max_date_index_str	  The index of the most recent
     *					  data.
     *
     *    @param  udp_bw_host_index_str   The index of the host from
     *					  where the UDP bandwidth
     *					  measurements with all other
     *					  hosts was done. If the index
     *					  is less than zero the UDP
     *					  bandwidth measurements between
     *					  all possible host combinations
     *					  are shown.
     *
     *    @param  udp_bw_type_str	  The UDP bandwidth type.
     *
    *********************************************************/
    public void  plotUDPBWData (String  max_date_index_str,
				String  udp_bw_host_index_str,
				String	udp_bw_type_str)
    /********************************************************/
    {
	try    // Catch badly formatted numbers and UDP bandwidth types.
	{
	    /*
	     * Synchronise the setting of the required UDP bandwidth
	     * plot data with the "DataPlotWindow" class instance to
	     * have no interference with the plot window when it is just
	     * being shown in the non JavaScript functions thread.
	     */

	    synchronized (data_plot_window)
	    {
		/*
		 * Set the appropriate UDP bandwidth data to the plot
		 * window frame and set related parameters.
		 */

		setUDPBWDataToPlot (max_date_index_str,
				    udp_bw_host_index_str,
				    udp_bw_type_str);
	    }

	    /*
	     * Notify the non JavaScript functions thread to show the
	     * plot window frame synchronised with the corresponding
	     * control variable.
	     */

	    synchronized (do_show_plot)
	    {
		do_show_plot.value = true;
	    }
	}
	catch (Exception  e)
	{
	    showDiagnostics (e);
	}

    } // plotUDPBWData ()


    /**
     * Set the appropriate UDP bandwidth data to the plot window frame.
     * Set also related parameters.
     *
     *    @param  max_date_index_str	  The index of the most recent
     *					  data.
     *
     *    @param  udp_bw_host_index_str   The index of the host from
     *					  where the UDP bandwidth
     *					  measurements with all other
     *					  hosts was done. If the index
     *					  is less than zero the UDP
     *					  bandwidth measurements between
     *					  all possible host combinations
     *					  are shown.
     *
     *    @param  udp_bw_type_str	  The UDP bandwidth type.
     *
     *    @exception  Exception   An exception is thrown when numbers
     *				  are badly formatted or when UDP
     *				  bandwidth types are badly specified.
     *
    ****************************************************************/
    private void  setUDPBWDataToPlot ( String  max_date_index_str,
				       String  udp_bw_host_index_str,
				       String  udp_bw_type_str
				     )
				     throws  Exception
    /***************************************************************/
    {
	/*
	 * Set the type of the current plot.
	 */

	plot_type = UDP_BW_PLOT;

	/*
	 * Parse the index of the most recent date (= maximum date
	 * index).
	 */

	setMaxDateIndex (max_date_index_str);

	/*
	 * Calculate the last index in the time domain (= minimum date
	 * index) from the most recent date as starting point.
	 */

	setMinDateIndex ();

	/*
	 * Parse the index of the fixed UDP bandwidth host and the UDP
	 * bandwidth type from the arguments.
	 */

	int  udp_bw_host_index = getHostIndex (udp_bw_host_index_str);
	int  udp_bw_type       = getUDPBWType (udp_bw_type_str);

	/*
	 * Set the plot title and include the host title of the fixed
	 * UDP bandwidth host (when used) and the UDP bandwidth type
	 * into it.
	 */

	String  plot_title = getPlotUDPBWTitle (udp_bw_host_index,
						udp_bw_type);

	/*
	 * Get the date axis title, depending from the net data.
	 */

	String  date_axis_label = current_data.getDateAxisLabel ();

	/*
	 * Get the UDP bandwidth axis label. Include the UDP bandwidth
	 * type into it.
	 */

	String  udp_bw_axis_label = getUDPBWAxisLabel (udp_bw_type);

	/*
	 * Set the plot title and the axis label to be used in the plot
	 * window frame for the next plot.
	 */

	data_plot_window.setPlotTitle  (plot_title);
	data_plot_window.setXAxisLabel (date_axis_label);
	data_plot_window.setYAxisLabel (udp_bw_axis_label);

	/*
	 * Set the date coordinates. They depend from the date tick
	 * scaling type.
	 */

	if (ROUND_DATE_GRID)    // Use direct date coordinates.
	{
	    setDatesToPlot ();
	}
	else    // Interpolate date coord. Need also date ID parameters.
	{
	    setTimeOffsetToPlot	  ();
	    setDateIDParametersToPlot ();
	}

	/*
	 * Set the hashtable with the host keys to be excluded from the
	 * plot.
	 */

	data_plot_window.setNoPlotHostKeysTable (
	    udp_bw_data.getNoPlotHostKeysTable ());

	/*
	 * Add the UDP bandwidth data plot traces to the plot frame.
	 */

	int  nr_hosts = hosts.size ();

	if (udp_bw_host_index < 0)   // UDP BW values between all hosts.
	{
	    /*
	     * Do for all hosts. They define the 1th host used in the
	     * UDP bandwidth measurements.
	     */

	    for ( int host_1_index = 0;
		      host_1_index < nr_hosts;
		      host_1_index++ )
	    {
		/*
		 * Set the first 2th host. At one-directional tests this
		 * is the first of the remaining hosts. At two-
		 * directional tests this is the first host.
		 */

		int  start_host_2_index;

		if (one_direct)
		    start_host_2_index = host_1_index + 1;
		else
		    start_host_2_index = 0;

		/*
		 * Do for all 2th hosts used in the UDP bandwidth
		 * measurements.
		 */

		for ( int host_2_index = start_host_2_index;
			  host_2_index < nr_hosts;
			  host_2_index++ )
		{
		    if (host_2_index != host_1_index)
		    {
			if (qos_and_inet)    // Add also QoS test(s).
			{
			    addUDPBWDataToPlot (host_1_index,
						host_2_index,
						udp_bw_type,
						NetDataTable.QOS,
						qos_title,
						true,
						false);
			}

			/*
			 * Always add the "normal" Internet tests.
			 */

			addUDPBWDataToPlot (host_1_index,
					    host_2_index,
					    udp_bw_type,
					    NetDataTable.INET,
					    inet_title,
					    true,
					    false);

		    } // host_2_index != host_1_index

		} // For the selected 2th UDP bandwidth host.

	    } // For all 1th UDP bandwidth hosts.
	}
	else     // Add the UDP bandwidth measurements executes with a
	{	 // fixed host.
	    /*
	     * Do for all 1th hosts unequal to the fized (1th) host.
	     */

	    for ( int host_2_index = 0;
		      host_2_index < nr_hosts;
		      host_2_index++ )
	    {
		if (host_2_index != udp_bw_host_index)
		{
		    if (qos_and_inet)    // Add also QoS test.
		    {
			addUDPBWDataToPlot (udp_bw_host_index,
					    host_2_index,
					    udp_bw_type,
					    NetDataTable.QOS,
					    qos_title,
					    false,
					    false);

			if (!one_direct)    // Add QoS in reverse dir.
			{
			    addUDPBWDataToPlot (host_2_index,
						udp_bw_host_index,
						udp_bw_type,
						NetDataTable.QOS,
						qos_title,
						false,
						true);
			}

		    } // Add also QoS test.

		    /*
		     * Always add the "normal" Internet test.
		     */

		    addUDPBWDataToPlot (udp_bw_host_index,
					host_2_index,
					udp_bw_type,
					NetDataTable.INET,
					inet_title,
					false,
					false);

		    if (!one_direct)    // Add Inet in reverse dir.
		    {
			addUDPBWDataToPlot (host_2_index,
					    udp_bw_host_index,
					    udp_bw_type,
					    NetDataTable.INET,
					    inet_title,
					    false,
					    true);
		    }

		} // The 2th host unequal to the fixed host.

	    } // For all 2th hosts.

	} // UDP bandwidth measurement with the fixed host.

    } // setUDPBWDataToPlot ()


    /**
     * Return the title of the ping plot. It contains the title of the
     * fixed host connection (if existsing), the ping type and the type
     * of the current net data.
     *
     *    @param  ping_host_index   The index of the fixed host.
     *
     *    @param  ping_type	    The ping type.
     *
     *    @return  The title of the ping plot.
     *
    ******************************************************/
    private String  getPlotPingTitle (int  ping_host_index,
				      int  ping_type)
    /*****************************************************/
    {
	/*
	 * Add the ping title to the plot prefix ...
	 */

	String  base_title = PLOT_PING_PREFIX + " " +
			     LONG_PING_TYPE_NAMES [ping_type];

	/*
	 * ... and return with it the default plot title with the fixed
	 * host included, when it exists.
	 */
	 
	return getPlotTitle (base_title, ping_host_index);

    } // getPlotPingTitle ()


    /**
     * Return the title of the UDP bandwidth plot. It contains the title
     * of the fixed host connection (if existing), the UDP bandwidth
     * type and the type of the current net data.
     *
     *    @param  udp_bw_host_index   The index of the fixed host.
     *
     *    @param  udp_bw_type	      The UDP bandwidth type.
     *
     *    @return  The title of the UDP bandwidth plot.
     *
    *********************************************************/
    private String  getPlotUDPBWTitle (int  udp_bw_host_index,
				       int  udp_bw_type)
    /********************************************************/
    {
	/*
	 * Add the UDP bandwidth title to the plot prefix ...
	 */

	String  base_title = PLOT_UDP_BW_PREFIX + " " +
			     LONG_UDP_BW_TYPE_NAMES [udp_bw_type];

	/*
	 * ... and return with it the default plot title with the fixed
	 * host included, when it exists.
	 */

	return getPlotTitle (base_title, udp_bw_host_index);

    } // getPlotUDPBWTitle ()


    /**
     * Return the plot title. After the base plot title the net data 
     * type title is placed. Hereafter the fixed host title is included
     * when it exists, If one-directional traffic is is used, the net
     * data connection direction symbol is added to the end.
     *
     *    @param  base_title   The base title of the plot.
     *
     *    @param  host_index   The index of the fixed host. When it is
     *			       less than zero, no fixed hosts are used.
     *
     *    @return   The title of the plot.
     *
    ************************************************/
    private String  getPlotTitle (String  base_title,
				  int	  host_index)
    /***********************************************/
    {
	String  title_prefix = base_title		    + " " +
			       PLOT_TITLE_TRAILOR	    + " " +
			       current_data.getTypeTitle ();

	if (host_index < 0)    // No fixed host: add only plot trailor.
	{
	    return title_prefix;
	}
	else  // Fixed host: add plot trailor + host title ...
	{
	    String  plot_title = title_prefix + " " +
				 getHostTitle (host_index);

	    /*
	     * ... + net data connection direction symbol at one-
	     * directional net tests.
	     */

	    if (one_direct)
		plot_title += (" " + HOST_TO_LABEL);

	    return plot_title;    // Return the appropriate plot title.
	}

    } // getPlotTitle ()


    /**
     * Return the label of the plot ping axis. The ping type is
     * included to it.
     *
     *    @param  ping_type   The ping type.
     *
    ************************************************/
    private String  getPingAxisLabel (int  ping_type)
    /***********************************************/
    {
	return PLOT_PING_PREFIX			 + " " +
	       SHORT_PING_TYPE_NAMES [ping_type] + " " +
	       PING_TYPE_UNITS [ping_type];
    }


    /**
     * Return the label of the plot UDP bandwidth axis. The UDP
     * bandwidth type is included to it.
     *
     *    @param  udp_bw_type   The UDP bandwidth type.
     *
    ***************************************************/
    private String  getUDPBWAxisLabel (int  udp_bw_type)
    /**************************************************/
    {
	return AXIS_UDP_BW_PREFIX		     + " " +
	       SHORT_UDP_BW_TYPE_NAMES [udp_bw_type] + " " +
	       UDP_BW_TYPE_UNITS [udp_bw_type];
    }


    /**
     * Set the maximum date index which is the index of the most recent
     * date in the display. If this index is less than zero, the last
     * index of the date vector is returned. This is the most recent
     * date from the measurements. No maximum date index is set when
     * the index string is <CODE>null</CODE>.
     *
     *    @param  max_date_index_str   The index of the maximum date to
     *				       display.
     *
     *    @execption  NumberFormatException   Thrown when the specified
     *					      date index is incorrect.
     *
    **********************************************************/
    private void  setMaxDateIndex ( String  max_date_index_str
				  )
				  throws  NumberFormatException
    /*********************************************************/
    {
	if (max_date_index_str == null)    // Set no maximum date index.
	    return;

	int  new_date_index = Integer.parseInt (max_date_index_str);

	if (new_date_index < 0  ||  new_date_index >= dates.size ())
	{
	    max_date_index = dates.size () - 1;    // Use last date.
	}
	else
	{
	    max_date_index = new_date_index;    // Set max. date index.
	}

    } // setMaxDateIndex ()


    /**
     * Set the minimum date from the time domain which is the less
     * recent index to display. If the time domain is less than zero,
     * the less recent index in the time domain is used.
     *
    *******************************/
    private void  setMinDateIndex ()
    /******************************/
    {
	long  domain_time = current_data.getCurrentDomainTime ();

	if (domain_time < 0)    // Use the less recent date available.
	{
	    min_date_index = 0;

	    return;
	}

	/*
	 * Set the maximum (most recent) date.
	 */

	DateFormat  max_date = (DateFormat) dates.elementAt (
						max_date_index);

	/*
	 * The minimum time boundary, just not displayed, is the next
	 * minute when the time domain is substracted from the maximum
	 * date. All times are in [ms].
	 */

	long  min_time_bound = max_date.getNextMinuteTimeInMS () -
				   domain_time;

	/*
	 * Go back in the date history while the current date is larger
	 * than the minimum time boundary. The last index found is the
	 * index of the minimum (less recent) date in the display.
	 */

	boolean  in_domain = true;    // Still in time domain.

	min_date_index = max_date_index;   // Start at the maximum date.

	while (in_domain  &&  min_date_index > 0) // Go back in history.
	{
	    DateFormat  date = (DateFormat) dates.elementAt (
						min_date_index);

	    if (date.getTimeInMSSkipSec () > min_time_bound)
		min_date_index--;
	    else
		in_domain = false;    // Out of the domain.
	}

	/*
	 * Go one up when we are out of the domain and when we are not
	 * yet at the maximum date index.
	 */

	 if (!in_domain  &&  min_date_index < max_date_index)
	    min_date_index++;

    } // setMinDateIndex ()


    /**
     * Return the index of the fixed host. If the specified index string
     * is <CODE>null</CODE>, the index currently used is returned. When
     * the index is less than zero all traces are plotted. This is also
     * stored in the class instance <CODE>plot_all</CODE>. It is mainly
     * used to toggle between fixed host / all plot shown in
     * <CODE>handlePlotShow()</CODE>.
     *
     *    @param  host_index_str   The fixed host index string.
     *
     *    @return  The index of the fixed host.
     *
     *    @exception  NumberFormatException  Thrown after a parse error
     *					     of the host index string.
     *
    ******************************************************/
    private int  getHostIndex ( String  host_index_str
			      )
			      throws  NumberFormatException
    /*****************************************************/
    {
	if (host_index_str == null)   // Return the current fixed index.
	{
	    if (plot_all)     // All data are plotted.
		return -1;
	    else
		return fixed_host_index;    // Return the fixed index.
	}
	else    // Set the new fixed host index.
	{
	    int  host_index = Integer.parseInt (host_index_str);

	    if (host_index < 0)    // All data are plotted.
	    {
		plot_all	 = true;
	    }
	    else    // Set the fixed host index.
	    {
		plot_all	 = false;
		fixed_host_index = host_index;
	    }

	    return host_index;    // Return the new fixed host index.

	} // Set the new fixed host index.

    } // getHostIndex ()


    /**
     * Return the ping type specified by the ping type string. When the
     * string is <CODE>null</CODE>, the current ping type is returned.
     *
     *    @param  ping_type_str   The ping type string.
     *
     *    @return  The ping type.
     *
     *    @exception  NumberFormatException   Thrown after a parse error
     *					      in the ping type string.
     *
    *****************************************************/
    private int  getPingType ( String  ping_type_str
			     )
			     throws  NumberFormatException
    /****************************************************/
    {
	if (ping_type_str != null)
	    ping_type = Integer.parseInt (ping_type_str);

	return ping_type;
    }


    /**
     * Return the UDP bandwidth type specified by the UDP bandwidth type
     * string. When the string is <CODE>null</CODE>, the current UDP
     * bandwidth type is returned.
     *
     *    @param  udp_bw_type_str   The UDP bandwidth type string.
     *
     *    @return   The UDP bandwidth type.
     *
     *    @exception  NumberFormatException   Thrown after a parse error
     *					      in the UDP bandwidth type
     *					      string.
     *
    ******************************************************/
    private int  getUDPBWType ( String  udp_bw_type_str
			      )
			      throws  NumberFormatException
    /*****************************************************/
    {
	if (udp_bw_type_str != null)
	    udp_bw_type = Integer.parseInt (udp_bw_type_str);

	return udp_bw_type;
    }


    /**
     * Set the dates to the plot window frame. Therefore, they are split
     * in pure date and time parts. Note that this function is only used
     * when the plot date values are used at the date coordinate ticks.
     *
    **********************/
    void  setDatesToPlot ()
    /*********************/
    {
	DateFormat  date_format;
	String	    time_or_id;
	int	    date_index;
	int	    buff_index;

	/*
	 * Allocate storage for the pure date and time arrays.
	 */

	String []  date_ar = new String [max_date_index + 1];
	String []  time_ar = new String [max_date_index + 1];

	/*
	 * Fill the pure date and time arrays from the date vector. To
	 * the dates no years are added. To the times no seconds are
	 * added. If a date ID hashtable exists, the date ID values are
	 * used in the place of the short times, at least when they
	 * exist.
	 */

	Hashtable  date_id_table = current_data.getDateIDTable ();

	for ( date_index = min_date_index;
	      date_index <= max_date_index;
	      date_index++ )
	{
	    date_format = (DateFormat) dates.elementAt (date_index);
	    buff_index  = max_date_index - date_index;

	    if (date_id_table == null)    // Get short time.
	    {
		time_or_id = date_format.getShortTime ();
	    }
	    else    // Get date ID in the place of short time.
	    {
		time_or_id = (String)
			     date_id_table.get (date_format.getDate ());

		/*
		 * Replace non-existing date IDs by empty strings.
		 */

		if (time_or_id == null)
		    time_or_id = "";
	    }

	    /*
	     * Store the short date and the time/date ID found above.
	     */

	    date_ar [buff_index] = date_format.getShortDate ();
	    time_ar [buff_index] = time_or_id;
	}

	/*
	 * Set the pure date and time arrays to the plot window frame.
	 */
	 
	data_plot_window.setDates (date_ar, time_ar);

    } // setDatesToPlot ()


    /**
     * Set the time offset to the plot. It is the next hour after the
     * maximum date. Note that this function is only used when the
     * dates are rounded ad the date ticks.
     *
    ***********************************/
    private void  setTimeOffsetToPlot ()
    /**********************************/
    {
	DateFormat  date_format = (DateFormat) dates.elementAt (
						   max_date_index);

	time_offset = date_format.getNextHourTimeInMS ();

	data_plot_window.setTimeOffset (time_offset);
    }

    /**
     * Set the date ID hashtable and the date formats uased at the plot,
     * in the same order as the date coordinates, to the plot. For both
     * values <CODE>null</CODE> is used when no date ID hashtable is
     * specified. When a hashtable is used, new storage is created.
     *
    *****************************************/
    private void  setDateIDParametersToPlot ()
    /****************************************/
    {
	Hashtable  date_id_table = current_data.getDateIDTable ();

	if (date_id_table == null)
	    data_plot_window.setDateIDParameters (null, null);
	else
	{
	    Hashtable  date_id_table_clone =
		(Hashtable) date_id_table.clone ();

	    data_plot_window.setDateIDParameters (
		    date_id_table_clone, getPlotDateVector ());
	}
    }


    /**
     * Return the private plot controls as a component array. This
     * function is part of the <CODE>ExternPlotControls</CODE>
     * interface. It is called from the <CODE>DataPlotWindow</CODE>
     * class instance.
     * </P>
     *
     * <P>
     * Note that there are different control for the load data plot and
     * for the net data (ping and throughput) plots. The reason is that
     * at the load data always all plot traces can be plotted.
     *
     *    @return  The plot control component array.
     *
    **************************************/
    public Component []  getPlotControls ()
    /*************************************/
    {
	/*
	 * In variable control_type "control_type" is the alst plot type
	 * stored after the controls are adjusted in
	 * "adjustPlotControls()".
	 */

	if (control_type == LOAD_PLOT)
	    return load_controls;
	else
	    return plot_controls;
    }


    /**
     * Handle an action event at one of the private plot controls.
     * Return if the action event indeed did occur at one of the plot
     * controls. This function is part of the
     * <CODE>ExternPlotControls</CODE> interface. It is called from the
     * <CODE>DataPlotWindow</CODE> class instance.
     *
     *    @param  event    The action event to handle.
     *
     *    @param  object   The target object of the action event.
     *
     *    @return   True when the event did occur at one of the plot
     *		    controls. False when this was not the case.
     *
    *************************************************/
    public boolean  plotControlAction (Event   event,
				       Object  object)
    /************************************************/
    {
	/*
	 * Set the target object.
	 */

	Object  target = event.target;

	/*
	 * Parse the target object.
	 */

	if (target == show_button)   // Show all hosts / fixed host.
	{
	    handlePlotShow ();
	    return true;
	}
	else if (target == scaling_button) // Linear/Log Y-axis scaling.
	{
	    handleYScaling ();
	    return true;
	}
	else if (target == first_button)    // First time domain.
	{
	    handleFirstDomain ();
	    return true;
	}
	else if (target == prev_button)    // Previous time domain.
	{
	    handlePreviousDomain ();
	    return true;
	}
	else if (target == next_button)    // Next time domain.
	{
	    handleNextDomain ();
	    return true;
	}
	else if (target == current_data.getDomainChoice ()) // A time
	{						    // domain is
	    handleSetDomain ();				    // selected.
	    return true;
	}
	else    // None of the private plot controls.
	{
	    return false;
	}

    } // plotControlAction ()


    /**
     * Handle the setting of the first time domain by an action event.
     * This is done by setting the maximum date index to the last index
     * in the date and by replotting the plot frame. Note that the
     * minimum date index is set when the plot data are added to the
     * plot during the replotting.
     *
    *********************************/
    private void  handleFirstDomain ()
    /********************************/
    {
	int  last_max_date_index = dates.size () - 1;

	/*
	 * Do not replot anything when we are already at the last date
	 * index.
	 */

	if (max_date_index == last_max_date_index)
	    return;

	max_date_index = last_max_date_index;
	replot ();
    }


    /**
     * Handle the setting of the previous time domain by an action
     * event. This is done by setting the maximum date index to the
     * previous time domain and replotting the data. The minimum index
     * is set during the replot.
     *
    ************************************/
    private void  handlePreviousDomain ()
    /***********************************/
    {
	int  last_max_date_index = dates.size () - 1;

	/*
	 * Do nothing when the max date index was already the last one.
	 */

	if (max_date_index == last_max_date_index)
	    return;

	/*
	 * Store the current max date index.
	 */

	int  curr_max_date_index = max_date_index;

	/*
	 * Get the current maximum date.
	 */

	DateFormat  max_date = (DateFormat) dates.elementAt (
						max_date_index);

	/*
	 * The maximum time boundary is the current maximum time with
	 * the seconds skipped added by the time domain.
	 */

	long  max_time_bound = max_date.getTimeInMSSkipSec	 () +
			       current_data.getCurrentDomainTime ();

	/*
	 * Go to recent dates when di not pass the maximum date
	 * boundary.
	 */

	boolean  in_domain = true;

	while (in_domain  &&  max_date_index < last_max_date_index)
	{
	    DateFormat  date = (DateFormat) dates.elementAt (
						max_date_index);

	    if (date.getNextMinuteTimeInMS () < max_time_bound)
		max_date_index++;
	    else
		in_domain = false;
	}

	/*
	 * Substract one from the maximum date when we are out of the
	 * time domain and we are not at the last date index.
	 */

	if (!in_domain  &&  max_date_index > 0)
	    max_date_index--;

	/*
	 * Go one date further when the maximum date is unchanged and
	 * we are not yet at the last maximum date.
	 */

	if ( max_date_index == curr_max_date_index  &&  
	     max_date_index <  last_max_date_index )
	{
	    max_date_index++;
	}

	/*
	 * Replot the plot frame with the new time domain.
	 */

	replot ();

    } // handlePreviousDomain ()


    /**
     * Handle the setting of the next time domain by an action event.
     * This is done by setting the maximum date index to the current
     * minimum date index and replotting the plot frame. The minimum
     * date index is redefined during the replot.
     *
    ********************************/
    private void  handleNextDomain ()
    /*******************************/
    {
	/*
	 * Nothing can't be done when we are already at the last date.
	 */

	if (min_date_index == 0)
	    return;

	/*
	 * Go 1 date back when the maximum date is already equal to the
	 * minimum date and the last date is not yet reached. In all
	 * other cases the max date index is set to the current
	 * minimum date index.
	 */

	if (max_date_index == min_date_index  &&  max_date_index > 0)
	    max_date_index--;
	else
	    max_date_index = min_date_index;

	/*
	 * Replot the plot frame with the next time domain.
	 */

	replot ();

    } // handleNextDomain ()


    /**
     * Handle the setting of a new time domain value by an action event.
     * This is done by obtaining the new domain index from the domain
     * selector and looking up the domain value which belongs to this
     * index.
    *******************************/
    private void  handleSetDomain ()
    /******************************/
    {
	/*
	 * Lookup the time domain using the selected domain index.
	 */

	ControlChoice  domain_choice = current_data.getDomainChoice ();

	int   domain_index  = domain_choice.getSelectedIndex ();
	long  new_domain    = current_data.getDomainTime (domain_index);

	/*
	 * Nothing must be done when the index is unchanged.
	 */

	if (new_domain == current_data.getCurrentDomainTime ())
	    return;

	current_data.setCurrentDomainTime (new_domain);
	replot				  ();
    
    } // handleSetDomain ()


    /**
     * Handle the toggling between show fixed host / show all plots by
     * the action event. Replot the data after a toggle.
     *
    ******************************/
    private void  handlePlotShow ()
    /*****************************/
    {
	plot_all = !plot_all;    // Toggle show all / show fixed host.
	replot ();		 // Replot the plot frame.
    }


    /**
     * Handle the toggling between linear&nbsp;/ logarithmic Y-scaling.
     * Changed the setting of the currently selected plot type to
     * control. Replot the data after a toggle.
     *
    ******************************/
    private void  handleYScaling ()
    /*****************************/
    {
       	if (control_scale.value == PlotCanvas.LINEAR)
	{
	    control_scale.value = PlotCanvas.LOG;
	}
	else    // PlotCanvas.LOG.
	{
	    control_scale.value = PlotCanvas.LINEAR;
	}

	replot ();
    }


    /**
     * Replot the plot frame. This is performed by resetting the current
     * net data to the plot frame and replotting it by the appropriate
     * plot function.
     * </P>
     *
     * <P>
     * All plot function are called with <CODE>null</CODE> arguments.
     * This forces the reuse of the current plot data.
     *
    **********************/
    private void  replot ()
    /*********************/
    {
	switch (plot_type)    // Select the plot function to use.
	{
	    case LOAD_PLOT :    // Replot the current load data.

		plotLoadData (null);
		break;

	    case PING_PLOT :    // Replot the current ping data.

		plotPingData (null, null, null);
		break;

	    case THROUGHPUT_PLOT :    // Replot the current tput data.

		plotThroughputData (null, null);
		break;

	    case UDP_BW_PLOT :    // Replot the current UDP BW data.

		plotUDPBWData (null, null, null);
		break;

	    default :    // No plot defined yet: do nothing.

		break;

	} // Select the plot function.

    } // replot ()


    /**
     * Adjust the plot controls before the plot frame is shown. This
     * function is part of the <CODE>ExternPlotControls</CODE>
     * interface. It is called from the <CODE>DataPlotWindow</CODE>
     * class instance.
     *
    *********************************/
    public void  adjustPlotControls ()
    /********************************/
    {
	/*
	 * Store the current plot type such that the implementation of
	 * this interface is able to return the correct array plot
	 * controls by this interface function "getPlotControls()".
	 */

	control_type = plot_type;

	/*
	 * Set the Y-axis scaling type to be used by the current plot.
	 */

	switch (control_type)
	{
	    case PING_PLOT :    // Scale currently ping data.

		control_scale = ping_scale;
		break;

	    case THROUGHPUT_PLOT :    // Scale currently tput data.

		control_scale = throughput_scale;
		break;

	    case UDP_BW_PLOT :    // Scale currently UDP bandwidth data.

		control_scale = udp_bw_scale;
		break;

	    default :    // LOAD_PLOT; always linear Y-scaling.

		load_scale.value = PlotCanvas.LINEAR;  // Just for sure.
		control_scale	 = load_scale;
		break;
	}

	/*
	 * Set the Y-scaling in the data plot.
	 */

	data_plot.setYScaling (control_scale.value);

	/*
	 * Adjust the label and status message of the show all / show
	 * fixed host button.
	 */

	if (plot_all)    // Button leads to host plot traces.
	{
	    String  host_title	  = getHostTitle (fixed_host_index);
	    String  label_prefix  = SHOW_LABEL  + " " + host_title;
	    String  status_prefix = SHOW_STATUS + " " + host_title;

	    if (one_direct)    // One-directional.
	    {
		show_button.setLabel		 (label_prefix  + " " +
						  HOST_TO_LABEL);
		show_button.setMouseEnterMessage (status_prefix + " " +
						  HOST_TO_LABEL);
	    }
	    else    // Two-directional.
	    {
		show_button.setLabel		 (label_prefix);
		show_button.setMouseEnterMessage (status_prefix);
	    }
	}
	else    // Button leads to all plot traces.
	{
	    show_button.setLabel	     (SHOW_ALL_LABEL);
	    show_button.setMouseEnterMessage (SHOW_ALL_STATUS);
	}

	/*
	 * Adjust the label and the mouse enter status message of the
	 * linear / logarithmic Y-axis scaling button when available.
	 */

	if (control_scale.value == PlotCanvas.LOG)
	{
	    scaling_button.setLabel		(LINEAR_LABEL);
	    scaling_button.setMouseEnterMessage (LINEAR_STATUS);
	}
	else    // PlotCanvas.LINEAR.
	{
	    scaling_button.setLabel		(LOG_LABEL);
	    scaling_button.setMouseEnterMessage (LOG_STATUS);
	}

	/*
	 * Enable (disable) the first and previous time domain buttons
	 * if they are (not) required.
	 */

	int  last_max_date_index = dates.size () - 1;

	if (max_date_index == last_max_date_index)  // Most recent dom.
	{
	    first_button.disable ();
	    prev_button.disable  ();
	}
	else    // Oldest domain.
	{
	    first_button.enable  ();
	    prev_button.enable   ();
	}

	/*
	 * Enable (disable) the next time domain button if it is (not)
	 * required.
	 */

	if (min_date_index == 0)      // Most recent domain.
	    next_button.disable ();
	else			      // Oldest domain.
	    next_button.enable  ();

	/*
	 * Replace the domain choice when a new net data type is used.
	 */

	ControlChoice  domain_choice = current_data.getDomainChoice ();

	if (domain_choice != dom_choice_add)
	{
	    domain_panel.remove		 (dom_choice_add);
	    addDomainChoiceToDomainPanel (domain_choice);
	}
    
    } // adjustPlotControls ()


    /**
     * Add the load data from the specified host to the plot window
     * frame. Mark missing load data for a specified date by breaking
     * the line, joining the data points, when line joining is selected.
     *
     *    @param  host_index   The index of the host from which the load
     *			       data are added.
     *
     *    @exception  NumberFormatException   Thrown at a bad formatted
     *					      load value string.
     *
    ************************************************************/
    private void  addLoadDataToPlot ( int  host_index
				    )
				    throws  NumberFormatException
    /***********************************************************/
    {
	/*
	 * Allocate the storage for the load plot data in the current
	 * time domain.
	 */

	Vector  load_trace = new Vector (max_date_index + 1 -
					 min_date_index);

	String   load_value;
	Double   x;
	Double   y;
	boolean  joined = false;    // No line joined at the start.

	/*
	 * Add the plot data within the time domain to the storage. Add
	 * one "null" data point to break the line, joining the data
	 * points, when load data are missing for a specific date.
	 */

	for ( int date_index =  max_date_index;
		  date_index >= min_date_index;
		  date_index-- )
	{
	    load_value = getLoadValue (host_index, date_index);

	    if (load_value.equals (DATA_VALUE_NOT_FOUND))   // No load
	    {
		/*
		 * Add a "null" data point to break the line when no
		 * such data point was yet there.
		 */

		if (joined)    // Line not yet broken.
		{
		    load_trace.addElement (null);
		    joined = false;
		}
	    }
	    else    // Load data are available for this date.
	    {
		x = getPlotDate (date_index);
		y = new Double  (load_value);

		load_trace.addElement (new DataPoint (x, null, null,
						      y, null, null));

		joined = true;    // Line joined.
	    }
	}

	/*
	 * Add the plot trace to the plot window frame.
	 */

	data_plot_window.addTrace (load_trace,
				   getHostTitle   (host_index),
				   getLoadHostKey (host_index));

    } // addLoadDataToPlot ()


    /**
     * Add the ping data with the specified type from the connection
     * between the two specified hosts to the plot window frame. Mark
     * missing ping data for a specified date by breaking the line,
     * joining the data points, when line joining is selected. Do not
     * add the ping data when the connection is skipped and when there
     * are no data for this connection available.
     *
     *    @param  host_1_index		The 1th host used for the ping
     *					data.
     *
     *	  @param  host_2_index		The 2th host used for the ping
     *					data.
     *
     *	  @param  ping_type		The ping type.
     *
     *	  @param  net_type		The net connection type.
     *
     *	  @param  net_title		The net connection title.
     *
     *    @param  label_both_hosts	Set the titles of the specified
     *					hosts in the plot trace label.
     *
     *    @param  label_hosts_reverse   True: label the hosts in the
     *					plot trace in the reverse order
     *					as they are specified here.
     *
     *	  @exception  Exception   Thrown after a parsing error when the
     *				  ping value from the specified type is
     *				  obtained.
     *
    *************************************************************/
    private void  addPingDataToPlot ( int      host_1_index,
				      int      host_2_index,
				      int      ping_type,
				      String   net_type,
				      String   net_title,
				      boolean  label_both_hosts,
				      boolean  label_hosts_reverse
				    )
				    throws Exception
    /************************************************************/
    {
	/*
	 * Allocate the storage for the ping plot data in the current
	 * time domain.
	 */

	Vector  ping_trace = new Vector (max_date_index + 1 -
					 min_date_index);

	/*
	 * Set the net type label, used in the plot trace label, when
	 * both QoS and Internet net types are used.
	 */

	String  net_type_label = (qos_and_inet ? " " + net_title : "");

	String	 ping_value;
	Double   x;
	Double   y;
	Double   dyh;
	Double   dyl;
	boolean  joined = false;    // No line joined at the start.

	/*
	 * Add the plot data within the time domain to the trace
	 * storage.
	 */

	for ( int date_index = max_date_index;
	      date_index >= min_date_index;
	      date_index-- )
	{
	    /*
	     * Get the ping value as string from the ping storage,
	     * specified by hosts and date indices and by the specified
	     * net type.
	     */

	    ping_value = getDataValue (ping_data,
				       host_1_index,
				       host_2_index,
				       date_index,
				       net_type,
				       false);

	    /*
	     * Add the ping data to the plot when a value was found. Add
	     * one "null" data point to break the line, joining the data
	     * points, when ping data are missing for a specific date.
	     */

	    if (ping_value.equals (DATA_VALUE_NOT_FOUND))    // No ping.
	    {
		/*
		 * Add a "null" data point to break the line when no
		 * such data point was yet there.
		 */

		if (joined)    // Line not yet broken.
		{
		    ping_trace.addElement (null);
		    joined = false;
		}
	    }
	    else    // Ping data are available for this date.
	    {
		/*
		 * Set the ping string in the ping class instance to
		 * parse it.
		 */

		ping.set (ping_value);

		/*
		 * Add the ping data to the plot when also all the ping
		 * type value fields are defined.
		 */

		if (ping.isDefined ())
		{
		    /*
		     * Get the plot date X coordinate.
		     */

		    x = getPlotDate (date_index);

		    /*
		     * Parse the ping value. Use error bars when all
		     * ping values should be displayed.
		     */

		    if (ping_type == PingFormat.ALL_TYPE) // All ping's.
		    {
			Double  yh;
			Double  yl;
			double  yav;

			/*
			 * Set the ping value with error bars in the
			 * domain [<avg> - <min>, <max> - <avg>].
			 */

			y   = new Double (
				      ping.get (PingFormat.AVG_TYPE));
			yh  = new Double (
				      ping.get (PingFormat.MAX_TYPE));
			yl  = new Double (
				      ping.get (PingFormat.MIN_TYPE));

			/*
			 * Set the values and error bar values which are
			 * below the minimum logarithmic value to this
			 * value when logarithmic Y-scaling is used.
			 */

			if (ping_scale.value == PlotCanvas.LOG)
			{
			    if (y.doubleValue () < MIN_LOG_PING_VALUE)
				y = MIN_LOG_PING;

			    if (yh.doubleValue () < MIN_LOG_PING_VALUE)
				yh = MIN_LOG_PING;

			    if (yl.doubleValue () < MIN_LOG_PING_VALUE)
				yl = MIN_LOG_PING;
			}

			yav = y.doubleValue ();
			dyh = new Double (yh.doubleValue () - yav);
			dyl = new Double (yav - yl.doubleValue ());
		    }
		    else    // Show <min>, <avg>, <max> ping value.
		    {
			y   = new Double (ping.get (ping_type));
			dyh = null;
			dyl = null;

			/*
			 * Set the ping value to the minimum logarithmic
			 * value when logarithmic Y-scaling is used if
			 * it is too small.
			 */

			if ( ping_scale.value == PlotCanvas.LOG  &&
			     y.doubleValue () < MIN_LOG_PING_VALUE )
			{
			    y = MIN_LOG_PING;
			}
		    }

		    /*
		     * Add the ping data to the plot trace.
		     */

		    ping_trace.addElement (new DataPoint (x, null, null,
							  y, dyh, dyl));

		    joined = true;    // Line joined.

		} // All ping data type values are defined.

	    } // A ping value was found.

	} // Add the plot data to the trace storage.

	/*
	 * Add the plot trace to the plot window frame, but only when
	 * the connection is not skipped or when there are still plot
	 * data from a skipped connection available.
	 */

	String  hosts_label = getHostsLabel   (host_1_index,
					       host_2_index,
					       net_type_label,
					       label_both_hosts,
					       label_hosts_reverse);
	String  hosts_key   = getDataHostsKey (host_1_index,
					       host_2_index,
					       net_type);

	if ( !skip_conns.isSkipped (hosts_key)  ||
	     ping_trace.size () > 0 )
	{
	    data_plot_window.addTrace (ping_trace,
				       hosts_label,
				       hosts_key);
	}

    } // addPingDataToPlot ()


    /**
     * Add the throughput data from the conection between the two
     * specified hosts to the plot window frame. Mark missing throughput
     * data for a specified data by breaking the line, joining the data
     * points, when line joining is selected. Do not add the throughput
     * data when the connection is skipped and when there are no data
     * for this connection available.
     *
     *    @param  host_1_index		The 1th host used for the
     *					throughput data.
     *
     *    @param  host_2_index		The 2th host used for the
     *					throughput data.
     *
     *	  @param  net_type		The net connection type.
     *
     *	  @param  net_title		The net connection title.
     *
     *    @param  label_both_hosts	Set the titles of the specified
     *					hosts in the label of the plot
     *					trace.
     *
     *    @param  label_hosts_reverse	True: label the hosts in the
     *					plot trace in the reverse order
     *					as they are specified here.
     *
     *    @exception  NumberFormatException    Thrown at a bad formatted
     *					       throughput value string.
     *
    *******************************************************************/
    private void  addThroughputDataToPlot ( int      host_1_index,
					    int      host_2_index,
					    String   net_type,
					    String   net_title,
					    boolean  label_both_hosts,
					    boolean  label_hosts_reverse
					  )
					  throws  NumberFormatException
    /******************************************************************/
    {
	/*
	 * Allocate the storage for the throughput plot data in the
	 * current time domain.
	 */

	Vector  throughput_trace = new Vector (max_date_index + 1 -
					       min_date_index);

	/*
	 * Set the net type label, used in the plot trace label, when
	 * both QoS and Internet net types are used.
	 */

	String  net_type_label = (qos_and_inet ? " " + net_title : "");

	String   throughput_value;
	Double   x;
	Double   y;
	boolean  joined = false;    // No line joined at the start.

	/*
	 * Add the plot data within the time domain to the trace
	 * storage.
	 */

	for ( int date_index = max_date_index;
	      date_index >= min_date_index;
	      date_index-- )
	{
	    /*
	     * Get the throughput as string from the throughput storage,
	     * specified by hosts and date indices and by the specified
	     * net type.
	     */

	    throughput_value = getDataValue (throughput_data,
					     host_1_index,
					     host_2_index,
					     date_index,
					     net_type,
					     false);

	    /*
	     * Add the throughput data to the plot when a value was
	     * found. Add one "null" data point to break the line,
	     * joining the data points, when throughput data are missing
	     * for a specific date.
	     */

	    if (throughput_value.equals (DATA_VALUE_NOT_FOUND)) // No
	    {							// tput.
		/*
		 * Add a "null" data point to break the line when no
		 * such data point was yet there.
		 */

		if (joined)    // Line not yet broken.
		{
		    throughput_trace.addElement (null);
		    joined = false;
		}
	    }
	    else    // Throughput data are available for this date.
	    {
		/*
		 * Set the plot coordinates.
		 */

		x = getPlotDate (date_index);
		y = new Double  (throughput_value);

		/*
		 * Set the throughput value to the minimum logarithmic
		 * value when logarithmic Y-scaling is used if it is
		 * too small.
		 */

		if ( throughput_scale.value == PlotCanvas.LOG  &&
		     y.doubleValue () < MIN_LOG_THROUGHPUT_VALUE )
		{
		    y = MIN_LOG_THROUGHPUT;
		}

		/*
		 * Add the throughput data to the plot trace.
		 */

		throughput_trace.addElement (
		    new DataPoint (x, null, null, y, null, null));

		joined = true;    // Line joined.

	    } // A throughput value was found.

	} // Add the plot data to the trace storage.

	/*
	 * Add the plot trace to the plot window frame, but only when
	 * the connection is not skipped and when there are still plot
	 * data from a skipped connection available.
	 */
				  
	String  hosts_label = getHostsLabel   (host_1_index,
					       host_2_index,
					       net_type_label,
					       label_both_hosts,
					       label_hosts_reverse);
	String  hosts_key   = getDataHostsKey (host_1_index,
					       host_2_index,
					       net_type);

	if ( !skip_conns.isSkipped (hosts_key)  ||
	     throughput_trace.size () > 0 )
	{
	    data_plot_window.addTrace (throughput_trace,
				       hosts_label,
				       hosts_key);
	}

    } // addThroughputDataToPlot ()


    /**
     * Add the UDP bandwidth data with the specified type from the
     * connection between the two specified hosts to the plot window
     * frame. Mark missing UDP bandwidth data for a specified date by
     * breaking the line, joining the data points, when line joining is
     * selected. Do not add the UDP bandwidth data when the connection
     * is skipped and when there are no data for this connection
     * available.
     *
     *    @param  host_1_index		The 1th host used for the UDP
     *					bandwidth data.
     *
     *	  @param  host_2_index		The 2th host used for the UDP
     *					bandwidth data.
     *
     *	  @param  udp_bw_type		The UDP bandwidth type.
     *
     *	  @param  net_type		The net connection type.
     *
     *	  @param  net_title		The net connection title.
     *
     *	  @param  label_both_hosts	Set the titles of the specified
     *					hosts in the plot trace label.
     *
     *    @param  label_hosts_reverse   True: lablel the hosts in the
     *					plot trace in the reverse order
     *					as they are specified here.
     *
     *    @exception  Exception   Thrown after a parsing error when the
     *				  UDP bandwidth value from the specified
     *				  type is obtained.
     *
    **************************************************************/
    private void  addUDPBWDataToPlot ( int	host_1_index,
				       int	host_2_index,
				       int	udp_bw_type,
				       String	net_type,
				       String	net_title,
				       boolean	label_both_hosts,
				       boolean  label_hosts_reverse
				     )
				     throws Exception
    /*************************************************************/
    {
	/*
	 * Allocate the storage for the UDP bandwidth plot data in the
	 * current time domain.
	 */

	Vector  udp_bw_trace = new Vector (max_date_index + 1 -
					   min_date_index);

	/*
	 * Set the net type label, used in the plot trace label, when
	 * both QoS and Internet net types are used.
	 */

	String  net_type_label = (qos_and_inet ? " " + net_title : "");

	String   udp_bw_value;
	Double	 x;
	Double	 y;
	boolean  joined = false;    // No line joined at the start.

	/*
	 * Add the plot data within the time domain to the trace
	 * storage.
	 */

	for ( int date_index = max_date_index;
	      date_index >= min_date_index;
	      date_index-- )
	{
	    /*
	     * Get the UDP bandwidth value as string from the UDP
	     * bandwidth storage, specified by hosts and date indices
	     * and by the specified net type.
	     */

	    udp_bw_value = getDataValue (udp_bw_data,
					 host_1_index,
					 host_2_index,
					 date_index,
					 net_type,
					 false);

	    /*
	     * Add the UDP bandwidth data to the plot when a value was
	     * found. Add one "null" data point to break the line,
	     * joining the data points, when UDP bandwidth data are
	     * missing for a specific date.
	     */

	    if (udp_bw_value.equals (DATA_VALUE_NOT_FOUND))    // No UDP
	    {						       // BW.
		/*
		 * Add a "null" data point to break the line when no
		 * such data point was yet there.
		 */

		if (joined)    // Line not yet broken.
		{
		    udp_bw_trace.addElement (null);
		    joined = false;
		}
	    }
	    else    // UDP bandwidth data are available for this date.
	    {
		/*
		 * Set the UDP bandwidth string in the UDP bandwidth
		 * class instance to parse it.
		 */

		udp_bw.set (udp_bw_value);

		/*
		 * Add the UDP bandwidth data to the plot when all the
		 * UDP bandwidth type values are defined.
		 */

		if (udp_bw.isDefined ())
		{
		    /*
		     * Get the plot date X coordinate.
		     */

		    x = getPlotDate (date_index);

		    /*
		     * Parse the UDP bandwidth value.
		     */

		    y = new Double (udp_bw.get (udp_bw_type));

		    /*
		     * Set the UDP bandwidth value to the minimum
		     * logarithmic value when logarithmic Y-scaling is
		     * used if it is too small.
		     */

		    if ( udp_bw_scale.value == PlotCanvas.LOG  &&
			 y.doubleValue () < MIN_LOG_UDP_BW_VALUE )
		    {
			y = MIN_LOG_UDP_BW;
		    }

		    /*
		     * Add the UDP bandwidth data to the plot trace.
		     */

		    udp_bw_trace.addElement (
			new DataPoint (x, null, null, y, null, null));

		    joined = true;    // Line joined.

		} // All UDP bandwidth data type values are defined.

	    } // An UDP bandwidth value was found.

	} // Add the plot data to the trace storage.

	/*
	 * Add the plot trace to the plot window frame, but only when
	 * the connection is not skipped or when there are still plot
	 * data from a skipped connection available.
	 */

	String  hosts_label = getHostsLabel   (host_1_index,
					       host_2_index,
					       net_type_label,
					       label_both_hosts,
					       label_hosts_reverse);
	String  hosts_key   = getDataHostsKey (host_1_index,
					       host_2_index,
					       net_type);

	if ( !skip_conns.isSkipped (hosts_key)  ||
	     udp_bw_trace.size () > 0 )
	{
	    data_plot_window.addTrace (udp_bw_trace,
				       hosts_label,
				       hosts_key);
	}

    } // addUDPBWDataToPlot ()


    /**   
     * Get the hosts label from the specified parameters.
     *
     *    @param  host_1_index	     The 1th host to be (possibly) put
     *				     in the label.
     *
     *	  @param  host_2_index	     The 2th host which is always put in
     *				     the label.
     *
     *    @param  net_type_label     The net type label.
     *
     *    @param  label_both_hosts   Set the titles of both specified
     *				     hosts in the label. If false: only
     *				     the 2th host is placed in the
     *				     label.
     *
     *	  @param  reverse_hosts      When true: reverse the hosts to
     *				     label. Also the direction mark
     *				     between the hosts is reversed.
     *
     *    @return   The hosts label.
     *
    ********************************************************/
    private String  getHostsLabel (int	    host_1_index,
				   int	    host_2_index,
				   String   net_type_label,
				   boolean  label_both_hosts,
				   boolean  reverse_hosts)
    /*******************************************************/
    {
	String  host_direct_label;

	/*
	 * Reverse the host indices when selected. Also set the
	 * corresponding direction label.
	 */

	if (reverse_hosts)    // Treat 2th host as 1th one.
	{
	    int swap_index;

	    swap_index   = host_1_index;
	    host_1_index = host_2_index;
	    host_2_index = swap_index;

	    host_direct_label = HOST_FROM_LABEL;
	}
	else    // Keep hosts in this order.
	{
	    host_direct_label = HOST_TO_LABEL;
	}

	if (label_both_hosts)    // Label both hosts for connection.
	{
	    return getHostTitle (host_1_index) + " " +
		   host_direct_label	       + " " +
		   getHostTitle (host_2_index) + net_type_label;
	}
	else if (one_direct)    // One-directional: connection in title.
	{
	    return getHostTitle (host_2_index) + net_type_label;
	}
	else    // Two-directional: label also connection direction.
	{
	    return host_direct_label	       + " " +
		   getHostTitle (host_2_index) + net_type_label;
	}

    } // getHostLabel ()


    /**
     * Get a new vector with <CODE>DateFormat</CODE> objects which
     * corresponds with the plotted dates.
     *
     *    @return  The vector with date format objects.
     *
    ***********************************/
    private Vector  getPlotDateVector ()
    /**********************************/
    {
	/*
	 * Create the plot date vector.
	 */
	 
	Vector  date_vector = new Vector (max_date_index + 1 -
					  min_date_index);

	/*
	 * Add the date formats to plot in reverse order: also
	 * increasing history.
	 */

	for ( int date_index =  max_date_index;
		  date_index >= min_date_index;
		  date_index-- )
	{
	    date_vector.addElement (dates.elementAt (date_index));
	}

	/*
	 * Return the date vector.
	 */

	return date_vector;

    } // getPlotDateVector ()


    /**
     * Return the date as plot coordinate.
     * </P>
     *
     * <P>
     * If the date grid is used in the ticks the (positive) index
     * relative to the  most recent date is returned.
     * </P>
     *
     * <P>
     * If the date values are interpolated to obtain the date grid
     * ticks, the time difference in [ms] is returned.
     *
     *    @param  date_index   The index of the date.
     *
     *    @return   The date coordinate.
     *
    ********************************************/
    private Double  getPlotDate (int  date_index)
    /*******************************************/
    {
	if (ROUND_DATE_GRID)    // Date grid values in ticks.
	{
	    return  new Double ((double) max_date_index - date_index);
	}
	else    // Interpolate between dates.
	{
	    DateFormat  date = (DateFormat) dates.elementAt (
						date_index);

	    /*
	     * Set the (positive) offset from the most recent time. The
	     * seconds are skipped.
	     */

	    long  time = time_offset - date.getTimeInMSSkipSec ();

	    return  new Double ((double) time);
	}

    } // getPlotDate ()


    /**
     * Return the load value for the host and date (plus time) at the
     * specified indices. If no value could be found the string
     * &quot;-1&quot; is returned. The value is returned with a new
     * <CODE>String</CODE> object.
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @param  host_index_str   The index of the host.
     *
     *    @param  date_index_str   The index of the date (and time).
     *
     *    @return  The load value.
     *
    ***************************************************/
    public String  getLoadValue (String  host_index_str,
				 String  date_index_str)
    /**************************************************/
    {
	try
	{
	    /*
	     * Parse the host and date index.
	     */

	    int  host_index = Integer.parseInt (host_index_str);
	    int  date_index = Integer.parseInt (date_index_str);

	    /*
	     * Return the load value obtained with the specified
	     * indces.
	     */

	    return new String (getLoadValue (host_index, date_index));
	}
	catch (NumberFormatException  e_num)
	{
	    showDiagnostics (e_num);

	    return new String (DATA_VALUE_NOT_FOUND);
	}

    } // getLoadValue ()  (for index strings)


    /**
     * Return the load value for the host and date (plus time) at the
     * specified indices. If no value could be found the string
     * &quot;-1&quot; is returned.
     *
     *    @param  host_index   The index of the host.
     *
     *    @param  date_index   The index of the date (and time).
     *
     *    @return  The load value.
     *
    *********************************************/
    private String  getLoadValue (int  host_index,
				  int  date_index)
    /********************************************/
    {
	/*
	 * Return the load value for the specified host and at the
	 * specified date (aand time) from the hashtable.
	 */

	one_host_ar [0] = (String) hosts.elementAt (host_index);

	DateFormat  date = (DateFormat) dates.elementAt (date_index);

	String  value = load_data.getValue (
			    one_host_ar,
			    date,
			    NetDataTable.DEFAULT_NET_TYPE);

	if (value == null)    // No value was available.
	    value = DATA_VALUE_NOT_FOUND;

	return value;    // Return the load value.

    } // getLoadValue ()  (for indices)


    /**
     * Return the host key for load values. In this case only one host
     * is envolved. For the (unused) network type, the default type is
     * used.
     *
     *    @param  host_index   The index of the host.
     *
     *    @return   The load host key.
     *
    ***********************************************/
    private String  getLoadHostKey (int  host_index)
    /**********************************************/
    {
	one_host_ar [0] = (String) hosts.elementAt (host_index);

	return gen_host_key.get (one_host_ar,
				 NetDataTable.DEFAULT_NET_TYPE);
    }


    /**
     * Return the host key for the both specified hosts, defining the
     * data connection. The host key is also dependent from the network
     * type and (weekly) dependent from the data table type.
     *
     *    @param  host_1_index   The index of the first host.
     *
     *    @param  host_2_index   The index of the second host.
     *
     *    @return   The host key for the net data.
     *
    *****************************************************/
    private String  getDataHostsKey (int     host_1_index,
				     int     host_2_index,
				     String  net_type)
    /****************************************************/
    {
	two_hosts_ar [0] = (String) hosts.elementAt (host_1_index);
	two_hosts_ar [1] = (String) hosts.elementAt (host_2_index);

	return gen_host_key.get (two_hosts_ar, net_type);
    }


    /**
     * Return the ping value with the specified type from the connection
     * between the specified hosts and at the specified date (plus
     * time). All variables are referenced by their indices. The ping
     * value is returned with a new <CODE>String</CODE> object. When no
     * value could be found:
     *
     * <UL>
     *
     * <LI>The string &quot;-10&quot; is returned when the connection is
     *	   skipped.</LI>
     *
     * <LI>The string &quot;-1&quot; is returned when the connection is
     *	   not skipped.</LI>
     *
     * </UL>
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @param  host_1_index_str   The index of the first host. This
     *				     host should be lexically smaller
     *				     than the second host.
     *
     *    @param  host_2_index_str   The index of the second host.
     *
     *    @param  date_index_str     The index of the date (and time).
     *
     *    @param  ping_type_str	     The ping type: min, avg, max, all.
     *
     *    @return  The ping value from the specified type.
     *
    *****************************************************/
    public String  getPingValue (String  host_1_index_str,
				 String  host_2_index_str,
				 String  date_index_str,
				 String  ping_type_str)
    /****************************************************/
    {
	/*
	 * Return the value, using the default net type.
	 */

	return getPingValue (host_1_index_str,
			     host_2_index_str,
			     date_index_str,
			     ping_type_str,
			     NetDataTable.DEFAULT_NET_TYPE);
    
    } // getPingValue ()  (default net type)


    /**
     * Return the ping value with the specified type from the connection
     * between the specified hosts, at the specified date (plus time)
     * and with the specified net type. The ping value is returned with
     * a new <CODE>String</CODE> object. All variables are referenced by
     * their indices. When no value could be found:
     *
     * <UL>
     *
     * <LI>The string &quot;-10&quot; is returned when the connection is
     *	   skipped.</LI>
     *
     * <LI>The string &quot;-1&quot; is returned when the connection is
     *	   not skipped.</LI>
     *
     * </UL>
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @param  host_1_index_str   The index of the first host. This
     *				     host should be lexically smaller
     *				     than the second host.
     *
     *    @param  host_2_index_str   The index of the second host.
     *
     *    @param  date_index_str     The index of the date (and time).
     *
     *    @param  ping_type_str	     The ping type: min, avg, max, all.
     *
     *    @param  net_type	     The net type.
     *
     *    @return  The ping value from the specified type.
     *
    *****************************************************/
    public String  getPingValue (String  host_1_index_str,
				 String  host_2_index_str,
				 String  date_index_str,
				 String  ping_type_str,
				 String  net_type)
    /****************************************************/
    {
	try    // Get the ping value.
	{
	    String  value = getDataValue (ping_data,
					  host_1_index_str,
					  host_2_index_str,
					  date_index_str,
					  net_type,
					  true);

	    if ( value.equals (DATA_VALUE_NOT_FOUND)  ||
		 value.equals (CONNECTION_SKIPPED) )
	    // Nothing available (and/or skipped): return value found.
	    {
		return new String (value);
	    }
	    else    // A ping value was found.
	    {
		ping.set (value);   // Parse it in the ping data format.

		int  ping_type = Integer.parseInt (ping_type_str);

		/*
		 * Return the specified ping type ping value.
		 */

		return new String (ping.get (ping_type));
	    }
	}
	catch (Exception  e)    // A bad formatted ping value was found.
	{
	    showDiagnostics (e);

	    return new String (DATA_VALUE_NOT_FOUND);
	}

    } // getPingValue ()  (with specified net type)


    /**
     * Return the throughput value from the connection between the
     * specified hosts and at the specified date (plus time). All
     * variables are referenced by their indices. The throughput value
     * is returned with a new <CODE>String</CODE> object. When no value
     * could be found:
     *
     * <UL>
     *
     * <LI>The string &quot;-10&quot; is returned when the connection is
     *	   skipped.</LI>
     *
     * <LI>The string &quot;-1&quot; is returned when the connection is
     *	   not skipped.</LI>
     *
     * </UL>
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @param  host_1_index_str   The index of the first host. This
     *				     host should be lexically smaller
     *				     than the second host.
     *
     *    @param  host_2_index_str   The index of the second host.
     *
     *    @param  date_index_str     The index of the date (and time).
     *
     *    @return  The throughput value.
     *
    ***********************************************************/
    public String  getThroughputValue (String  host_1_index_str,
				       String  host_2_index_str,
				       String  date_index_str)
    /***********************************************************/
    {
	/*
	 * Return the throughput value using the default net type.
	 */

	return new String (getDataValue (throughput_data,
					 host_1_index_str,
					 host_2_index_str,
					 date_index_str,
					 NetDataTable.DEFAULT_NET_TYPE,
					 true));

    } // getThroughputValue ()  (with the default net type)


    /**
     * Return the throughput value from the connection between the
     * specified hosts, at the specified date (plus time) and with the
     * specified net type. All variables are referenced by their
     * indices. The empty string is returned when no value could be
     * found. The value is returned with a new <CODE>String</CODE>
     * object.
     *
     * <UL>
     *
     * <LI>The string &quot;-10&quot; is returned when the connection is
     *	   skipped.</LI>
     *
     * <LI>The string &quot;-1&quot; is returned when the connection is
     *	   not skipped.</LI>
     *
     * </UL>
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @param  host_1_index_str   The index of the first host. This
     *				     host should be lexically smaller
     *				     than the second host.
     *
     *    @param  host_2_index_str   The index of the second host.
     *
     *    @param  date_index_str     The index of the date (and time).
     *
     *    @param  net_type   The net type.
     *
     *    @return  The throughput value.
     *
    ***********************************************************/
    public String  getThroughputValue (String  host_1_index_str,
				       String  host_2_index_str,
				       String  date_index_str,
				       String  net_type)
    /**********************************************************/
    {
	return new String (getDataValue (throughput_data,
					 host_1_index_str,
					 host_2_index_str,
					 date_index_str,
					 net_type,
					 true));
    }


    /**
     * Return the UDP bandwidth value with the specified type from the
     * connection between the specified hosts and at the specified date
     * (plus time). All variables are referenced by their indices. The
     * UDP bandwidth value is returned with a new <CODE>String</CODE>
     * object. When no value could be found:
     *
     * <UL>
     *
     * <LI>The string &quot;-10&quot; is returned when the connection is
     *	   skipped.</LI>
     *
     * <LI>The string &quot;-1&quot; is returned when the connection is
     *	   not skipped.</LI>
     *
     * </UL>
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @param  host_1_index_str   The index of the first host. This
     *				     should be lexically smaller than
     *				     the second host.
     *
     *	  @param  host_2_index_str   The index of the second host.
     *
     *	  @param  date_index_str     The index of the date (and time).
     *
     *	  @param  udp_bw_type_str    The UDP bandwidth type: receive
     *				     date rate, percentage frames lost.
     *
     *	  @return  The UDP bandwidth value from the specified type.
     *
    ******************************************************/
    public String  getUDPBWValue (String  host_1_index_str,
				  String  host_2_index_str,
				  String  date_index_str,
				  String  udp_bw_type_str)
    /*****************************************************/
    {
	/*
	 * Return the value, using the default net type.
	 */

	return getUDPBWValue (host_1_index_str,
			      host_2_index_str,
			      date_index_str,
			      udp_bw_type_str,
			      NetDataTable.DEFAULT_NET_TYPE);
    }


    /**
     * Return the UDP bandwidth value with the specified type from the
     * connection between the specified hosts, at the specified date
     * (plus time) and with the specified net type. The UDP bandwidth
     * value is returned with a new <CODE>String</CODE> object. All
     * variables are referenced by their indices. When no value could be
     * found:
     *
     * <UL>
     *
     * <LI>The string &quot;-10&quot; is returned when the connection is
     *	   skipped.</LI>
     *
     * <LI>The string &quot;-1&quot; is returned when the connection is
     *	   not skipped.</LI>
     *
     * </UL>
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @param  host_1_index_str   The index of the first host. This
     *				     host should be lexically smaller
     *				     than the second host.
     *
     *	  @param  host_2_index_str   The index of the second host.
     *
     *	  @param  date_index_str     The index of the date and time.
     *
     *	  @param  udp_bw_type_str    The UDP bandwidth type: receive
     *				     date rate, percentage frames lost.
     *
     *	  @param  net_type	     The net type.
     *
     *	  @return  The UDP bandwidth value from the specified type.
     *
    ******************************************************/
    public String  getUDPBWValue (String  host_1_index_str,
				  String  host_2_index_str,
				  String  date_index_str,
				  String  udp_bw_type_str,
				  String  net_type)
    /*****************************************************/
    {
	try    // Get the UDP bandwidth value.
	{
	    String  value = getDataValue (udp_bw_data,
					  host_1_index_str,
					  host_2_index_str,
					  date_index_str,
					  net_type,
					  true);

	    if ( value.equals (DATA_VALUE_NOT_FOUND)  ||
		 value.equals (CONNECTION_SKIPPED) )
	    // Nothing available (and/or skipped): return value found.
	    {
		return new String (value);
	    }
	    else    // An UDP bandwidth value was found.
	    {
		udp_bw.set (value);    // Parse it in the UDP BW data f.

		int  udp_bw_type = Integer.parseInt (udp_bw_type_str);

		/*
		 * Return the specified UDP bandwidth type UDP bandwidth
		 * value.
		 */

		return new String (udp_bw.get (udp_bw_type));
	    
	    }
	}
	catch (Exception  e)  // A bad formatted UDP BW value was found.
	{
	    showDiagnostics (e);

	    return new String (DATA_VALUE_NOT_FOUND);
	}

    }  // getUDPBWValue ()  (with specified net type)


    /**
     * Return the net data value which is stored in the data hashtable
     * <CODE>net_data</CODE>. The keys to obtain this value can be
     * constructed from the both host names which define the data
     * connection and the date plus time. All three the variables are
     * specified by their indices. When no value could be found:
     *
     * <UL>
     *
     * <LI>The value &quot;-10&quot; is returned when 1.&nbsp;there
     *	   should be checked if a connection is skipped and 2.&nsbp;the
     *	   connection was indeed skipped.</LI>
     *
     * <LI>The string &quot;-1&quot; otherwise.</LI>
     *
     * </UL>
     * </P>
     *
     * <P>
     * Note that this function is symmetric in both specified host
     * names: they may be interchanged, But of course they should be
     * different.
     *
     *    @param  net_data	     The hashtable with the net data.
     *
     *    @param  host_1_index_str   The index of the first host.
     *
     *    @param  host_2_index_str   The index of the second host.
     *
     *    @param  date_index_str     The index of the date (and time).
     *
     *    @param  net_type	     The network type.
     *
     *	  @param  check_skip	     True: check if the connection was
     *				     skipped when no value was found;
     *				     false: no check.
     *
     *    @return  The obtained data value.
     *
    ************************************************************/
    private String  getDataValue (NetDataTable  net_data,
    				  String	host_1_index_str,
				  String	host_2_index_str,
				  String	date_index_str,
				  String	net_type,
				  boolean	check_skip)
    /***********************************************************/
    {
	try    // Bad formatted host and date index strings.
	{
	    /*
	     * Parse the hosts and date from the index strings.
	     */

	    int  host_1_index = Integer.parseInt (host_1_index_str);
	    int  host_2_index = Integer.parseInt (host_2_index_str);
	    int  date_index   = Integer.parseInt (date_index_str);

	    /*
	     * Return the data value obtained with the specified
	     * indices.
	     */

	    return getDataValue (net_data, host_1_index, host_2_index,
				 date_index, net_type, check_skip);
	}
	catch (NumberFormatException  e_num)    // Bad index string.
	{
	    showDiagnostics (e_num);

	    /* No value to return after exception. */

	    return DATA_VALUE_NOT_FOUND;
	}

    } // getDataValue ()  (for index strings)


    /**
     * Return the net data value which is stored in the data hashtable
     * <CODE>net_data</CODE>. The keys to obtain this value can be
     * constructed from the both host names which define the data
     * connection and the date plus time. All three the variables are
     * specified by their indices. When no value could be found:
     *
     * <UL>
     *
     * <LI>The value &quot;-10&quot; is returned when 1.&nbsp;there
     *	   should be checked if a connection is skipped and 2.&nsbp;the
     *	   connection was indeed skipped.</LI>
     *
     * <LI>The string &quot;-1&quot; otherwise.</LI>
     *
     * </UL>
     * </P>
     *
     * <P>
     * Note that this function is symmetric in both specified host
     * names: they may be interchanged, But of course they should be
     * different.
     *
     *    @param  net_data	 The hashtable with the net data.
     *
     *    @param  host_1_index   The index of the first host.
     *
     *    @param  host_2_index   The index of the second host.
     *
     *    @param  date_index     The index of the date (and time).
     *
     *    @param  net_type	 The network type.
     *
     *	  @param  check_skip	 True: check if the connection was
     *				 skipped when no value was found; false:
     *				 no check.
     *
     *    @return  The otained data value.
     *
    ********************************************************/
    private String  getDataValue (NetDataTable  net_data,
    				  int		host_1_index,
				  int		host_2_index,
				  int		date_index,
				  String	net_type,
				  boolean	check_skip)
    /*******************************************************/
    {
	/*
	 * Obtain the hosts from the host vector and put these values in
	 * the array for the hosts key.
	 */

	   two_hosts_ar [0] = (String) hosts.elementAt (host_1_index);
	   two_hosts_ar [1] = (String) hosts.elementAt (host_2_index);

	/*
	 * Get the date from the corresponding vector.
	 */

	DateFormat  date = (DateFormat) dates.elementAt (date_index);

	/*
	 * Get the value from the net data hashtable. The keys are
	 * constructed from the hosts and the date (plus time).
	 */

	String  value = net_data.getValue (two_hosts_ar,
					   date,
					   net_type);

	if (value == null)    // No value could be found.
	{
	    /*
	     * Check for a skipped connection when specified. Set the
	     * value correspondingly.
	     */

	    if ( check_skip  &&
		 skip_conns.isSkipped (two_hosts_ar, net_type) )// Skip.
	    {
		value = CONNECTION_SKIPPED;
	    }
	    else    // Not skipped.
	    {
		value = DATA_VALUE_NOT_FOUND;
	    }
	}

	return value;    // Return the net data value.

    } // getDataValue ()  (for indices)


    /**
     * This function returns if there are skipped connections. It is
     * returned with a new <CODE>String</CODE> object.
     * </P>
     *
     * <P>
     * <EM>To be called from JavaScript.</EM>
     *
     *    @return   The boolean string &quot;true&quot; when there are
     *		    skipped connections; &quot;false&quot; otherwise.
     *
    **************************************/
    public String  hasSkippedConnections ()
    /*************************************/
    {
	if (skip_conns.hasSkipped ())
	    return new String (TRUE_STR);
	else
	    return new String (FALSE_STR);
    }


    /**
     * This function shows the diagnostics from an execption. It shows
     * the exception message in the status line and it prints a stack
     * trace.
     *
     *    @param  e   The exception for which the diagnostics are shown.
     *
    *******************************************/
    private void  showDiagnostics (Exception  e)
    /******************************************/
    {
	/*
	 * Set the status line message.
	 */

	StringBuffer  status_mess_sb = new StringBuffer (e.toString ());

	/*
	 * Append the data line # to the status line message when it is
	 * non-zero. It is assumed that the blink thread is stopped!
	 */

	if (data_line_nr.value > 0)
	{
	    status_mess_sb.append ("; data line #: ");
	    status_mess_sb.append (data_line_nr.value);
	}

	/*
	 * Show the status line message and print the stack trace.
	 */

	showStatus	  (status_mess_sb.toString ());
	e.printStackTrace (System.err);

	/*
	 * Append the data line # to the stack trace.
	 */

	if (data_line_nr.value > 0)
	    System.err.println ("\nData line #: " + data_line_nr.value +
				"\n");

    } // showDiagnostics ()


    /**
     * Return the Applet parameter information. The super class
     * parameter information is returned to which the parameter
     * information of this class is added.
     *
     *    @return  The parameter information.
     *
    **************************************/
    public String [][]  getParameterInfo ()
    /*************************************/
    {
	/*
	 * Get the parameter info from the super class.
	 */

	String [][]  super_param_info = super.getParameterInfo ();

	/*
	 * Define the parameter info of this class.
	 */

	String [][]  local_param_info =
	{
	  { DATES_FILE_NAME,
	    "string",
	    "name of the file with the dates used for the net data " +
	    "types; default: " + DEFAULT_DATES_FILE
	  },

	  { READ_DATES_NAME,
	    "{ true, false }",
	    "read the net data dates; default: " + DEFAULT_READ_DATES
	  },

	  { SIGNAL_BORDER_NAME,
	    "int",
	    "set the signal border; default: " + DEFAULT_SIGNAL_BORDER
	  },

	  { LIGHT_BORDER_NAME,
	    "int",
	    "set the light border; default: " + DEFAULT_LIGHT_BORDER
	  },

	  { NR_RECENT_DAYS_NAME,
	    "int",
	    "set the # recent days for the plot window; " +
	    "must be in the interval [" + MIN_NR_RECENT_DOMAIN_DAYS +
	    ", " + MAX_NR_RECENT_DOMAIN_DAYS + "]; default: " +
	    MAX_NR_RECENT_DOMAIN_DAYS
	  },

	  { NR_MEAN_DAYS_NAME,
	    "int",
	    "set the maximum # days available in the day mean data " +
	    "type; default: " + DEFAULT_NR_MEAN_DAYS
	  },

	  { GREEN_WHITE_FGND_BND_NAME,
	    "int",
	    "set the white foreground boundary, used when the green " +
	    "intensity is below this value; default: " +
	    DataPlotWindow.DFT_GREEN_WHITE_FGND_BND
	  },

	  { NO_PLOT_LEGEND_FGND_NAME,
	    "string",
	    "set the legend foreground which is used when the " +
	    "corresponding data are not plotted; default: " +
	    DataPlotWindow.DFT_NO_PLOT_LEGEND_FGND
	  },

	  { NO_PLOT_LEGEND_BGND_NAME,
	    "string",
	    "set the legend background which is used when the " +
	    "corresponding data are not plotted; default: " +
	    DataPlotWindow.DFT_NO_PLOT_LEGEND_BGND
	  }
	};

	int  super_param_info_length = super_param_info.length;
	int  local_param_info_length = local_param_info.length;

	/*
	 * Allocate storage for both parameter info's.
	 */

	String [][] parameter_info =
	    new String [super_param_info_length +
			local_param_info_length][];

	/*
	 * Copy the parameter info of the super class to the storage.
	 */

	for (int index = 0;  index < super_param_info_length;  index++)
	    parameter_info [index] = super_param_info [index];

	/*
	 * Add the parameter info of this class.
	 */

	for (int index = 0;  index < local_param_info_length;  index++)
	    parameter_info [super_param_info_length + index] =
		local_param_info [index];

	return parameter_info;    // Return the addition of both info's.

    } // getParameterInfo ()

} // class NetData
